# -*- coding: utf-8 -*-
import re

ISO639_3_1 = {
"sbk": u"Safwa",
"nrr": u"Norra",
"aua": u"Asumboa",
"auc": u"Waorani",
"aub": u"Alugu",
"aue": u"=/Kx'au//'ein",
"aud": u"Anuta",
"aug": u"Aguna",
"aui": u"Anuki",
"auh": u"Aushi",
"auk": u"Heyo",
"auj": u"Awjilah",
"aul": u"Aulua",
"auo": u"Auyokawa",
"auq": u"Anus",
"aup": u"Makayam",
"aur": u"Aruek",
"auu": u"Auye",
"aut": u"Austral",
"auw": u"Awyi",
"auv": u"Auvergnat",
"auy": u"Awiyaana",
"aux": u"Aurá",
"mlb": u"Mbule",
"sbi": u"Seti",
"wji": u"Warji",
"tnj": u"Tanjong",
"sco": u"Scots",
"yot": u"Yotti",
"mla": u"Malo",
"mlf": u"Mal",
"hch": u"Huichol",
"upi": u"Umeda",
"mle": u"Manambu",
"upv": u"Uripiv-Wala-Rano-Atchin",
"ppm": u"Papuma",
"mlm": u"Mulam",
"nen": u"Nengone",
"mlr": u"Vame",
"nem": u"Nemi",
"nej": u"Neko",
"nek": u"Neku",
"neh": u"Nyenkha",
"nei": u"Neo-Hittite",
"nef": u"Nefamese",
"neg": u"Negidal",
"ned": u"Nde-Gbite",
"nee": u"Nêlêmwa-Nixumwak",
"mlp": u"Bargam",
"nex": u"Neme",
"ney": u"Neyo",
"nev": u"Nyaheun",
"mlv": u"Motlav",
"net": u"Nete",
"neu": u"Neo",
"ner": u"Yahadian",
"mlw": u"Moloko",
"mee": u"Mengen",
"med": u"Melpa",
"meg": u"Mea",
"mef": u"Megam",
"mea": u"Menka",
"yvt": u"Yavitero",
"mec": u"Mara",
"meb": u"Ikobi",
"mem": u"Mangala",
"mei": u"Midob",
"mek": u"Mekeo",
"mej": u"Meyah",
"meu": u"Motu",
"met": u"Mato",
"mew": u"Maaka",
"mev": u"Mann",
"meq": u"Merey",
"mep": u"Miriwung",
"mes": u"Masmaje",
"mer": u"Meru",
"mey": u"Hassaniyya",
"mlx": u"Malfaxal",
"mez": u"Menominee",
"dry": u"Darai",
"xtq": u"Tumshuqese",
"drq": u"Dura",
"drs": u"Gedeo",
"drr": u"Dororo",
"dru": u"Rukai",
"drt": u"Drents",
"drw": u"Darwazi",
"dri": u"C'lela",
"drh": u"Darkhat",
"sjn": u"Sindarin",
"drl": u"Paakantyi",
"drc": u"Minderico",
"drb": u"Dair",
"dre": u"Dolpo",
"drd": u"Darmiya",
"drg": u"Rungus",
"txo": u"Toto",
"txm": u"Tomini",
"txi": u"Ikpeng",
"txh": u"Thracian",
"txg": u"Tangut",
"txe": u"Totoli",
"txc": u"Tsetsaut",
"txa": u"Tombonuo",
"xtz": u"Tasmanian",
"txx": u"Tatana",
"ppl": u"Pipil",
"txt": u"Citak",
"txs": u"Tonsea",
"txr": u"Tartessian",
"txq": u"Tii",
"dne": u"Ndendeule",
"dnd": u"Daonda",
"dng": u"Dungan",
"dnn": u"Dzùùngoo",
"lww": u"Lewo",
"dnk": u"Dengka",
"dnu": u"Danau",
"dnv": u"Danu",
"lwo": u"Luwo",
"dnr": u"Danaru",
"xtc": u"Katcha-Kadugli-Miri",
"lwa": u"Lwalu",
"dny": u"Dení",
"lwg": u"Wanga",
"kgq": u"Kamoro",
"kgp": u"Kaingang",
"kgr": u"Abun",
"kgu": u"Kobol",
"kgt": u"Somyev",
"kgv": u"Karas",
"jmr": u"Kamara",
"mwd": u"Mudbura",
"ilv": u"Ilue",
"kga": u"Koyaga",
"kgc": u"Kasseng",
"kgd": u"Kataang",
"jml": u"Jumli",
"kgf": u"Kube",
"jmb": u"Zumbun",
"jmc": u"Machame",
"kgk": u"Kaiwá",
"jma": u"Dima",
"kgm": u"Karipúna",
"kgl": u"Kunggari",
"jmd": u"Yamdena",
"kgn": u"Karingani",
"tnv": u"Tangchangya",
"xha": u"Harami",
"xhe": u"Khetrani",
"xhd": u"Hadrami",
"xho": u"Xhosa",
"xhr": u"Hernican",
"xhv": u"Khua",
"xhu": u"Hurrian",
"xht": u"Hattic",
"yur": u"Yurok",
"yga": u"Malyangapa",
"ygm": u"Yagomi",
"ybd": u"Yangbye",
"yut": u"Yopno",
"ygw": u"Yagwoia",
"czk": u"Knaanic",
"ygp": u"Gepo",
"cze": u"Czech",
"hod": u"Holma",
"hoe": u"Horom",
"hoc": u"Ho",
"hoa": u"Hoava",
"hoo": u"Holoholo",
"hol": u"Holu",
"hom": u"Homa",
"hoj": u"Hadothi",
"hoh": u"Hobyót",
"hoi": u"Holikachuk",
"hov": u"Hovongan",
"how": u"Honi",
"hot": u"Hote",
"yuj": u"Karkar-Yuri",
"hor": u"Horo",
"hop": u"Hopi",
"hoz": u"Hozo",
"hoy": u"Holiya",
"tgs": u"Nume",
"wja": u"Waja",
"yub": u"Yugambal",
"ypg": u"Phola",
"xst": u"Silt'e",
"tqm": u"Turumsa",
"yuf": u"Havasupai-Walapai-Yavapai",
"ymt": u"Mator-Taygi-Karagas",
"wur": u"Wurrugu",
"tqo": u"Toaripi",
"wuv": u"Wuvulu-Aua",
"wut": u"Wutung",
"wuy": u"Wauyai",
"wux": u"Wulna",
"wub": u"Wunambal",
"wua": u"Wikngenchera",
"wud": u"Wudu",
"wuh": u"Wutunhua",
"wun": u"Bungu",
"wum": u"Wumbvu",
"ono": u"Onondaga",
"fir": u"Firan",
"fip": u"Fipa",
"fiw": u"Fiwaga",
"fiz": u"Izere",
"fia": u"Nobiin",
"fie": u"Fyer",
"fij": u"Fijian",
"zhb": u"Zhaba",
"fin": u"Finnish",
"fil": u"Filipino",
"tqq": u"Tunni",
"mxx": u"Mahou",
"mxw": u"Namo",
"mxo": u"Mbowe",
"mxm": u"Meramera",
"mxj": u"Miju-Mishmi",
"mxk": u"Monumbo",
"mxh": u"Mvuba",
"mxi": u"Mozarabic",
"mxf": u"Malgbe",
"mxg": u"Mbangala",
"mxd": u"Modang",
"mxe": u"Mele-Fila",
"mxc": u"Manyika",
"zwa": u"Zay",
"jhi": u"Jehai",
"mdj": u"Mangbetu",
"mdk": u"Mangbutu",
"mdh": u"Maguindanaon",
"mdi": u"Mamvu",
"mdn": u"Mbati",
"mdm": u"Mayogo",
"mdb": u"Morigi",
"mdf": u"Moksha",
"mdg": u"Massalat",
"mdd": u"Mbum",
"mdx": u"Dizin",
"mdr": u"Mandar",
"mdp": u"Mbala",
"mdq": u"Mbole",
"mdw": u"Mbosi",
"mdt": u"Mbere",
"mdu": u"Mboko",
"smz": u"Simeku",
"smy": u"Semnani",
"smx": u"Samba",
"smw": u"Sumbawa",
"smv": u"Samvedi",
"smu": u"Somray",
"smt": u"Simte",
"smr": u"Simeulue",
"smq": u"Samo",
"dsq": u"Tadaksahak",
"dsn": u"Dusner",
"dso": u"Desiya",
"smk": u"Bolinao",
"dsh": u"Daasanach",
"dsi": u"Disa",
"smg": u"Simbali",
"smf": u"Auwe",
"smb": u"Simbari",
"syo": u"Suoy",
"syn": u"Senaya",
"zhi": u"Zhire",
"yif": u"Ache",
"yia": u"Yinggarda",
"syl": u"Sylheti",
"atf": u"Atuence",
"ate": u"Atemble",
"atb": u"Zaiwa",
"atc": u"Atsahuaca",
"xur": u"Urartian",
"ata": u"Pele-Ata",
"atn": u"Ashtiani",
"ato": u"Atong",
"atm": u"Ata",
"atj": u"Atikamekw",
"atk": u"Ati",
"ati": u"Attié",
"atw": u"Atsugewi",
"atu": u"Reel",
"atr": u"Waimiri-Atroari",
"atq": u"Aralle-Tabulahan",
"isc": u"Isconahua",
"xum": u"Umbrian",
"isa": u"Isabi",
"xuo": u"Kuo",
"atz": u"Arta",
"atx": u"Arutani",
"aty": u"Aneityum",
"kfv": u"Kurmukar",
"kft": u"Kanjari",
"kfu": u"Katkari",
"kfr": u"Kachchi",
"kfs": u"Bilaspuri",
"kfp": u"Korwa",
"kfq": u"Korku",
"kfz": u"Koromfé",
"jjr": u"Bankal",
"kfy": u"Kumaoni",
"kff": u"Koya",
"kfg": u"Kudiya",
"kfc": u"Konda-Dora",
"kfa": u"Kodava",
"kfn": u"Kuk",
"kfl": u"Kung",
"kfm": u"Khunsari",
"kfj": u"Kemiehua",
"kfk": u"Kinnauri",
"kfh": u"Kurichiya",
"xia": u"Xiandao",
"tns": u"Tenis",
"xii": u"Xiri",
"xil": u"Illyrian",
"xin": u"Xinca",
"xip": u"Xipináwa",
"xir": u"Xiriâna",
"xiy": u"Xipaya",
"yip": u"Pholo",
"gyg": u"Gbayi",
"gyf": u"Gungabula",
"gye": u"Gyem",
"gyd": u"Kayardild",
"gyb": u"Garus",
"gym": u"Ngäbere",
"gyl": u"Gayil",
"knl": u"Keninjal",
"gyi": u"Gyele",
"knm": u"Kanamarí",
"gyr": u"Guarayu",
"gyy": u"Gunya",
"knk": u"Kuranko",
"nzu": u"Teke-Nzikou",
"nzy": u"Nzakambay",
"nzb": u"Njebi",
"nzk": u"Nzakara",
"nzi": u"Nzima",
"yiz": u"Azhe",
"pny": u"Pinyin",
"pnx": u"Phong-Kniang",
"pnp": u"Pancana",
"tnr": u"Bedik",
"pns": u"Ponosakan",
"vgr": u"Vaghri",
"tyn": u"Kombai",
"pnr": u"Panim",
"tyh": u"O'du",
"tyi": u"Teke-Tsaayi",
"neo": u"Ná-Meo",
"tya": u"Tauya",
"pnt": u"Pontic",
"knv": u"Tabo",
"tkr": u"Tsakhur",
"tyx": u"Teke-Tyee",
"pnw": u"Panytyima",
"tyz": u"Tày",
"knw": u"Kung-Ekoka",
"tyu": u"Kua",
"tyv": u"Tuvinian",
"pnv": u"Pinigura",
"typ": u"Thaypan",
"dok": u"Dondo",
"doh": u"Dong",
"doo": u"Dongo",
"dol": u"Doso",
"lpx": u"Lopit",
"dob": u"Dobu",
"doa": u"Dom",
"dof": u"Domu",
"pnk": u"Paunaka",
"doe": u"Doe",
"doz": u"Dorze",
"dox": u"Bussa",
"doy": u"Dompo",
"dor": u"Dori'o",
"dos": u"Dogosé",
"dop": u"Lukpa",
"dov": u"Dombe",
"dow": u"Doyayo",
"dot": u"Dass",
"pno": u"Panobo",
"pnn": u"Pinai-Hagahai",
"nec": u"Nedebang",
"zak": u"Zanaki",
"kul": u"Kulere",
"png": u"Pongu",
"tgd": u"Ciwogai",
"wxa": u"Waxianghua",
"zsu": u"Sukurum",
"new": u"Newari",
"koi": u"Komi-Permyak",
"bav": u"Vengo",
"baw": u"Bambili-Bambui",
"bar": u"Bavarian",
"bap": u"Bantawa",
"baq": u"Basque",
"baz": u"Tunen",
"bax": u"Bamun",
"bay": u"Batuley",
"baf": u"Nubaca",
"bag": u"Tuki",
"bae": u"Baré",
"bab": u"Bainouk-Gunyuño",
"bac": u"Badui",
"baa": u"Babatana",
"ban": u"Balinese",
"bao": u"Waimaha",
"bal": u"Baluchi",
"bam": u"Bambara",
"baj": u"Barakai",
"bak": u"Bashkir",
"tgk": u"Tajik",
"smp": u"Samaritan",
"irx": u"Kamberau",
"iry": u"Iraya",
"irr": u"Ir",
"iru": u"Irula",
"irh": u"Irarutu",
"iri": u"Irigwe",
"irk": u"Iraqw",
"irn": u"Irántxe",
"xve": u"Venetic",
"ire": u"Iresim",
"omc": u"Mochica",
"oma": u"Omaha-Ponca",
"omg": u"Omagua",
"ome": u"Omejes",
"wtw": u"Wotu",
"omk": u"Omok",
"omi": u"Omi",
"omo": u"Utarmbung",
"omn": u"Minoan",
"oml": u"Ombo",
"omu": u"Omurano",
"omt": u"Omotik",
"wti": u"Berta",
"wtm": u"Mewati",
"rgu": u"Ringgou",
"unp": u"Worora",
"unr": u"Mundari",
"unx": u"Munda",
"fng": u"Fanagalo",
"und": u"Undetermined",
"une": u"Uneme",
"ung": u"Ngarinyin",
"unk": u"Enawené-Nawé",
"unm": u"Unami",
"fni": u"Fania",
"scg": u"Sanggau",
"pre": u"Principense",
"prd": u"Parsi-Dari",
"prg": u"Prussian",
"prf": u"Paranan",
"tlb": u"Tobelo",
"fra": u"French",
"prc": u"Parachi",
"fre": u"French",
"frd": u"Fordata",
"frk": u"Frankish",
"prb": u"Lua'",
"frq": u"Forak",
"frp": u"Arpitan",
"frt": u"Fortsenal",
"ywa": u"Kalou",
"rge": u"Romano-Greek",
"mcn": u"Masana",
"mcl": u"Macaguaje",
"mck": u"Mbunda",
"mcj": u"Mvanip",
"mci": u"Mese",
"gli": u"Guliguli",
"mcg": u"Mapoyo",
"mcf": u"Matsés",
"mcd": u"Sharanahua",
"mcc": u"Bitur",
"mca": u"Maca",
"prh": u"Porohanon",
"glk": u"Gilaki",
"mcz": u"Mawan",
"mcx": u"Mpiemo",
"mcv": u"Minanibai",
"mct": u"Mengisa",
"mcs": u"Mambai",
"mcr": u"Menya",
"mcq": u"Ese",
"mcp": u"Makaa",
"pru": u"Puragi",
"rgk": u"Rangkas",
"slx": u"Salampasu",
"sly": u"Selayar",
"slz": u"Ma'ya",
"prt": u"Phai",
"slt": u"Sila",
"slu": u"Selaru",
"slv": u"Slovenian",
"slw": u"Sialum",
"slp": u"Lamaholot",
"prw": u"Parawen",
"slr": u"Salar",
"sll": u"Salt-Yui",
"sjr": u"Siar-Lak",
"sln": u"Salinan",
"prv": u"Provençal",
"rgn": u"Romagnol",
"slj": u"Salumá",
"sld": u"Sissala",
"sjp": u"Surjapuri",
"prp": u"Parsi",
"prs": u"Dari",
"gld": u"Nanai",
"prr": u"Puri",
"gle": u"Irish",
"tzh": u"Tzeltal",
"glg": u"Galician",
"tzo": u"Tzotzil",
"tzn": u"Tugun",
"dho": u"Dhodia",
"dhn": u"Dhanki",
"dhm": u"Zemba",
"dhl": u"Dhalandji",
"dhi": u"Dhimal",
"gly": u"Gule",
"dhg": u"Dhangu",
"dhd": u"Dhundari",
"wry": u"Merwari",
"prx": u"Purik",
"dhv": u"Dehu",
"dhu": u"Dhurga",
"swr": u"Saweru",
"dhs": u"Dhaiso",
"dhr": u"Dhargari",
"sjo": u"Xibe",
"kiz": u"Kisi",
"kiy": u"Kirikiri",
"kis": u"Kis",
"jku": u"Labir",
"kiq": u"Kosadle",
"kiv": u"Kimbu",
"kit": u"Agob",
"kik": u"Kikuyu",
"kii": u"Kitsai",
"jko": u"Kubo",
"kio": u"Kiowa",
"kin": u"Kinyarwanda",
"kim": u"Karagas",
"kil": u"Kariya",
"kic": u"Kickapoo",
"kib": u"Koalib",
"kia": u"Kim",
"kig": u"Kimaama",
"glr": u"Glaro-Twabo",
"kie": u"Kibet",
"kid": u"Koshin",
"sja": u"Epena",
"zmm": u"Marimanindji",
"scv": u"Sheni",
"glv": u"Manx",
"glw": u"Glavda",
"yei": u"Yeni",
"smd": u"Sama",
"yen": u"Yendang",
"yea": u"Ravula",
"yec": u"Yeniche",
"yee": u"Yimas",
"yey": u"Yeyi",
"yes": u"Nyankpa",
"yer": u"Tarok",
"yeu": u"Yerukula",
"yet": u"Yetfa",
"yev": u"Yapunda",
"hah": u"Hahon",
"bnz": u"Beezen",
"bny": u"Bintulu",
"bnx": u"Bangubangu",
"hal": u"Halang",
"ham": u"Hewa",
"han": u"Hangaza",
"hao": u"Hakö",
"bns": u"Bundeli",
"bnr": u"Butmas-Tur",
"bnq": u"Bantik",
"bnp": u"Bola",
"bnw": u"Bisis",
"bnv": u"Bonerif",
"bnu": u"Bentong",
"bnk": u"Bierebo",
"bni": u"Bangi",
"bnh": u"Banawá",
"bno": u"Bantoanon",
"bnn": u"Bunun",
"bnm": u"Batanga",
"bnl": u"Boon",
"bnc": u"Bontok",
"bnb": u"Bookan",
"bna": u"Bonerate",
"has": u"Haisla",
"bng": u"Benga",
"bnf": u"Masiwang",
"bne": u"Bintauna",
"opt": u"Opata",
"opy": u"Ofayé",
"opa": u"Okpamheri",
"opm": u"Oksapmin",
"opo": u"Opao",
"opk": u"Kopkaka",
"ola": u"Walungge",
"www": u"Wawa",
"old": u"Mochi",
"ole": u"Olekha",
"wwr": u"Warrwa",
"olm": u"Oloma",
"olo": u"Livvi",
"yej": u"Yevanic",
"olr": u"Olrat",
"wwa": u"Waama",
"wwb": u"Wakabunga",
"wwo": u"Wetamut",
"txu": u"Kayapó",
"umu": u"Munsee",
"ump": u"Umpila",
"for": u"Fore",
"fos": u"Siraya",
"wmw": u"Mwani",
"fod": u"Foodo",
"umd": u"Umbindhamu",
"umg": u"Umbuygamu",
"uma": u"Umatilla",
"umc": u"Marrucinian",
"tni": u"Tandia",
"umm": u"Umon",
"fom": u"Foma",
"fon": u"Fon",
"umi": u"Ukit",
"foi": u"Foi",
"ulm": u"Ulumanda'",
"snf": u"Noon",
"zuy": u"Zumaya",
"pbn": u"Kpasam",
"zuh": u"Tokano",
"zun": u"Zuni",
"zul": u"Zulu",
"zum": u"Kumzari",
"mbl": u"Maxakalí",
"mbm": u"Ombamba",
"mbn": u"Macaguán",
"mbh": u"Mangseng",
"mbj": u"Nadëb",
"mbk": u"Malol",
"mbe": u"Molale",
"som": u"Somali",
"mba": u"Higaonon",
"mbc": u"Macushi",
"soq": u"Kanasi",
"sop": u"Songe",
"sos": u"Seeku",
"sor": u"Somrai",
"lwt": u"Lewotobi",
"sov": u"Sonsorol",
"mbu": u"Mbula-Bwazza",
"mbv": u"Mbulungish",
"mbw": u"Maring",
"mbp": u"Malayo",
"mbq": u"Maisin",
"lwm": u"Laomian",
"azo": u"Awing",
"iqu": u"Iquito",
"aza": u"Azha",
"aze": u"Azerbaijani",
"xwg": u"Kwegu",
"azr": u"Adzera",
"rej": u"Rejang",
"xwc": u"Woccon",
"xwa": u"Kwaza",
"khx": u"Kanu",
"khz": u"Keapara",
"khp": u"Kapori",
"khr": u"Kharia",
"khs": u"Kasua",
"kht": u"Khamti",
"kgs": u"Kumbainggar",
"khv": u"Khvarshi",
"khw": u"Khowar",
"khh": u"Kehu",
"khj": u"Kuturmi",
"khl": u"Lusi",
"khn": u"Khandesi",
"kho": u"Khotanese",
"kha": u"Khasi",
"khb": u"Lü",
"khe": u"Korowai",
"khf": u"Khuen",
"xkj": u"Kajali",
"xkk": u"Kaco'",
"xkh": u"Karahawyana",
"xko": u"Kiorr",
"kou": u"Koke",
"xkc": u"Kho'ini",
"xkf": u"Khengkha",
"xkg": u"Kagoro",
"xke": u"Kereho",
"xkz": u"Kurtokha",
"kgy": u"Kyerung",
"xkx": u"Karore",
"kgx": u"Kamaru",
"xkr": u"Xakriabá",
"xks": u"Kumbewaha",
"xkp": u"Kabatei",
"xkq": u"Koroni",
"xkv": u"Kgalagadi",
"xkw": u"Kembra",
"xkt": u"Kantosi",
"xku": u"Kaamba",
"nou": u"Ewage-Notu",
"jmw": u"Mouwase",
"otr": u"Otoro",
"nxu": u"Narau",
"rnp": u"Rongpo",
"nxq": u"Naxi",
"nxr": u"Ninggerum",
"nxx": u"Nafri",
"wss": u"Wasa",
"nxe": u"Nage",
"nxg": u"Ngad'a",
"nxa": u"Nauete",
"nxm": u"Numidian",
"kge": u"Komering",
"nxn": u"Ngawun",
"nxi": u"Nindi",
"nxj": u"Nyadu",
"kgg": u"Kusunda",
"oss": u"Ossetian",
"ost": u"Osatu",
"osi": u"Osing",
"tke": u"Takwane",
"oso": u"Ososo",
"osa": u"Osage",
"tkb": u"Buksa",
"osc": u"Oscan",
"vep": u"Veps",
"tka": u"Truká",
"tkn": u"Toku-No-Shima",
"ved": u"Veddah",
"kgo": u"Krongo",
"ven": u"Venda",
"veo": u"Ventureño",
"vel": u"Veluws",
"tkm": u"Takelma",
"lre": u"Laurentian",
"lrg": u"Laragia",
"xnb": u"Kanakanabu",
"lri": u"Marachi",
"yae": u"Pumé",
"lrk": u"Loarki",
"lrm": u"Marama",
"lrl": u"Lari",
"lro": u"Laro",
"lrn": u"Lorang",
"lrv": u"Larevat",
"lrz": u"Lemerig",
"dil": u"Dilling",
"dim": u"Dime",
"din": u"Dinka",
"dio": u"Dibo",
"dih": u"Kumiai",
"dii": u"Dimbong",
"dij": u"Dai",
"did": u"Didinga",
"dif": u"Dieri",
"dig": u"Digo",
"dia": u"Dia",
"diy": u"Diuwe",
"diz": u"Ding",
"dit": u"Dirari",
"diu": u"Diriku",
"div": u"Dhivehi",
"dir": u"Dirim",
"dis": u"Dimasa",
"tkp": u"Tikopia",
"ufi": u"Ufim",
"rop": u"Kriol",
"ruh": u"Ruga",
"run": u"Rundi",
"zrs": u"Mairasi",
"zrp": u"Zarphatic",
"zrg": u"Mirgan",
"rub": u"Gungu",
"tnf": u"Tangshewi",
"tkx": u"Tangko",
"zro": u"Záparo",
"zrn": u"Zerenkel",
"rea": u"Rerau",
"ydg": u"Yidgha",
"xmo": u"Morerebi",
"ymz": u"Muzi",
"box": u"Buamu",
"hbn": u"Heiban",
"bop": u"Bonkiman",
"boq": u"Bogaya",
"bor": u"Borôro",
"bos": u"Bosnian",
"bot": u"Bongo",
"bou": u"Bondei",
"bov": u"Tuwuli",
"bow": u"Rema",
"boh": u"Boma",
"boi": u"Barbareño",
"boj": u"Anjam",
"bok": u"Bonjo",
"bol": u"Bole",
"bom": u"Berom",
"bon": u"Bine",
"hbu": u"Habu",
"boa": u"Bora",
"bob": u"Aweer",
"bod": u"Tibetan",
"boe": u"Mundabli",
"bof": u"Bolon",
"ipk": u"Inupiaq",
"ipi": u"Ipili",
"ipo": u"Ipiko",
"aym": u"Aymara",
"ayo": u"Ayoreo",
"ayi": u"Leyigha",
"ayk": u"Akuku",
"aye": u"Ayere",
"ayd": u"Ayabadhu",
"ayg": u"Ginyanga",
"aya": u"Awar",
"ayu": u"Ayu",
"oog": u"Ong",
"oon": u"Önge",
"ylu": u"Aribwaung",
"oor": u"Oorlams",
"ylr": u"Yalarnnga",
"tep": u"Tepecano",
"wnc": u"Wantoat",
"fly": u"Tsotsitaal",
"isk": u"Ishkashimi",
"tby": u"Tabaru",
"flr": u"Fuliiru",
"ulw": u"Ulwa",
"fli": u"Fali",
"flh": u"Foau",
"uli": u"Ulithian",
"ull": u"Ullatan",
"ulc": u"Ulch",
"ula": u"Fungwa",
"ulf": u"Usku",
"idt": u"Idaté",
"ygr": u"Yagaria",
"gzn": u"Gane",
"sub": u"Suku",
"idu": u"Idoma",
"tbx": u"Kapin",
"gzi": u"Gazi",
"idr": u"Indri",
"uan": u"Kuan",
"gza": u"Ganza",
"ter": u"Tereno",
"ssy": u"Saho",
"yly": u"Nyâlayu",
"nyx": u"Nganyaywana",
"nyy": u"Nyakyusa-Ngonde",
"ido": u"Ido",
"nys": u"Nyunga",
"nyp": u"Nyang'i",
"nyq": u"Nayini",
"nyv": u"Nyulnyul",
"nyw": u"Nyaw",
"nyt": u"Nyawaygi",
"nyu": u"Nyungwe",
"nyj": u"Nyanga",
"nyk": u"Nyaneka",
"nyh": u"Nyigina",
"nyn": u"Nyankole",
"nyo": u"Nyoro",
"nyl": u"Nyeu",
"kxa": u"Kairiru",
"nyb": u"Nyangbo",
"nyc": u"Nyanga-li",
"nya": u"Nyanja",
"nyf": u"Giryama",
"nyg": u"Nyindu",
"nyd": u"Nyore",
"nye": u"Nyengo",
"mas": u"Masai",
"mar": u"Marathi",
"maw": u"Mampruli",
"mav": u"Sateré-Mawé",
"snl": u"Sangil",
"idi": u"Idi",
"snk": u"Soninke",
"snh": u"Shinabo",
"sni": u"Sensi",
"snw": u"Selee",
"mac": u"Macedonian",
"mae": u"Bo-Rukul",
"mad": u"Madurese",
"mag": u"Magahi",
"maf": u"Mafa",
"mai": u"Maithili",
"mah": u"Marshallese",
"mak": u"Makasar",
"mam": u"Mam",
"mao": u"Maori",
"man": u"Mandingo",
"msx": u"Moresada",
"ylm": u"Limi",
"zng": u"Mang",
"kxy": u"Kayong",
"znk": u"Manangkari",
"kxz": u"Kerewo",
"zns": u"Mangas",
"yin": u"Yinchia",
"ssn": u"Waata",
"lse": u"Lusengo",
"lsa": u"Lasgerdi",
"lsm": u"Saamia",
"ttv": u"Titan",
"lsh": u"Lish",
"lsi": u"Lashi",
"ttk": u"Totoro",
"lsr": u"Aruop",
"lss": u"Lasi",
"ssd": u"Siroi",
"ttc": u"Tektiteko",
"ttb": u"Gaa",
"tta": u"Tutelo",
"ttg": u"Tutong",
"ssg": u"Seimat",
"tte": u"Bwanabwana",
"jig": u"Djingili",
"jid": u"Bu",
"djr": u"Djambarrpuyngu",
"dju": u"Kapriman",
"jic": u"Tol",
"djw": u"Djawi",
"jia": u"Jina",
"jio": u"Jiamao",
"jil": u"Jilim",
"jih": u"sTodsde",
"jii": u"Jiiddu",
"dja": u"Djadjawurrung",
"djb": u"Djinba",
"dje": u"Zarma",
"djd": u"Djamindjung",
"djf": u"Djangun",
"dji": u"Djinang",
"djj": u"Djeebbana",
"djl": u"Djiwarli",
"djo": u"Jangkang",
"djn": u"Djauan",
"kky": u"Guguyimidjir",
"kkx": u"Kohin",
"kkz": u"Kaska",
"kku": u"Tumi",
"kkt": u"Koi",
"kkw": u"Teke-Kukuya",
"kkv": u"Kangean",
"kkq": u"Kaiku",
"kkp": u"Gugubera",
"kks": u"Giiwo",
"kkr": u"Kir-Balar",
"kkm": u"Kiong",
"kko": u"Karko",
"kki": u"Kagulu",
"kkh": u"Khün",
"kkk": u"Kokota",
"kkj": u"Kako",
"kke": u"Kakabe",
"kkd": u"Kinuku",
"kka": u"Kakanda",
"kkc": u"Odoodee",
"kkb": u"Kwerisa",
"xln": u"Alanic",
"xli": u"Liburnian",
"xle": u"Lemnian",
"xld": u"Lydian",
"xlc": u"Lycian",
"xla": u"Kamula",
"xly": u"Elymian",
"xls": u"Lusitanian",
"vec": u"Venetian",
"xlp": u"Lepontic",
"bly": u"Notre",
"blz": u"Balantak",
"blw": u"Balangao",
"blv": u"Bolo",
"blq": u"Baluan-Pam",
"blp": u"Blablanga",
"bls": u"Balaesang",
"blr": u"Blang",
"bll": u"Biloxi",
"blo": u"Anii",
"bli": u"Bolia",
"blh": u"Kuwaa",
"blj": u"Bolongan",
"ble": u"Balanta-Kentohe",
"bld": u"Bolango",
"blg": u"Balau",
"blf": u"Buol",
"bla": u"Siksika",
"blb": u"Bilua",
"orz": u"Ormu",
"orx": u"Oro",
"oru": u"Ormuri",
"orr": u"Oruma",
"oro": u"Orokolo",
"orm": u"Oromo",
"ork": u"Orokaiva",
"orh": u"Oroqen",
"org": u"Oring",
"ore": u"Orejón",
"wsv": u"Wotapuri-Katarqalai",
"orc": u"Orma",
"ora": u"Oroha",
"xpm": u"Pumpokol",
"waw": u"Waiwai",
"ptt": u"Enrekang",
"onj": u"Onjob",
"oni": u"Onin",
"onn": u"Onobasulu",
"laz": u"Aribwatsa",
"onb": u"Lingao",
"ona": u"Ona",
"tbw": u"Tagbanwa",
"ong": u"Olo",
"one": u"Oneida",
"ons": u"Ono",
"onp": u"Sartang",
"ont": u"Ontenu",
"onu": u"Unua",
"uky": u"Kuuk-Yak",
"ukw": u"Ukwuani-Aboh-Ndoni",
"uku": u"Ukue",
"ukr": u"Ukrainian",
"fmp": u"Fe'fe'",
"ukp": u"Ukpe-Bayobiri",
"rmz": u"Marma",
"ukh": u"Ukhwejo",
"ukg": u"Ukuriguma",
"rmx": u"Romam",
"uka": u"Kaburi",
"rmb": u"Rembarunga",
"tbh": u"Thurawal",
"lnn": u"Lorediakarkar",
"zsa": u"Sarasira",
"sak": u"Sake",
"saj": u"Sahu",
"sah": u"Yakut",
"sao": u"Sause",
"san": u"Sanskrit",
"sac": u"Meskwaki",
"sab": u"Buglere",
"saa": u"Saba",
"rme": u"Angloromani",
"sag": u"Sango",
"saf": u"Safaliba",
"sae": u"Sabanê",
"sad": u"Sandawe",
"saz": u"Saurashtra",
"say": u"Saya",
"sax": u"Sa",
"rmk": u"Romkun",
"sas": u"Sasak",
"sar": u"Saraveca",
"saq": u"Samburu",
"sap": u"Sanapaná",
"saw": u"Sawi",
"rmh": u"Murkim",
"sau": u"Saleman",
"sat": u"Santali",
"ulb": u"Ulukwumi",
"tri": u"Trió",
"zom": u"Zou",
"rmm": u"Roma",
"ylg": u"Yelogu",
"iwo": u"Iwur",
"iwm": u"Iwam",
"iwk": u"I-Wak",
"wno": u"Wano",
"wnm": u"Wanggamala",
"tbl": u"Tboli",
"pwg": u"Gapapaiwa",
"axx": u"Xaragure",
"wnp": u"Wanap",
"axb": u"Abipon",
"wnu": u"Usan",
"axe": u"Ayerrerenge",
"pwa": u"Pawaia",
"pwn": u"Paiwan",
"pwm": u"Molbog",
"xmh": u"Kuku-Muminh",
"xmi": u"Miarrã",
"xmj": u"Majera",
"xmd": u"Mbudum",
"xme": u"Median",
"xmf": u"Mingrelian",
"xmg": u"Mengaka",
"xma": u"Mushungulu",
"xmb": u"Mbonga",
"xmc": u"Makhuwa-Marrevone",
"xmx": u"Maden",
"xmy": u"Mayaguduna",
"xmt": u"Matbat",
"xmu": u"Kamu",
"pti": u"Pintiini",
"xmp": u"Kuku-Mu'inh",
"xmq": u"Kuku-Mangk",
"xmr": u"Meroitic",
"ges": u"Geser-Gorom",
"ger": u"German",
"geq": u"Geme",
"gew": u"Gera",
"gez": u"Geez",
"gey": u"Enya",
"gex": u"Garre",
"geb": u"Kire",
"gea": u"Geruma",
"geg": u"Gengle",
"ged": u"Gade",
"gek": u"Yiwom",
"gej": u"Gen",
"gei": u"Gebe",
"geo": u"Georgian",
"gel": u"ut-Ma'in",
"zhw": u"Zhoa",
"wny": u"Wanyi",
"zza": u"Zaza",
"fqs": u"Fas",
"yxg": u"Yagara",
"tuy": u"Tugen",
"sis": u"Siuslaw",
"squ": u"Squamish",
"vku": u"Kurrama",
"lpa": u"Lelepa",
"vki": u"Ija-Zuba",
"vkj": u"Kujarge",
"vkk": u"Kaur",
"vkl": u"Kulisusu",
"vkm": u"Kamakan",
"wdj": u"Wadjiginy",
"vko": u"Kodeoha",
"vka": u"Kariyarra",
"wul": u"Silimo",
"tux": u"Tuxináwa",
"tuz": u"Turka",
"tuq": u"Tedaga",
"tur": u"Turkish",
"tus": u"Tuscarora",
"tuu": u"Tututni",
"tuv": u"Turkana",
"tuh": u"Taulil",
"tui": u"Tupuri",
"tuj": u"Tugutil",
"tuk": u"Turkmen",
"tul": u"Tula",
"tum": u"Tumbuka",
"tun": u"Tunica",
"tuo": u"Tucano",
"ime": u"Imeraguen",
"tub": u"Tübatulabal",
"tuc": u"Mutu",
"tud": u"Tuxá",
"tue": u"Tuyuca",
"tug": u"Tunia",
"kjb": u"Q'anjob'al",
"kja": u"Mlap",
"dkr": u"Kuijau",
"kje": u"Kisar",
"kjj": u"Khinalugh",
"kjh": u"Khakas",
"kji": u"Zabana",
"kjn": u"Kunjen",
"dkx": u"Mazagway",
"kjm": u"Kháng",
"kjr": u"Kurudu",
"imi": u"Anamgura",
"dka": u"Dakpakha",
"kjz": u"Bumthangkha",
"kjy": u"Erave",
"dkk": u"Dakka",
"iml": u"Miluk",
"tua": u"Wiarumus",
"imn": u"Imonda",
"siv": u"Sumariup",
"bmb": u"Bembe",
"bmc": u"Biem",
"bma": u"Lame",
"bmf": u"Bom",
"bmg": u"Bamwe",
"bme": u"Limassa",
"bmj": u"Bote-Majhi",
"bmk": u"Ghayavi",
"bmh": u"Kein",
"bmi": u"Bagirmi",
"bmo": u"Bambalang",
"bml": u"Bomboli",
"bmr": u"Muinane",
"bmp": u"Bulgebi",
"bmq": u"Bomu",
"bmv": u"Bum",
"bmw": u"Bomwali",
"bmu": u"Somba-Siawari",
"bmz": u"Baramu",
"kjf": u"Khalaj",
"bmx": u"Baimak",
"kjg": u"Khmu",
"hdy": u"Hadiyya",
"vun": u"Vunjo",
"sxs": u"Sasaru",
"vum": u"Vumbu",
"ivb": u"Ibatan",
"ylb": u"Yaleba",
"tvd": u"Tsuvadi",
"ivv": u"Ivatan",
"sbf": u"Shabo",
"pap": u"Papiamento",
"paq": u"Parya",
"par": u"Panamint",
"pas": u"Papasena",
"pat": u"Papitalai",
"pau": u"Palauan",
"pav": u"Pakaásnovos",
"pax": u"Pankararé",
"pay": u"Pech",
"paz": u"Pankararú",
"vut": u"Vute",
"pab": u"Parecís",
"pac": u"Pacoh",
"pad": u"Paumarí",
"pae": u"Pagibete",
"paf": u"Paranawát",
"pag": u"Pangasinan",
"pah": u"Tenharim",
"pai": u"Pe",
"paj": u"Ipeka-Tapuia",
"pak": u"Parakanã",
"pal": u"Pahlavi",
"pam": u"Pampanga",
"pan": u"Panjabi",
"nac": u"Narak",
"kju": u"Kashaya",
"oia": u"Oirata",
"naa": u"Namla",
"naf": u"Nabak",
"tks": u"Takestani",
"kjx": u"Ramopa",
"uji": u"Tanjijili",
"mpn": u"Mindiri",
"gdq": u"Mehri",
"gdr": u"Wipi",
"gdu": u"Gudu",
"gdx": u"Godwari",
"gdd": u"Gedaged",
"gde": u"Gude",
"gdf": u"Guduf-Gava",
"gdg": u"Ga'dang",
"gdh": u"Gadjerawang",
"gdi": u"Gundi",
"gdj": u"Gurdjar",
"gdk": u"Gadang",
"gdl": u"Dirasha",
"gdm": u"Laal",
"gdn": u"Umanakaina",
"gdo": u"Ghodoberi",
"nas": u"Naasioi",
"poy": u"Pogolo",
"nap": u"Neapolitan",
"sbg": u"Seget",
"nav": u"Navajo",
"fvr": u"Fur",
"ulk": u"Meriam",
"naw": u"Nawuri",
"moz": u"Mukulu",
"moy": u"Shekkacho",
"mox": u"Molima",
"mos": u"Mossi",
"mor": u"Moro",
"mov": u"Mohave",
"mou": u"Mogum",
"mot": u"Barí",
"mok": u"Morori",
"moj": u"Monzombo",
"moi": u"Mboi",
"moh": u"Mohawk",
"moo": u"Monom",
"mon": u"Mongolian",
"mom": u"Mangue",
"mol": u"Moldavian",
"moc": u"Mocoví",
"mob": u"Moinba",
"moa": u"Mwan",
"mog": u"Mongondow",
"mof": u"Mohegan-Montauk-Narragansett",
"moe": u"Montagnais",
"mod": u"Mobilian",
"nay": u"Narrinyeri",
"wel": u"Welsh",
"tvu": u"Tunen",
"tvw": u"Sedoa",
"tvs": u"Taveta",
"tvm": u"Tela-Masbuar",
"tvl": u"Tuvalu",
"tvn": u"Tavoyan",
"tve": u"Te'un",
"eze": u"Uzekwe",
"tva": u"Vaghua",
"kmg": u"Kâte",
"kme": u"Bakole",
"jgk": u"Gwak",
"kmb": u"Kimbundu",
"kma": u"Konni",
"jgo": u"Ngomba",
"ddr": u"Dhudhuroa",
"jgb": u"Ngbee",
"ddw": u"Dawera-Daweloor",
"jge": u"Judeo-Georgian",
"kmh": u"Kalam",
"ddj": u"Jaru",
"kmt": u"Kemtuik",
"ddo": u"Dido",
"kmq": u"Kwama",
"kmp": u"Gimme",
"ddg": u"Fataluku",
"dde": u"Doondo",
"ddd": u"Dongotono",
"mpi": u"Mpade",
"acb": u"Áncá",
"aca": u"Achagua",
"xnr": u"Kangri",
"ace": u"Achinese",
"acd": u"Gikyode",
"ack": u"Aka-Kora",
"aci": u"Aka-Cari",
"ach": u"Acoli",
"ptr": u"Piamatsina",
"acn": u"Achang",
"acl": u"Akar-Bale",
"acs": u"Acroá",
"acr": u"Achi",
"acv": u"Achumawi",
"acu": u"Achuar-Shiwiar",
"act": u"Achterhoeks",
"acz": u"Acheron",
"xno": u"Anglo-Norman",
"wao": u"Wappo",
"bjg": u"Bidyogo",
"bjd": u"Bandjigali",
"bjc": u"Bariji",
"bjb": u"Banggarla",
"bja": u"Budza",
"bjn": u"Banjar",
"bjm": u"Bajelani",
"bjk": u"Barok",
"bjj": u"Kanauji",
"bji": u"Burji",
"bjh": u"Bahinemo",
"bjw": u"Bakwé",
"bjv": u"Bedjond",
"bju": u"Busuu",
"bjt": u"Balanta-Ganja",
"bjs": u"Bajan",
"bjr": u"Binumarien",
"bjz": u"Baruga",
"bjy": u"Bayali",
"her": u"Herero",
"ptp": u"Patep",
"hed": u"Herdé",
"heg": u"Helong",
"heb": u"Hebrew",
"hem": u"Hemba",
"xzh": u"Zhang-Zhung",
"wam": u"Wampanoag",
"heh": u"Hehe",
"hei": u"Heiltsuk",
"tbr": u"Tumtum",
"wal": u"Wolaytta",
"xbx": u"Kabixí",
"xbw": u"Kambiwá",
"uig": u"Uighur",
"svb": u"Ulau-Suain",
"scq": u"Sa'och",
"uis": u"Uisai",
"waj": u"Waffa",
"uiv": u"Iyive",
"sva": u"Svan",
"wew": u"Wejewa",
"wga": u"Wagaya",
"tbu": u"Tubar",
"cpn": u"Cherepon",
"xbc": u"Bactrian",
"cps": u"Capiznon",
"mnx": u"Manikion",
"mny": u"Manyawa",
"mnz": u"Moni",
"scn": u"Sicilian",
"sck": u"Sadri",
"goa": u"Guro",
"mns": u"Mansi",
"mnt": u"Maykulan",
"mnu": u"Mer",
"mnv": u"Rennell-Bellona",
"mnw": u"Mon",
"mni": u"Manipuri",
"mnj": u"Munji",
"mnk": u"Mandinka",
"mnl": u"Tiale",
"mnm": u"Mapena",
"scu": u"Shumcho",
"mna": u"Mbula",
"mnb": u"Muna",
"gob": u"Playero",
"mnd": u"Mondé",
"mne": u"Naba",
"mnf": u"Mundani",
"zmj": u"Maridjabin",
"smo": u"Samoan",
"zmh": u"Makolkol",
"zmn": u"Mbangwe",
"zml": u"Madngele",
"zmb": u"Zimba",
"zmc": u"Margany",
"zmf": u"Mfinu",
"smm": u"Musasa",
"zmd": u"Maridan",
"zme": u"Mangerr",
"zmz": u"Mbandja",
"zmx": u"Bomitaba",
"zmr": u"Maranunggu",
"zms": u"Mbesa",
"zmp": u"Mpuono",
"zmq": u"Mituku",
"zmv": u"Mbariman-Gudhinma",
"zmt": u"Maringarr",
"zmu": u"Muruwari",
"smh": u"Samei",
"mpz": u"Mpi",
"got": u"Gothic",
"hya": u"Hya",
"pbv": u"Pnar",
"hye": u"Armenian",
"pbr": u"Pangwa",
"wsi": u"Wusi",
"smc": u"Som",
"wsk": u"Waskia",
"pby": u"Pyu",
"pbz": u"Palu",
"pbg": u"Paraujano",
"wsu": u"Wasu",
"pbc": u"Patamona",
"pbb": u"Páez",
"pbo": u"Papel",
"gor": u"Gorontalo",
"pbi": u"Parkwa",
"qvy": u"Queyu",
"mpx": u"Misima-Panaeati",
"aba": u"Abé",
"abb": u"Bankon",
"abd": u"Manide",
"abg": u"Abaga",
"abi": u"Abidji",
"abj": u"Aka-Bea",
"abk": u"Abkhazian",
"abm": u"Abanyom",
"abn": u"Abua",
"abo": u"Abon",
"abq": u"Abaza",
"abr": u"Abron",
"abt": u"Ambulas",
"abu": u"Abure",
"abw": u"Pal",
"abx": u"Inabaknon",
"abz": u"Abui",
"xok": u"Xokleng",
"xoi": u"Kominimung",
"ggu": u"Gagu",
"ggt": u"Gitua",
"ggw": u"Gogodala",
"gge": u"Guragone",
"ggd": u"Gugadj",
"ggg": u"Gurgula",
"gga": u"Gao",
"ggb": u"Gbii",
"ggl": u"Ganglau",
"ggh": u"Garreh-Ajuran",
"ggk": u"Kungarakany",
"fwe": u"Fwe",
"fwa": u"Fwâi",
"pyn": u"Poyanáwa",
"xcy": u"Cayuse",
"nco": u"Sibe",
"vif": u"Vili",
"vig": u"Viemo",
"pin": u"Piame",
"vie": u"Vietnamese",
"yll": u"Yil",
"vin": u"Vinza",
"vil": u"Vilela",
"vis": u"Vishavan",
"mqb": u"Mbuko",
"viv": u"Iduna",
"rgr": u"Resígaro",
"vit": u"Viti",
"yzk": u"Zokhuo",
"sbh": u"Sori-Harengan",
"eya": u"Eyak",
"twc": u"Teshenawa",
"twa": u"Twana",
"twg": u"Tereweng",
"twd": u"Twents",
"twi": u"Twi",
"twn": u"Twendi",
"two": u"Tswapong",
"eyo": u"Keiyo",
"twp": u"Ere",
"twq": u"Tasawaq",
"tww": u"Tuwari",
"twt": u"Turiwára",
"twu": u"Termanu",
"twx": u"Tewe",
"twy": u"Tawoyan",
"xut": u"Kuthant",
"xuu": u"Kxoe",
"scr": u"Croatian",
"prm": u"Kibiri",
"kld": u"Gamilaraay",
"dez": u"Dengese",
"klg": u"Tagakaulo",
"kla": u"Klamath-Modoc",
"klb": u"Kiliwa",
"klc": u"Kolbila",
"der": u"Deori",
"des": u"Desano",
"jda": u"Jad",
"deu": u"German",
"dev": u"Domung",
"deh": u"Dehwari",
"dei": u"Demisa",
"klv": u"Maskelynes",
"dek": u"Dek",
"del": u"Delaware",
"dem": u"Dem",
"jdt": u"Judeo-Tat",
"dec": u"Dagik",
"ded": u"Dedua",
"dee": u"Dewoin",
"def": u"Dezfuli",
"deg": u"Degema",
"ist": u"Istriot",
"csk": u"Jola-Kasa",
"isi": u"Nkem-Nkum",
"csb": u"Kashubian",
"xhc": u"Hunnic",
"ish": u"Esan",
"csz": u"Coos",
"rys": u"Yaeyama",
"bkd": u"Binukid",
"bke": u"Bengkulu",
"bkf": u"Beeke",
"bkg": u"Buraka",
"bka": u"Kyak",
"bkb": u"Finallig",
"bkl": u"Berik",
"bkn": u"Bukitan",
"bko": u"Kwa'",
"bkh": u"Bakoko",
"bki": u"Baki",
"bkj": u"Pande",
"bkk": u"Brokskat",
"bkt": u"Boloki",
"bku": u"Buhid",
"bkv": u"Bekwarra",
"bkw": u"Bekwel",
"bkq": u"Bakairí",
"bkr": u"Bakumpai",
"bkx": u"Baikeno",
"bky": u"Bokyi",
"bkz": u"Bungku",
"kor": u"Korean",
"paw": u"Pawnee",
"wav": u"Waka",
"isd": u"Isnag",
"ito": u"Itonama",
"itl": u"Itelmen",
"itk": u"Judeo-Italian",
"prk": u"Parauk",
"ite": u"Itene",
"ita": u"Italian",
"itz": u"Itzá",
"itx": u"Itik",
"itv": u"Itawit",
"itw": u"Ito",
"itu": u"Itutang",
"itr": u"Iteri",
"its": u"Isekiri",
"wrg": u"Warungu",
"wrd": u"Warduji",
"slk": u"Slovak",
"wrb": u"Warluwara",
"wra": u"Warapu",
"pcr": u"Panang",
"kcy": u"Korandje",
"pcp": u"Pacahuara",
"pcw": u"Pyapun",
"wrh": u"Wiradhuri",
"wri": u"Wariyangga",
"pcj": u"Parenga",
"pch": u"Pardhan",
"pci": u"Duruwa",
"pcn": u"Piti",
"wrs": u"Waris",
"pcl": u"Pardhi",
"pcb": u"Pear",
"pcc": u"Bouyei",
"pcf": u"Paliyan",
"pcg": u"Paniya",
"pcd": u"Picard",
"swn": u"Sawknah",
"oks": u"Oko-Eni-Osayen",
"okr": u"Kirike",
"oku": u"Oku",
"okv": u"Orokaiva",
"uhn": u"Damal",
"oka": u"Okanagan",
"okb": u"Okobo",
"okd": u"Okodia",
"oki": u"Okiek",
"okj": u"Oko-Juwoi",
"okn": u"Oki-No-Erabu",
"tra": u"Tirahi",
"gft": u"Gafat",
"trd": u"Turi",
"gfk": u"Patpatar",
"pot": u"Potawatomi",
"sbs": u"Subiya",
"sbq": u"Sileibi",
"mmy": u"Migaama",
"mmx": u"Madak",
"sbt": u"Kimki",
"mmz": u"Mabaale",
"mmu": u"Mmaala",
"mmt": u"Malalamai",
"mmw": u"Emae",
"mmv": u"Miriti",
"mmq": u"Musak",
"mmp": u"Siawi",
"mmm": u"Maii",
"mmn": u"Mamanwa",
"mmi": u"Musar",
"mmh": u"Mehináku",
"mmk": u"Mukha-Dora",
"mmj": u"Majhwar",
"mme": u"Mae",
"mmd": u"Maonan",
"mmf": u"Mundat",
"mma": u"Mama",
"sbo": u"Sabüm",
"mmb": u"Momina",
"trr": u"Taushiro",
"toq": u"Toposa",
"slc": u"Sáliba",
"tou": u"Tho",
"jer": u"Jere",
"koh": u"Koyo",
"kom": u"Komi",
"jet": u"Manem",
"koa": u"Konomala",
"koc": u"Kpati",
"kob": u"Kohoroxitari",
"koe": u"Kacipo-Balesi",
"kod": u"Kodi",
"kog": u"Cogui",
"kof": u"Kubi",
"jeb": u"Jebero",
"kox": u"Coxima",
"koz": u"Korak",
"jeg": u"Jeng",
"jee": u"Jerung",
"jeh": u"Jeh",
"jei": u"Yei",
"jen": u"Dza",
"kot": u"Lagwan",
"jel": u"Yelmek",
"kov": u"Kudu-Camo",
"zsk": u"Kaskean",
"aad": u"Amal",
"aag": u"Ambrak",
"aaf": u"Aranadan",
"aaa": u"Ghotuo",
"aac": u"Ari",
"aab": u"Alumu-Tesu",
"aam": u"Aramanik",
"aal": u"Afade",
"aan": u"Anambé",
"aai": u"Arifama-Miniafia",
"aak": u"Ankave",
"aau": u"Abau",
"aaw": u"Solong",
"aas": u"Aasáx",
"aar": u"Afar",
"aay": u"Aariya",
"aaz": u"Amarasi",
"bhi": u"Bhilali",
"bhh": u"Bukharic",
"bhj": u"Bahing",
"bhm": u"Bathari",
"bhl": u"Bimin",
"bho": u"Bhojpuri",
"bha": u"Bharia",
"bhc": u"Biga",
"bhb": u"Bhili",
"bhe": u"Bhaya",
"bhd": u"Bhadrawahi",
"bhg": u"Binandere",
"bhf": u"Odiai",
"bhy": u"Bhele",
"bhx": u"Bhalay",
"bhp": u"Bima",
"bhs": u"Buwal",
"bhu": u"Bhunjia",
"bht": u"Bhattiyali",
"bhw": u"Biak",
"bhv": u"Bahau",
"rrt": u"Arritinngithigh",
"hgw": u"Haigwai",
"hgm": u"Hai//om",
"wil": u"Wilawila",
"vnm": u"Vinmavis",
"vnk": u"Vano",
"tlu": u"Tulehu",
"vnp": u"Vunapu",
"tpg": u"Kula",
"tpf": u"Tarpia",
"tpe": u"Tippera",
"tpn": u"Tupinambá",
"tpm": u"Tampulma",
"tpk": u"Tupinikin",
"tpj": u"Tapieté",
"tpw": u"Tupí",
"tpv": u"Tanapag",
"ext": u"Extremaduran",
"tpr": u"Tuparí",
"tpq": u"Tukpa",
"tpz": u"Tinputz",
"tpy": u"Trumai",
"ycp": u"Chepya",
"ugb": u"Kuku-Ugbanh",
"uga": u"Ugaritic",
"sbm": u"Sagala",
"uge": u"Ughele",
"wgg": u"Wangganguru",
"oji": u"Ojibwa",
"yay": u"Agwagwune",
"ych": u"Chesu",
"knr": u"Kaningra",
"ycn": u"Yucuna",
"yax": u"Yauma",
"ycl": u"Lolopo",
"tjn": u"Tonjon",
"kns": u"Kensiu",
"crv": u"Chaura",
"crw": u"Chrau",
"cru": u"Carútana",
"crz": u"Cruzeño",
"crx": u"Carrier",
"cry": u"Cori",
"crc": u"Lonwolwol",
"cra": u"Chara",
"crf": u"Caramanta",
"crg": u"Michif",
"cre": u"Cree",
"cri": u"Sãotomense",
"cro": u"Crow",
"seu": u"Serui-Laut",
"rav": u"Sampang",
"ser": u"Serrano",
"sey": u"Secoya",
"seg": u"Segeju",
"see": u"Seneca",
"sed": u"Sedang",
"sec": u"Sechelt",
"sea": u"Semai",
"seo": u"Suarmin",
"sel": u"Selkup",
"sek": u"Sekani",
"sej": u"Sene",
"sei": u"Seri",
"seh": u"Sena",
"zkn": u"Kanan",
"zko": u"Kott",
"zkh": u"Khorezmian",
"zkk": u"Karankawa",
"zkd": u"Kadu",
"zkg": u"Koguryo",
"wgb": u"Wagawaga",
"zkb": u"Koibal",
"zkz": u"Khazar",
"zku": u"Kaurna",
"zkv": u"Krevinian",
"yat": u"Yambeta",
"zkr": u"Zakhring",
"ikp": u"Ikpeshi",
"ikw": u"Ikwere",
"ikv": u"Iku-Gora-Ankwa",
"iku": u"Inuktitut",
"ikt": u"Inuinnaqtun",
"ikz": u"Ikizu",
"ikx": u"Ik",
"swt": u"Sawila",
"ttr": u"Tera",
"ikk": u"Ika",
"iki": u"Iko",
"iko": u"Olulumo-Ikom",
"ikl": u"Ikulu",
"pdu": u"Kayan",
"pdt": u"Plautdietsch",
"pdo": u"Padoe",
"pdn": u"Podena",
"sww": u"Sowa",
"pda": u"Anam",
"wgo": u"Waigeo",
"rad": u"Rade",
"rae": u"Ranau",
"rab": u"Camling",
"rac": u"Rasawa",
"xap": u"Apalachee",
"xaq": u"Aquitanian",
"xar": u"Karami",
"raa": u"Dungmali",
"xat": u"Katawixi",
"xau": u"Kauwera",
"xav": u"Xavánte",
"xaw": u"Kawaiisu",
"xah": u"Kahayan",
"ran": u"Riantana",
"xal": u"Kalmyk",
"xam": u"/Xam",
"xan": u"Xamtanga",
"rao": u"Rao",
"xab": u"Sambe",
"xac": u"Kachari",
"xad": u"Adai",
"xae": u"Aequian",
"xag": u"Aghwan",
"ram": u"Canela",
"gay": u"Gayo",
"gaw": u"Nobonob",
"gav": u"Gabutamon",
"gat": u"Kenati",
"gar": u"Galeya",
"gaq": u"Gata'",
"gap": u"Gal",
"gao": u"Gants",
"gam": u"Kandawo",
"gal": u"Galoli",
"gak": u"Gamkonora",
"gaj": u"Gadsup",
"gai": u"Borei",
"gah": u"Alekano",
"gag": u"Gagauz",
"gaf": u"Gende",
"gae": u"Guarequena",
"gad": u"Gaddang",
"gab": u"Gabri",
"gaa": u"Ga",
"fut": u"Futuna-Aniwa",
"fuu": u"Furu",
"fur": u"Friulian",
"mlg": u"Malagasy",
"mld": u"Malakhel",
"mlj": u"Miltu",
"mlk": u"Ilwana",
"mlh": u"Mape",
"mli": u"Malimpung",
"mln": u"Malango",
"mlo": u"Mlomp",
"fuy": u"Fuyug",
"fuf": u"Pular",
"mls": u"Masalit",
"fuc": u"Pulaar",
"mlt": u"Maltese",
"mlu": u"To'abaita",
"fun": u"Fulniô",
"rar": u"Rarotongan",
"ful": u"Fulah",
"fum": u"Fum",
"fuj": u"Ko",
"rap": u"Rapanui",
"vol": u"Volapük",
"raq": u"Saam",
"vot": u"Votic",
"vor": u"Voro",
"pwb": u"Panawa",
"psn": u"Panasuan",
"spd": u"Saep",
"ewo": u"Ewondo",
"tqb": u"Tembé",
"tql": u"Lehali",
"raz": u"Rahambuu",
"tqn": u"Tenino",
"psm": u"Pauserna",
"ewe": u"Ewe",
"rat": u"Razajerdi",
"tqu": u"Touo",
"tqw": u"Tonkawa",
"tqp": u"Tomoip",
"rax": u"Rang",
"tqr": u"Torona",
"ray": u"Rapa",
"sya": u"Siang",
"dgg": u"Doga",
"dge": u"Degenan",
"syk": u"Sukur",
"dgk": u"Dagba",
"dgh": u"Dghwede",
"dgn": u"Dagoman",
"dgl": u"Andaandi",
"dgr": u"Dogrib",
"dgs": u"Dogoso",
"sjw": u"Shawnee",
"syw": u"Kagate",
"dgw": u"Daungwurrung",
"dgt": u"Ndrag'ngith",
"dgu": u"Degaru",
"dgz": u"Daga",
"dgx": u"Doghoro",
"jbw": u"Yawijibaya",
"jbt": u"Jabutí",
"jbr": u"Jofotek-Bromnya",
"kni": u"Kanufi",
"knf": u"Mankanya",
"kng": u"Koongo",
"knd": u"Konda",
"kne": u"Kankanaey",
"jbe": u"Judeo-Berber",
"psy": u"Piscataway",
"knz": u"Kalamsé",
"knx": u"Kendayan",
"kny": u"Kanyok",
"jbo": u"Lojban",
"jbn": u"Nafusi",
"jbk": u"Barikewa",
"jbj": u"Arandai",
"knp": u"Kwanja",
"knq": u"Kintaq",
"ldb": u"Dũya",
"ldg": u"Lenyima",
"ldd": u"Luri",
"ldk": u"Leelau",
"ldj": u"Lemoro",
"ldi": u"Laari",
"ldh": u"Lamja-Dengsa-Tola",
"ldo": u"Loo",
"ldn": u"Láadan",
"ldm": u"Landoma",
"ldl": u"Kaan",
"ldq": u"Lufu",
"ldp": u"Tso",
"pss": u"Kaulong",
"wic": u"Wichita",
"wih": u"Wik-Me'anha",
"cuw": u"Chukwa",
"cuv": u"Cuvok",
"cur": u"Chhulung",
"cuq": u"Cun",
"cup": u"Cupeño",
"quv": u"Sacapulteco",
"cug": u"Cung",
"rga": u"Roria",
"cub": u"Cubeo",
"cua": u"Cua",
"win": u"Ho-Chunk",
"cuo": u"Cumanagoto",
"cum": u"Cumeral",
"cul": u"Culina",
"cui": u"Cuiba",
"cuh": u"Chuka",
"bin": u"Bini",
"bio": u"Nai",
"bil": u"Bile",
"bim": u"Bimoba",
"bij": u"Vaghat-Ya-Bijim-Legeri",
"bik": u"Bikol",
"bii": u"Bisu",
"bif": u"Biafada",
"big": u"Biangai",
"bid": u"Bidiyo",
"bie": u"Bepour",
"bib": u"Bissa",
"bic": u"Bikaru",
"bia": u"Badimaya",
"biz": u"Baloi",
"skv": u"Skou",
"bix": u"Bijori",
"biy": u"Birhor",
"bit": u"Berinomo",
"biu": u"Biete",
"bir": u"Bisorio",
"bis": u"Bislama",
"bip": u"Bila",
"biq": u"Bipi",
"wiw": u"Wirangu",
"wiv": u"Vitu",
"wiu": u"Wiru",
"wit": u"Wintu",
"xfa": u"Faliscan",
"wir": u"Wiraféd",
"ijc": u"Izon",
"ije": u"Biseni",
"yad": u"Yagua",
"ijn": u"Kalabari",
"wbf": u"Wara",
"pex": u"Petats",
"pey": u"Petjo",
"pev": u"Pémono",
"pep": u"Kunja",
"per": u"Persian",
"pel": u"Pekal",
"pem": u"Phende",
"pen": u"Penesak",
"peh": u"Bonan",
"pei": u"Chichimeca-Jonaz",
"pek": u"Penchal",
"pee": u"Taje",
"peg": u"Pengo",
"tfr": u"Teribe",
"kbs": u"Kande",
"ziw": u"Zigula",
"goe": u"Gongduk",
"qyp": u"Quiripi",
"zir": u"Ziriya",
"klm": u"Migum",
"sjl": u"Sajalong",
"kbp": u"Kabiyè",
"wbj": u"Alagwa",
"kln": u"Kalenjin",
"sjm": u"Mapun",
"nsh": u"Ngoshie",
"nsk": u"Naskapi",
"nsn": u"Nehan",
"nso": u"Pedi",
"nsc": u"Nshi",
"nse": u"Nsenga",
"nsg": u"Ngasa",
"nsx": u"Nsongo",
"nsy": u"Nasal",
"nsz": u"Nisenan",
"nss": u"Nali",
"nsw": u"Navut",
"mkf": u"Miya",
"mke": u"Mawchi",
"mkd": u"Macedonian",
"mkc": u"Siliput",
"mka": u"Mbre",
"mkm": u"Moklen",
"mkl": u"Mokole",
"mkk": u"Byep",
"mkj": u"Mokilese",
"mki": u"Dhatki",
"mkv": u"Mafea",
"mkt": u"Vamale",
"mkr": u"Malas",
"mkp": u"Moikodi",
"mkz": u"Makasae",
"sdt": u"Shuadit",
"sdu": u"Sarudu",
"sdp": u"Sherdukpen",
"sds": u"Sened",
"usp": u"Uspanteco",
"sdz": u"Sallands",
"sdd": u"Semendo",
"sde": u"Surubu",
"sdf": u"Sarli",
"sdg": u"Savi",
"sda": u"Toraja-Sa'dan",
"sdb": u"Shabak",
"sdm": u"Semandang",
"sdj": u"Suundi",
"cic": u"Chickasaw",
"cia": u"Cia-Cia",
"zim": u"Mesme",
"cie": u"Cineni",
"cid": u"Chimariko",
"cih": u"Chinali",
"cim": u"Cimbrian",
"zha": u"Zhuang",
"cir": u"Tiri",
"cip": u"Chiapanec",
"ciw": u"Chippewa",
"cit": u"Chittagonian",
"quc": u"K'iche'",
"ciy": u"Chaima",
"zho": u"Chinese",
"sxb": u"Suba",
"sxc": u"Sicanian",
"sxe": u"Sighu",
"sxg": u"Shixing",
"sxl": u"Selian",
"sxm": u"Samre",
"sxn": u"Sangir",
"sxo": u"Sorothaptic",
"sxr": u"Saaroa",
"lyg": u"Lyngngam",
"lya": u"Layakha",
"lyn": u"Luyana",
"xte": u"Ketengban",
"jct": u"Krymchak",
"kqr": u"Kimaragang",
"kqq": u"Krenak",
"kqp": u"Kimré",
"kqw": u"Kandas",
"kqv": u"Okolod",
"kqu": u"Seroa",
"kqz": u"Korana",
"kqy": u"Koorete",
"kqx": u"Mser",
"kqc": u"Doromu-Koki",
"kqb": u"Kovai",
"kqa": u"Mum",
"sjg": u"Assangori",
"kqg": u"Khe",
"kqf": u"Kakabai",
"kqe": u"Kalagan",
"kqj": u"Koromira",
"kqi": u"Koitabu",
"kqh": u"Kisankasa",
"kqn": u"Kaonde",
"kqm": u"Khisa",
"kql": u"Kyenele",
"kir": u"Kirghiz",
"ukq": u"Ukwa",
"ttu": u"Torau",
"lpe": u"Lepki",
"ago": u"Tainae",
"agn": u"Agutaynen",
"agm": u"Angaataha",
"agl": u"Fembe",
"agj": u"Argobba",
"agi": u"Agariya",
"agh": u"Ngelima",
"agg": u"Angor",
"agf": u"Arguni",
"age": u"Angal",
"agd": u"Agarabi",
"agc": u"Agatu",
"agb": u"Legbo",
"aga": u"Aguano",
"xbr": u"Kambera",
"kmo": u"Kwoma",
"xbo": u"Bolgarian",
"xbn": u"Kenaboi",
"xbi": u"Kombio",
"agx": u"Aghul",
"agw": u"Kahua",
"agu": u"Aguacateco",
"ags": u"Esimbi",
"agr": u"Aguaruna",
"agq": u"Aghem",
"agp": u"Paranan",
"bvr": u"Burarra",
"bvq": u"Birri",
"bvw": u"Boga",
"bvv": u"Baniva",
"bvz": u"Bauzi",
"bvy": u"Baybayanon",
"bvx": u"Dibole",
"bvc": u"Baelelea",
"bvb": u"Bube",
"bva": u"Barein",
"bvg": u"Bonkeng",
"bvf": u"Boor",
"bvd": u"Baeggu",
"bvk": u"Bukat",
"bvj": u"Baan",
"bvh": u"Bure",
"bvo": u"Bolgo",
"bvn": u"Buna",
"bvm": u"Bamunka",
"qui": u"Quileute",
"kmu": u"Kanite",
"tdi": u"Tomadino",
"kms": u"Kamasau",
"suv": u"Puroik",
"tdh": u"Thulung",
"pun": u"Pubian",
"vlp": u"Valpei",
"vls": u"Vlaams",
"vlr": u"Vatrata",
"lpo": u"Lipo",
"evh": u"Uvbie",
"trh": u"Turaka",
"trj": u"Toram",
"trm": u"Tregami",
"evn": u"Evenki",
"trn": u"Trinitario",
"trb": u"Terebu",
"eve": u"Even",
"try": u"Turung",
"trz": u"Torá",
"tdo": u"Teme",
"kmy": u"Koma",
"puo": u"Puoc",
"kmx": u"Waboda",
"tru": u"Turoyo",
"trt": u"Tunggare",
"trw": u"Torwali",
"trv": u"Taroko",
"tdk": u"Tambas",
"xsm": u"Kasem",
"tdj": u"Tajio",
"odu": u"Odual",
"odk": u"Od",
"oda": u"Odut",
"ues": u"Kioko",
"tdn": u"Tondano",
"tdl": u"Sur",
"pui": u"Puinave",
"slo": u"Slovak",
"pma": u"Paama",
"lea": u"Lega-Shabunda",
"leb": u"Lala-Bisa",
"lec": u"Leco",
"led": u"Lendu",
"lee": u"Lyélé",
"lef": u"Lelemi",
"leg": u"Lengua",
"leh": u"Lenje",
"lei": u"Lemio",
"lej": u"Lengola",
"lek": u"Leipon",
"lem": u"Nomaande",
"len": u"Lenca",
"lep": u"Lepcha",
"leq": u"Lembena",
"ler": u"Lenkau",
"les": u"Lese",
"let": u"Lesing-Gelimi",
"lev": u"Lamma",
"lex": u"Luang",
"ley": u"Lemolang",
"lez": u"Lezghian",
"ctu": u"Chol",
"tdy": u"Tadyawan",
"ctg": u"Chittagonian",
"ctc": u"Chetco",
"ctm": u"Chitimacha",
"ctn": u"Chhintange",
"cto": u"Emberá-Catío",
"sgy": u"Sanglechi",
"sgz": u"Sursurunga",
"haa": u"Han",
"sgp": u"Singpho",
"sgr": u"Sangisari",
"sgu": u"Salas",
"sgt": u"Brokpake",
"sgi": u"Suga",
"sgh": u"Shughni",
"sgk": u"Sangkong",
"sgj": u"Surgujia",
"sgm": u"Singa",
"sgl": u"Sanglechi-Ishkashimi",
"sgo": u"Songa",
"sgc": u"Kipsigis",
"sge": u"Segai",
"sgd": u"Surigaonon",
"cha": u"Chamorro",
"chb": u"Chibcha",
"chc": u"Catawba",
"che": u"Chechen",
"chg": u"Chagatai",
"chh": u"Chinook",
"chi": u"Chinese",
"chk": u"Chuukese",
"chl": u"Cahuilla",
"cho": u"Choctaw",
"chp": u"Chipewyan",
"chr": u"Cherokee",
"chs": u"Chumash",
"cht": u"Cholón",
"chv": u"Chuvash",
"chw": u"Chuwabu",
"chx": u"Chantyal",
"chy": u"Cheyenne",
"zik": u"Zimakani",
"pfa": u"Pááfang",
"srb": u"Sora",
"pfe": u"Peere",
"pfl": u"Pfaelzisch",
"xcm": u"Comecrudo",
"srg": u"Sulod",
"stk": u"Arammba",
"srd": u"Sardinian",
"pug": u"Phuie",
"sre": u"Sara",
"xcw": u"Coahuilteco",
"xcb": u"Cumbric",
"xcc": u"Camunic",
"xnz": u"Kenzi",
"ttj": u"Tooro",
"wed": u"Wedau",
"xch": u"Chemakum",
"xcn": u"Cotoname",
"xco": u"Chorasmian",
"xcr": u"Carian",
"xcv": u"Chuvantsy",
"srl": u"Isirawa",
"xcu": u"Curonian",
"srm": u"Saramaccan",
"afn": u"Defaka",
"afo": u"Eloyi",
"afh": u"Afrihili",
"afi": u"Akrukay",
"rdb": u"Rudbari",
"afk": u"Nanubae",
"afd": u"Andai",
"afe": u"Putukwam",
"gcn": u"Gaina",
"afz": u"Obokuitai",
"aft": u"Afitti",
"afu": u"Awutu",
"afp": u"Tapei",
"afr": u"Afrikaans",
"npn": u"Mondropolon",
"sir": u"Siri",
"gcc": u"Mali",
"npb": u"Nupbikha",
"npy": u"Napu",
"xnh": u"Kuanhua",
"gce": u"Galice",
"szk": u"Sizaki",
"nps": u"Nipsan",
"gcd": u"Ganggalida",
"mje": u"Muskum",
"mjg": u"Tu",
"mja": u"Mahei",
"mjl": u"Mandeali",
"mjm": u"Medebur",
"mjj": u"Mawak",
"mjk": u"Matukar",
"mju": u"Manna-Dora",
"mjv": u"Mannan",
"mjw": u"Karbi",
"mjp": u"Malapandaram",
"mjq": u"Malaryan",
"mjr": u"Malavedan",
"mjs": u"Miship",
"mjx": u"Mahali",
"mjy": u"Mahican",
"mjz": u"Majhi",
"vmo": u"Muko-Muko",
"vml": u"Malgana",
"vmk": u"Makhuwa-Shirima",
"vmh": u"Maraghei",
"vmf": u"Mainfränkisch",
"vmg": u"Minigir",
"vmb": u"Mbabaram",
"vmu": u"Muluridyi",
"vmr": u"Marenje",
"vms": u"Moksela",
"tsn": u"Tswana",
"tso": u"Tsonga",
"tsl": u"Ts'ün-Lao",
"tsj": u"Tshangla",
"tsh": u"Tsuvan",
"tsi": u"Tsimshian",
"tsg": u"Tausug",
"tsd": u"Tsakonian",
"tsb": u"Tsamai",
"tsc": u"Tswa",
"tsa": u"Tsaangi",
"tsz": u"Purepecha",
"tsv": u"Tsogo",
"tsw": u"Tsishingini",
"tsu": u"Tsou",
"eus": u"Basque",
"eur": u"Europanto",
"dad": u"Marik",
"dae": u"Duupa",
"daf": u"Dan",
"dag": u"Dagbani",
"daa": u"Dangaléat",
"dac": u"Dambi",
"dal": u"Dahalo",
"dam": u"Damakawa",
"dan": u"Danish",
"dah": u"Gwahatike",
"dai": u"Day",
"dak": u"Dakota",
"dav": u"Taita",
"daw": u"Davawenyo",
"dar": u"Dargwa",
"das": u"Daho-Doo",
"dax": u"Dayi",
"daz": u"Dao",
"kpq": u"Korupun-Sela",
"kpr": u"Korafe-Yegha",
"kps": u"Tehit",
"kpt": u"Karata",
"kpu": u"Kafoa",
"kpv": u"Komi-Zyrian",
"kpw": u"Kobon",
"kpy": u"Koryak",
"kpz": u"Kupsabiny",
"kpa": u"Kutto",
"kpc": u"Curripaco",
"kpd": u"Koba",
"kpe": u"Kpelle",
"kpf": u"Komba",
"kpg": u"Kapingamarangi",
"kph": u"Kplang",
"kpi": u"Kofei",
"kpj": u"Karajá",
"kpk": u"Kpan",
"kpl": u"Kpala",
"kpm": u"Koho",
"kpn": u"Kepkiriwát",
"kpo": u"Ikposo",
"lfa": u"Lefa",
"rey": u"Reyesano",
"res": u"Reshe",
"cwt": u"Kuwaataay",
"ret": u"Retta",
"rei": u"Reli",
"ren": u"Rengao",
"wer": u"Weri",
"rel": u"Rendille",
"rem": u"Remo",
"cwa": u"Kabwa",
"cwb": u"Maindo",
"cwe": u"Kwere",
"cwg": u"Chewong",
"bwr": u"Bura-Pabir",
"bws": u"Bomboma",
"bwt": u"Bafaw-Balong",
"bww": u"Bwa",
"bwz": u"Bwisi",
"tds": u"Doutai",
"qua": u"Quapaw",
"bwa": u"Bwatoo",
"bwb": u"Namosi-Naitasiri-Serua",
"bwc": u"Bwile",
"bwd": u"Bwaidoka",
"bwf": u"Boselewa",
"bwg": u"Barwe",
"bwh": u"Bishuo",
"bwi": u"Baniwa",
"bwk": u"Bauwaki",
"bwl": u"Bwela",
"bwm": u"Biwat",
"tdr": u"Todrah",
"wep": u"Westphalien",
"pgg": u"Pangwali",
"pgn": u"Paelignian",
"ihp": u"Iha",
"ihw": u"Bidhawal",
"pgi": u"Pagi",
"ihi": u"Ihievbe",
"pgs": u"Pangseng",
"pgy": u"Pongyong",
"ush": u"Ushojo",
"nuw": u"Nguluwan",
"hat": u"Haitian",
"shb": u"Ninam",
"udu": u"Uduk",
"ogu": u"Ogbronuagum",
"ogo": u"Khana",
"ogn": u"Ogan",
"ude": u"Udihe",
"ogg": u"Ogbogolo",
"udi": u"Udi",
"hau": u"Hausa",
"ogc": u"Ogbah",
"ogb": u"Ogbia",
"tdv": u"Toro",
"hav": u"Havu",
"mjo": u"Malankuravan",
"tom": u"Tombulu",
"pip": u"Pero",
"haw": u"Hawaiian",
"nqn": u"Nen",
"nqo": u"N'Ko",
"nqm": u"Ndom",
"mik": u"Mikasuki",
"mij": u"Abar",
"min": u"Minangkabau",
"mia": u"Miami",
"mic": u"Mi'kmaq",
"mid": u"Mandaic",
"mif": u"Mofu-Gudur",
"miq": u"Mískito",
"miw": u"Akoye",
"miv": u"Mimi",
"xor": u"Korubo",
"sfw": u"Sehwi",
"ttn": u"Towei",
"ckl": u"Cibak",
"cko": u"Anufo",
"ckh": u"Chak",
"cku": u"Koasati",
"ckt": u"Chukot",
"ckv": u"Kavalan",
"ckq": u"Kajakse",
"cks": u"Tayo",
"ckr": u"Kairak",
"cky": u"Cakfem-Mushere",
"ckx": u"Caka",
"dbi": u"Doka",
"kbj": u"Kari",
"dbj": u"Ida'an",
"dbm": u"Duguri",
"dbl": u"Dyirbal",
"dbo": u"Dulbu",
"dbn": u"Duriankere",
"dbb": u"Deno",
"dbe": u"Dabe",
"dbd": u"Dadiya",
"dbf": u"Edopi",
"dby": u"Dibiyaso",
"shi": u"Tachelhit",
"dbq": u"Daba",
"dbp": u"Duwai",
"szp": u"Suabo",
"dbr": u"Dabarre",
"dbv": u"Dungu",
"ksu": u"Khamyang",
"kst": u"Winyé",
"ksv": u"Kusu",
"jaz": u"Jawe",
"ksp": u"Kaba",
"jay": u"Yan-nhangu",
"jav": u"Javanese",
"jat": u"Jakati",
"jau": u"Yaur",
"jap": u"Jaruára",
"jaq": u"Yaqay",
"jan": u"Jandai",
"jao": u"Yanyuwa",
"jal": u"Yalahatan",
"jaj": u"Zazao",
"jak": u"Jakun",
"jaf": u"Jara",
"ksl": u"Kumalu",
"jad": u"Jahanka",
"jae": u"Yabem",
"jab": u"Hyam",
"jac": u"Popti'",
"ksk": u"Kansa",
"jaa": u"Jamamadí",
"xdc": u"Dacian",
"xvo": u"Volscian",
"xdm": u"Edomite",
"xvn": u"Vandalic",
"vma": u"Martuyhunira",
"aeq": u"Aer",
"gbg": u"Gbanziri",
"aes": u"Alsea",
"aeu": u"Akeu",
"gbc": u"Garawa",
"aew": u"Ambakich",
"aey": u"Amele",
"aex": u"Amerax",
"gbl": u"Gamit",
"aez": u"Aeka",
"gbk": u"Gaddi",
"gbi": u"Galela",
"aea": u"Areba",
"gbp": u"Gbaya-Bossangoa",
"gbq": u"Gbaya-Bozoum",
"aek": u"Haeke",
"aem": u"Arem",
"ael": u"Ambele",
"btu": u"Batu",
"btt": u"Bete-Bendi",
"btw": u"Butuanon",
"btv": u"Bateri",
"btq": u"Batek",
"btp": u"Budibud",
"btr": u"Baetora",
"bty": u"Bobot",
"bte": u"Gamo-Ningi",
"btf": u"Birgit",
"bta": u"Bata",
"btl": u"Bhatola",
"btn": u"Ratagnon",
"bti": u"Burate",
"wmt": u"Walmajarri",
"kbu": u"Kabutra",
"vrs": u"Varisi",
"vrt": u"Burmbar",
"szl": u"Silesian",
"vra": u"Vera'a",
"vro": u"Võro",
"tsk": u"Tseku",
"etr": u"Edolo",
"ets": u"Yekhee",
"loa": u"Loloda",
"ett": u"Etruscan",
"etu": u"Ejagham",
"etz": u"Semimi",
"tlz": u"Toala'",
"etx": u"Eten",
"etb": u"Etebi",
"etc": u"Etchemin",
"zbt": u"Batui",
"tlg": u"Tofanma",
"tlf": u"Telefol",
"tlk": u"Taloki",
"tlj": u"Talinga-Bwisi",
"tlh": u"Klingon",
"tlm": u"Tolomako",
"tll": u"Tetela",
"wtf": u"Watiwa",
"wtk": u"Watakataui",
"lgk": u"Lingarak",
"lgh": u"Laghuu",
"lgi": u"Lengilu",
"lgn": u"Opuuo",
"lgl": u"Wala",
"ilg": u"Garig-Ilgar",
"lgb": u"Laghu",
"xog": u"Soga",
"wif": u"Wik-Keyangan",
"lga": u"Lungga",
"lgg": u"Lugbara",
"lgz": u"Ligenza",
"ile": u"Interlingue",
"lgr": u"Lengo",
"ilb": u"Ila",
"lgq": u"Logba",
"lgt": u"Pahi",
"lgu": u"Longgu",
"qwt": u"Kwalhioqua-Tlatskanai",
"ysn": u"Sani",
"xod": u"Kokoda",
"ysc": u"Yassic",
"ysg": u"Sonaga",
"ysy": u"Sanie",
"ilo": u"Iloko",
"yss": u"Yessan-Mayo",
"cvg": u"Chug",
"lzz": u"Laz",
"cjk": u"Chokwe",
"cji": u"Chamalal",
"cjn": u"Chenapian",
"zgr": u"Magori",
"cje": u"Chru",
"cjr": u"Chorotega",
"cjs": u"Shor",
"cjp": u"Cabécar",
"cjv": u"Chuave",
"phk": u"Phake",
"phh": u"Phukha",
"pho": u"Phunoi",
"phn": u"Phoenician",
"phm": u"Phimbi",
"phl": u"Phalura",
"iow": u"Iowa-Oto",
"iou": u"Tuma-Irumu",
"phg": u"Phuong",
"ior": u"Inor",
"phd": u"Phudagi",
"phr": u"Pahari-Potwari",
"phq": u"Phana'",
"phw": u"Phangduwali",
"phv": u"Pahlavani",
"phu": u"Phuan",
"wyr": u"Wayoró",
"ofo": u"Ofo",
"tsr": u"Akei",
"wyb": u"Wangaaybuwan-Ngiyambaa",
"szb": u"Ngalum",
"ofu": u"Efutop",
"wym": u"Wymysorys",
"lzl": u"Litzlitz",
"xed": u"Hdi",
"xeg": u"//Xegwi",
"xeb": u"Eblan",
"xel": u"Kelo",
"xem": u"Kembayan",
"xet": u"Xetá",
"xeu": u"Keoru-Ahia",
"kwb": u"Kwa",
"xep": u"Epi-Olmec",
"xer": u"Xerénte",
"xes": u"Kesawai",
"adw": u"Amundava",
"adt": u"Adnyamathanha",
"adu": u"Aduge",
"adr": u"Adonara",
"adp": u"Adap",
"adq": u"Adangbe",
"gmb": u"Gula'alaa",
"gma": u"Gambera",
"weh": u"Weh",
"adz": u"Adzera",
"ady": u"Adyghe",
"adg": u"Andegerebinha",
"add": u"Dzodinka",
"ade": u"Adele",
"adb": u"Adabe",
"ada": u"Adangme",
"adn": u"Adang",
"ado": u"Abu",
"adl": u"Galo",
"adj": u"Adioukrou",
"gmv": u"Gamo",
"adh": u"Adhola",
"adi": u"Adi",
"yox": u"Yoron",
"nvo": u"Nyokon",
"nvm": u"Namiae",
"kwn": u"Kwangali",
"nvh": u"Nasarian",
"mhn": u"Mócheno",
"mhl": u"Mauwake",
"mhm": u"Makhuwa-Moniga",
"mhj": u"Mogholi",
"mhk": u"Mungaka",
"mhi": u"Ma'di",
"mhf": u"Mamaa",
"mhg": u"Margu",
"mhd": u"Mbugu",
"mhe": u"Besisi",
"mhb": u"Mahongwe",
"mhc": u"Mocho",
"mhx": u"Maru",
"mhy": u"Ma'anyan",
"mhv": u"Arakanese",
"mhw": u"Mbukushu",
"mht": u"Mandahuaca",
"mhu": u"Digaro-Mishmi",
"kwt": u"Kwesten",
"nja": u"Nzanyi",
"njj": u"Njen",
"nji": u"Gudanji",
"njl": u"Njalgulgule",
"njs": u"Nisa",
"njr": u"Njerep",
"nju": u"Ngadjunmaya",
"njz": u"Nyishi",
"njy": u"Njyem",
"njx": u"Kunyi",
"tmq": u"Tumleo",
"est": u"Estonian",
"tmu": u"Iau",
"esq": u"Esselen",
"tmw": u"Temuan",
"tmx": u"Tomyang",
"tmy": u"Tami",
"tmz": u"Tamanaku",
"tmc": u"Tumak",
"tmd": u"Haruai",
"iso": u"Isoko",
"tmf": u"Toba-Maskoy",
"tmg": u"Ternateño",
"esm": u"Esuma",
"esh": u"Eshtehardi",
"nrn": u"Norn",
"dcc": u"Deccan",
"isn": u"Isanzu",
"ykt": u"Kathu",
"dcr": u"Negerhollands",
"krx": u"Karon",
"kry": u"Kryts",
"krp": u"Korop",
"krq": u"Krui",
"krv": u"Kavet",
"kru": u"Kurukh",
"krj": u"Kinaray-A",
"ism": u"Masimasi",
"krh": u"Kurama",
"kri": u"Krio",
"krn": u"Sapo",
"krl": u"Karelian",
"krm": u"Krim",
"krb": u"Karkin",
"krc": u"Karachay-Balkar",
"kra": u"Kumhali",
"krd": u"Kairui-Midiki",
"kre": u"Panará",
"isl": u"Icelandic",
"yri": u"Yarí",
"yrk": u"Nenets",
"yrl": u"Nhengatu",
"yrn": u"Yerong",
"yra": u"Yerakai",
"yrb": u"Yareba",
"yre": u"Yaouré",
"yrs": u"Yarsun",
"oua": u"Tagargrent",
"yrw": u"Yarawata",
"buz": u"Bukwen",
"bux": u"Boghom",
"bur": u"Burmese",
"bus": u"Bokobaru",
"bup": u"Busoa",
"buq": u"Brem",
"buv": u"Bun",
"buw": u"Bubi",
"but": u"Bungain",
"buu": u"Budu",
"buj": u"Basa-Gurmana",
"buk": u"Bugawac",
"bui": u"Bongili",
"bun": u"Sherbro",
"buo": u"Terei",
"bul": u"Bulgarian",
"bub": u"Bua",
"buc": u"Bushi",
"bua": u"Buriat",
"buf": u"Bushoong",
"bug": u"Buginese",
"bud": u"Ntcham",
"bue": u"Beothuk",
"ssx": u"Samberigi",
"pih": u"Pitcairn-Norfolk",
"pii": u"Pini",
"pij": u"Pijao",
"xas": u"Kamas",
"pil": u"Yom",
"pim": u"Powhatan",
"inz": u"Ineseño",
"pio": u"Piapoco",
"int": u"Intha",
"pib": u"Yine",
"pic": u"Pinji",
"inp": u"Iñapari",
"pie": u"Piro",
"pif": u"Pingelapese",
"inm": u"Minaean",
"inn": u"Isinai",
"ino": u"Inoke-Yate",
"inh": u"Ingush",
"ind": u"Indonesian",
"pir": u"Piratapuyo",
"ing": u"Degexit'an",
"inb": u"Inga",
"oac": u"Oroch",
"oaa": u"Orok",
"mch": u"Maquiritari",
"hpo": u"Hpon",
"ssz": u"Sengseng",
"ubu": u"Umbu-Ungu",
"ubr": u"Ubir",
"uby": u"Ubykh",
"mcb": u"Machiguenga",
"uba": u"Ubang",
"tmb": u"Katbol",
"ubi": u"Ubi",
"sst": u"Sinasina",
"pto": u"Zo'é",
"tcq": u"Kaiy",
"nwr": u"Nawaru",
"ptn": u"Patani",
"nwy": u"Nottoway-Meherrin",
"nwe": u"Ngwe",
"nwg": u"Ngayawung",
"ssw": u"Swati",
"nwa": u"Nawathinehena",
"nwb": u"Nyabwa",
"nwm": u"Nyamusa-Molo",
"nwo": u"Nauo",
"sch": u"Sakachep",
"mws": u"Mwimbi-Muthambi",
"mwr": u"Marwari",
"mwv": u"Mentawai",
"mwu": u"Mittu",
"mwt": u"Moken",
"mwz": u"Moingi",
"mwy": u"Mosiro",
"mwx": u"Mediak",
"xce": u"Celtiberian",
"nrz": u"Lala",
"mvw": u"Machinga",
"mwc": u"Are",
"mwb": u"Juwal",
"mwa": u"Mwatebu",
"mwg": u"Aiklep",
"mwf": u"Murrinh-Patha",
"mnq": u"Minriq",
"mwj": u"Maligo",
"mwi": u"Labo",
"mwh": u"Mouk-Aria",
"mwn": u"Nyamwanga",
"mwm": u"Sar",
"mwl": u"Mirandese",
"uok": u"Uokha",
"sca": u"Sansu",
"tzj": u"Tz'utujil",
"ssq": u"So'a",
"reb": u"Rembong",
"scc": u"Serbian",
"scb": u"Chut",
"cmm": u"Michigamea",
"cml": u"Campalagian",
"cmk": u"Chimakum",
"cmi": u"Emberá-Chamí",
"cme": u"Cerma",
"gnu": u"Gnau",
"cma": u"Maa",
"cmt": u"Camtho",
"cms": u"Messapic",
"scx": u"Sicel",
"quq": u"Quinqui",
"pty": u"Pathiya",
"wig": u"Wik-Ngathana",
"tmh": u"Tamashek",
"sss": u"Sô",
"slq": u"Salchuq",
"ptw": u"Pentlatch",
"ptu": u"Bambam",
"gnb": u"Gangte",
"mnc": u"Manchu",
"kuz": u"Kunza",
"kuy": u"Kuuku-Ya'u",
"gnc": u"Guanche",
"kuw": u"Kpagua",
"kuv": u"Kur",
"kut": u"Kutenai",
"kus": u"Kusaal",
"kur": u"Kurdish",
"kuq": u"Karipuna",
"kup": u"Kunimaipa",
"kuo": u"Kumukio",
"kun": u"Kunama",
"kum": u"Kumyk",
"gna": u"Kaansa",
"kuk": u"Kepo'",
"kuj": u"Kuria",
"kui": u"Kuikúro-Kalapálo",
"kuh": u"Kushi",
"kug": u"Kupa",
"kue": u"Kuman",
"kud": u"'Auhelawa",
"kuc": u"Kwinsu",
"kub": u"Kutep",
"kua": u"Kuanyama",
"gng": u"Ngangam",
"gnd": u"Zulgo-Gemzek",
"tmj": u"Samarokena",
"ssm": u"Semnam",
"gne": u"Ganang",
"yml": u"Iamalele",
"wmx": u"Womo",
"gnk": u"//Gana",
"tmi": u"Tutuba",
"wiy": u"Wiyot",
"gnh": u"Lere",
"zmo": u"Molo",
"akz": u"Alabama",
"aky": u"Aka-Kol",
"akx": u"Aka-Kede",
"wdd": u"Wandji",
"glo": u"Galambu",
"aks": u"Akaselem",
"akr": u"Araki",
"akq": u"Ak",
"akp": u"Siwu",
"akw": u"Akwa",
"akv": u"Akhvakh",
"aku": u"Akum",
"akt": u"Akolet",
"akk": u"Akkadian",
"akj": u"Aka-Jeru",
"aki": u"Aiome",
"ako": u"Akurio",
"akn": u"Amikoana",
"akm": u"Aka-Bo",
"akl": u"Aklanon",
"akc": u"Mpur",
"aka": u"Akan",
"gnm": u"Ginuman",
"akg": u"Anakalangu",
"akf": u"Akpa",
"ake": u"Akawaio",
"akd": u"Ukpet-Ehom",
"sso": u"Sissano",
"brz": u"Bilbil",
"bry": u"Burui",
"brw": u"Bellari",
"brt": u"Bitare",
"brs": u"Baras",
"brr": u"Birao",
"brq": u"Breri",
"brp": u"Barapasi",
"bro": u"Brokkat",
"brn": u"Boruca",
"brm": u"Barambu",
"brl": u"Birwa",
"brk": u"Birked",
"brj": u"Bieria",
"bri": u"Mokpwe",
"brh": u"Brahui",
"brg": u"Baure",
"brf": u"Bera",
"bre": u"Breton",
"brd": u"Baraamu",
"brb": u"Lave",
"bra": u"Braj",
"qum": u"Sipacapense",
"mlz": u"Malaynon",
"zmy": u"Mariyedi",
"tzx": u"Tabriak",
"qun": u"Quinault",
"nka": u"Nkoya",
"nkc": u"Nkongho",
"nkd": u"Koireng",
"nke": u"Duke",
"nkg": u"Nekgini",
"nkj": u"Nakai",
"nkk": u"Nokuku",
"nkm": u"Namat",
"nkn": u"Nkangala",
"nko": u"Nkonya",
"nkp": u"Niuatoputapu",
"nkq": u"Nkami",
"nkr": u"Nukuoro",
"nkw": u"Nkutu",
"nkx": u"Nkoroo",
"nkz": u"Nkari",
"tmo": u"Temoq",
"szn": u"Sula",
"ert": u"Eritai",
"tnt": u"Tontemboan",
"tnw": u"Tonsawang",
"erw": u"Erokwanas",
"tnq": u"Taino",
"tnp": u"Whitesands",
"err": u"Erre",
"ers": u"Ersu",
"xvs": u"Vestinian",
"pid": u"Piaroa",
"tny": u"Tongwe",
"tnx": u"Tanema",
"tng": u"Tobanga",
"erg": u"Sie",
"tna": u"Tacana",
"era": u"Eravallan",
"tnc": u"Tanimuca-Retuarã",
"tnm": u"Tabla",
"tnl": u"Lenakel",
"tno": u"Toromono",
"ero": u"Horpa",
"erh": u"Eruwa",
"eri": u"Ogea",
"tnk": u"Kwamera",
"sle": u"Sholaga",
"uar": u"Tairuma",
"mpd": u"Machinere",
"mpe": u"Majang",
"uam": u"Uamué",
"ssj": u"Sausi",
"mpo": u"Miu",
"ena": u"Apali",
"enb": u"Markweeta",
"enc": u"En",
"end": u"Ende",
"eng": u"English",
"eni": u"Enim",
"zeg": u"Zenag",
"enn": u"Engenni",
"eno": u"Enggano",
"enq": u"Enga",
"enr": u"Emumu",
"nru": u"Narua",
"enu": u"Enu",
"sse": u"Balangingi",
"ttd": u"Tauade",
"lal": u"Lalia",
"lam": u"Lamba",
"lan": u"Laru",
"lao": u"Lao",
"lah": u"Lahnda",
"lai": u"Lambya",
"lad": u"Ladino",
"lae": u"Pattani",
"laf": u"Lafofa",
"lag": u"Langi",
"lac": u"Lacandon",
"lax": u"Tiwa",
"iby": u"Ibani",
"lat": u"Latin",
"lau": u"Laba",
"lav": u"Latvian",
"law": u"Lauje",
"laq": u"Qabiao",
"lar": u"Larteh",
"mpv": u"Mungkip",
"mpw": u"Mapidian",
"mpt": u"Mian",
"mpu": u"Makuráp",
"wfg": u"Yafi",
"mpr": u"Vangunu",
"kmn": u"Awtuw",
"mps": u"Dadibi",
"zea": u"Zeeuws",
"mpp": u"Migabac",
"mpq": u"Matís",
"zen": u"Zenaga",
"ssf": u"Thao",
"cll": u"Chala",
"clm": u"Clallam",
"clh": u"Chilisso",
"cli": u"Chakali",
"clk": u"Idu-Mishmi",
"cla": u"Ron",
"imo": u"Imbongu",
"clc": u"Chilcotin",
"ims": u"Marsian",
"imr": u"Imroing",
"clu": u"Caluyanun",
"clw": u"Chulym",
"wsa": u"Warembori",
"pgk": u"Rerep",
"wba": u"Warao",
"pjt": u"Pitjantjatjara",
"pbp": u"Badyara",
"yau": u"Yuwana",
"ssc": u"Suba-Simbiti",
"pgu": u"Pagu",
"ysd": u"Samatao",
"xgl": u"Galindan",
"xgf": u"Gabrielino-Fernandeño",
"por": u"Portuguese",
"xgb": u"Gbin",
"xga": u"Galatian",
"xgu": u"Unggumi",
"xgr": u"Garza",
"gol": u"Gola",
"gon": u"Gondi",
"goi": u"Gobasi",
"gok": u"Gowli",
"goj": u"Gowlan",
"god": u"Godié",
"gog": u"Gogo",
"gof": u"Gofa",
"goc": u"Gorakor",
"ajw": u"Ajawa",
"wgu": u"Wirangu",
"aji": u"Ajië",
"wgw": u"Wagawaga",
"wsr": u"Owenia",
"goy": u"Goundo",
"gox": u"Gobu",
"ajn": u"Andajin",
"goz": u"Gozarkhani",
"gou": u"Gavar",
"gow": u"Gorowa",
"yok": u"Yokuts",
"goq": u"Gorap",
"gop": u"Yeretuar",
"gos": u"Gronings",
"nty": u"Mantsi",
"ntz": u"Natanzi",
"nts": u"Natagaimas",
"ntr": u"Delo",
"ntu": u"Natügu",
"ntw": u"Nottoway",
"nti": u"Natioro",
"ntk": u"Ikoma-Nata-Isenye",
"ntj": u"Ngaanyatjarra",
"ntm": u"Nateni",
"nto": u"Ntomba",
"tpa": u"Taupota",
"nte": u"Nathembo",
"mvp": u"Duri",
"mvq": u"Moere",
"mvr": u"Marau",
"mvs": u"Massep",
"mvt": u"Mpotovoro",
"mvu": u"Marfa",
"kij": u"Kilivila",
"mvx": u"Meoswar",
"mvz": u"Mesqan",
"mva": u"Manam",
"mvb": u"Mattole",
"kih": u"Kilmeri",
"mvd": u"Mamboru",
"mvh": u"Mulgi",
"mvi": u"Miyako",
"mvk": u"Mekmek",
"mvm": u"Muya",
"mvn": u"Minaveha",
"mvo": u"Marovo",
"nhd": u"Chiripá",
"nhf": u"Nhuwala",
"nha": u"Nhanda",
"nhb": u"Beng",
"nho": u"Takuu",
"nhh": u"Nahari",
"nhu": u"Noone",
"nhr": u"Naro",
"toz": u"To",
"tox": u"Tobian",
"toy": u"Topoiyo",
"teo": u"Teso",
"pis": u"Pijin",
"tow": u"Jemez",
"toj": u"Tojolabal",
"toh": u"Gitonga",
"tol": u"Tolowa",
"tea": u"Temiar",
"tob": u"Toba",
"tof": u"Gizrra",
"teb": u"Tetete",
"tod": u"Toma",
"toe": u"Tomedes",
"tec": u"Terik",
"tef": u"Teressa",
"xib": u"Iberian",
"teg": u"Teke-Tege",
"tex": u"Tennet",
"ktx": u"Kaxararí",
"ktz": u"Ju/'hoan",
"tey": u"Tulishi",
"ktt": u"Ketum",
"ktw": u"Kato",
"ktp": u"Kaduo",
"ktq": u"Katabaga",
"ktl": u"Koroshi",
"ktm": u"Kurti",
"ktn": u"Karitiâna",
"kto": u"Kuot",
"kth": u"Karanga",
"ktk": u"Kaniet",
"ktd": u"Kokata",
"kte": u"Nubri",
"ktf": u"Kwami",
"ktg": u"Kalkutung",
"kta": u"Katua",
"ktb": u"Kambaata",
"ktc": u"Kholok",
"lbq": u"Wampar",
"rag": u"Logooli",
"lbr": u"Lohorung",
"lbu": u"Labu",
"lbt": u"Lachi",
"lbw": u"Tolaki",
"lbv": u"Lavatbura-Lamusong",
"lby": u"Lamu-Lamu",
"lbx": u"Lawangan",
"ral": u"Ralte",
"lbz": u"Lardil",
"raj": u"Rajasthani",
"rak": u"Tulu-Bohuai",
"rah": u"Rabha",
"rai": u"Ramoaaina",
"lba": u"Lui",
"raw": u"Rawang",
"lbc": u"Lakkia",
"lbb": u"Label",
"lbe": u"Lak",
"ras": u"Tegali",
"lbg": u"Laopang",
"lbf": u"Tinani",
"lbi": u"La'bi",
"lbj": u"Ladakhi",
"lbm": u"Lodhi",
"lbo": u"Laven",
"lbn": u"Lamet",
"ypp": u"Phupa",
"tes": u"Tengger",
"thn": u"Thachanadan",
"ypz": u"Phuza",
"tet": u"Tetum",
"wng": u"Wanggom",
"teu": u"Soo",
"ypa": u"Phala",
"tev": u"Teor",
"yph": u"Phupha",
"ypm": u"Phuma",
"bsx": u"Yangkam",
"xow": u"Kowaki",
"bst": u"Basketo",
"bsu": u"Bahonsuai",
"bsw": u"Baiso",
"bsq": u"Bassa",
"bsr": u"Bassa-Kontagora",
"bss": u"Akoose",
"bsl": u"Basa-Gumna",
"bsm": u"Busami",
"bsn": u"Barasana-Eduria",
"bso": u"Buso",
"bsh": u"Kati",
"bsi": u"Bassossi",
"bsj": u"Bangwinji",
"bsk": u"Burushaski",
"bse": u"Wushi",
"bsf": u"Bauchi",
"bsg": u"Bashkardi",
"qya": u"Quenya",
"bsa": u"Abinomn",
"bsc": u"Bassari",
"xop": u"Kopar",
"uda": u"Uda",
"tha": u"Thai",
"udg": u"Muduga",
"pkp": u"Pukapuka",
"sul": u"Surigaonon",
"pkt": u"Maleng",
"pku": u"Paku",
"pkb": u"Pokomo",
"pkc": u"Paekche",
"pkg": u"Pak-Tong",
"pkh": u"Pankhu",
"suh": u"Suba",
"pkn": u"Pakanha",
"pko": u"Pökoot",
"yel": u"Yela",
"hrx": u"Hunsrik",
"hrz": u"Harzani",
"hru": u"Hruso",
"hrt": u"Hértevin",
"occ": u"Occidental",
"hrv": u"Croatian",
"suu": u"Sungkai",
"hrr": u"Horuru",
"hro": u"Haroi",
"udl": u"Wuzlam",
"hrk": u"Haruku",
"hre": u"Hre",
"udm": u"Udmurt",
"hra": u"Hrangkhol",
"xoc": u"O'chi'chi'",
"ybx": u"Yawiyo",
"yby": u"Yaweyuha",
"xon": u"Konkomba",
"xoo": u"Xukurú",
"eme": u"Emerillon",
"ema": u"Emai-Iuleha-Ora",
"emb": u"Embaloh",
"emm": u"Mamulique",
"eml": u"Emiliano-Romagnolo",
"emo": u"Emok",
"emn": u"Eman",
"emi": u"Mussau-Emira",
"suz": u"Sunwar",
"emw": u"Emplawas",
"emx": u"Erromintxela",
"nux": u"Mehek",
"nuy": u"Nunggubuyu",
"mph": u"Maung",
"nuu": u"Ngbundu",
"nur": u"Nukuria",
"nus": u"Nuer",
"nup": u"Nupe-Nupe-Tako",
"nuq": u"Nukumanu",
"nun": u"Anong",
"nuo": u"Nguôn",
"num": u"Niuafo'ou",
"nuj": u"Nyole",
"nuk": u"Nuu-chah-nulth",
"nuh": u"Ndunda",
"nui": u"Ngumbi",
"nuf": u"Nusu",
"nug": u"Nungali",
"nud": u"Ngala",
"nue": u"Ngundu",
"nuc": u"Nukuini",
"nua": u"Yuaga",
"muu": u"Yaaku",
"muw": u"Mundari",
"muv": u"Muthuvan",
"mup": u"Malvi",
"mus": u"Creek",
"mur": u"Murle",
"muy": u"Muyang",
"mux": u"Bo-Ung",
"muz": u"Mursi",
"mug": u"Musgu",
"ybk": u"Bokha",
"mua": u"Mundang",
"muc": u"Mbu'",
"mub": u"Mubi",
"mum": u"Maiwala",
"muo": u"Nyong",
"mui": u"Musi",
"muh": u"Mündü",
"muk": u"Mugom",
"muj": u"Mabire",
"pni": u"Aoheng",
"hai": u"Haida",
"zbl": u"Blissymbols",
"haj": u"Hajong",
"yba": u"Yala",
"wne": u"Waneci",
"ybb": u"Yemba",
"pnh": u"Penrhyn",
"coq": u"Coquille",
"cop": u"Coptic",
"cos": u"Corsican",
"cor": u"Cornish",
"cou": u"Wamey",
"cot": u"Caquinte",
"cow": u"Cowlitz",
"coy": u"Coyaima",
"cox": u"Nanti",
"ill": u"Iranun",
"coz": u"Chochotec",
"ilk": u"Ilongot",
"ilw": u"Talur",
"coc": u"Cocopa",
"cob": u"Chicomuceltec",
"coe": u"Koreguaje",
"cod": u"Cocama-Cocamilla",
"cog": u"Chong",
"cof": u"Colorado",
"coh": u"Chonyi-Dzihana-Kauma",
"coj": u"Cochimi",
"com": u"Comanche",
"col": u"Columbia-Wenatchi",
"coo": u"Comox",
"con": u"Cofán",
"kwa": u"Dâw",
"kwc": u"Likwala",
"hac": u"Gurani",
"kwe": u"Kwerba",
"kwd": u"Kwaio",
"kwf": u"Kwara'ae",
"kwi": u"Awa-Cuaiquer",
"had": u"Hatam",
"kwk": u"Kwakiutl",
"kwj": u"Kwanga",
"kwm": u"Kwambi",
"kwl": u"Kofyar",
"kwo": u"Kwomtari",
"kwq": u"Kwak",
"kwp": u"Kodia",
"kws": u"Kwese",
"kwr": u"Kwer",
"kwu": u"Kwakum",
"kww": u"Kwinti",
"kwx": u"Khirwar",
"hag": u"Hanga",
"srq": u"Sirionó",
"hay": u"Haya",
"tsx": u"Mubami",
"rth": u"Ratahan",
"haz": u"Hazaragi",
"xxr": u"Koropó",
"xxt": u"Tambora",
"hap": u"Hupla",
"haq": u"Ha",
"xxk": u"Ke'o",
"har": u"Harari",
"gnq": u"Gana",
"aiy": u"Ali",
"aix": u"Aighon",
"gnt": u"Guntai",
"aiz": u"Aari",
"gnz": u"Ganzi",
"ait": u"Arikem",
"aiw": u"Aari",
"aiq": u"Aimaq",
"aip": u"Burumakok",
"air": u"Airoran",
"aim": u"Aimol",
"ail": u"Aimele",
"aio": u"Aiton",
"aih": u"Ai-Cham",
"aik": u"Ake",
"aie": u"Amara",
"aid": u"Alngith",
"aif": u"Agi",
"aia": u"Arosi",
"aic": u"Ainbai",
"sqt": u"Soqotri",
"tvo": u"Tidore",
"gni": u"Gooniyandi",
"rnn": u"Roon",
"yor": u"Yoruba",
"rnl": u"Ranglong",
"yil": u"Yindjilandji",
"gnn": u"Gumatj",
"nij": u"Ngaju",
"nii": u"Nii",
"nin": u"Ninzo",
"nio": u"Nganasan",
"nil": u"Nila",
"nim": u"Nilamba",
"nib": u"Nakame",
"nia": u"Nias",
"nif": u"Nek",
"nig": u"Ngalakan",
"nid": u"Ngandi",
"nie": u"Niellim",
"niz": u"Ningil",
"nix": u"Hema",
"niy": u"Ngiti",
"nir": u"Nimboran",
"nis": u"Nimi",
"niq": u"Nandi",
"niv": u"Gilyak",
"niw": u"Nimo",
"niu": u"Niuean",
"sqi": u"Albanian",
"thy": u"Tha",
"thx": u"The",
"thw": u"Thudam",
"thu": u"Thuri",
"tht": u"Tahltan",
"ths": u"Thakali",
"thp": u"Thompson",
"epo": u"Esperanto",
"thm": u"Aheu",
"thk": u"Tharaka",
"gnl": u"Gangulu",
"epi": u"Epie",
"thf": u"Thangmi",
"thd": u"Thayore",
"sqh": u"Shau",
"kcb": u"Kawacha",
"wdg": u"Wadaginam",
"elk": u"Elkei",
"eli": u"Nding",
"elm": u"Eleme",
"ele": u"Elepi",
"elx": u"Elamite",
"elp": u"Elpaputih",
"elu": u"Elu",
"yww": u"Yawarawarga",
"lcs": u"Lisabata-Nuniali",
"lcq": u"Luhu",
"rna": u"Runa",
"rng": u"Ronga",
"rnd": u"Ruund",
"lcf": u"Lubu",
"lcd": u"Lola",
"lce": u"Loncong",
"lcc": u"Legenyem",
"lcl": u"Lisela",
"lcm": u"Tungag",
"rnw": u"Rungwa",
"lch": u"Luchazi",
"ywr": u"Yawuru",
"bpa": u"Dakaka",
"bpb": u"Barbacoas",
"bpd": u"Banda-Banda",
"bpg": u"Bonggo",
"bpi": u"Bagupi",
"bph": u"Botlikh",
"bpk": u"Orowe",
"bpj": u"Binji",
"bpm": u"Biyom",
"bpo": u"Anasi",
"bpp": u"Kaure",
"bpu": u"Bongu",
"bpy": u"Bishnupriya",
"bpz": u"Bilba",
"rka": u"Kraol",
"jyy": u"Jaya",
"cnu": u"Chenoua",
"ykk": u"Yakaikeke",
"yko": u"Yasa",
"ykl": u"Khlula",
"cnc": u"Côông",
"yku": u"Kuamasi",
"cna": u"Changthang",
"cno": u"Con",
"cni": u"Asháninka",
"plu": u"Palikúr",
"plq": u"Palaic",
"plp": u"Palpa",
"jya": u"Jiarong",
"plz": u"Paluan",
"pyu": u"Puyuma",
"plg": u"Pilagá",
"hss": u"Harsusi",
"ple": u"Palu'e",
"pld": u"Polari",
"plb": u"Polonombauk",
"pla": u"Miani",
"ywn": u"Yawanawa",
"pln": u"Palenquero",
"plm": u"Palembang",
"plj": u"Polci",
"pli": u"Pali",
"plh": u"Paulohi",
"obl": u"Oblo",
"obm": u"Moabite",
"obi": u"Obispeño",
"obu": u"Obulom",
"ahb": u"Axamb",
"ybh": u"Yakha",
"ppa": u"Pao",
"aha": u"Ahanta",
"ahg": u"Qimant",
"ppe": u"Papi",
"ahe": u"Ahe",
"ppk": u"Uma",
"ahk": u"Akha",
"ahh": u"Aghu",
"ahn": u"Àhàn",
"aho": u"Ahom",
"ahl": u"Igo",
"ahr": u"Ahirani",
"ahs": u"Ashe",
"ppp": u"Pelende",
"ppv": u"Papavô",
"aht": u"Ahtena",
"ppt": u"Pare",
"xyl": u"Yalakalore",
"wan": u"Wan",
"giu": u"Mulao",
"git": u"Gitxsan",
"wag": u"Wa'ema",
"waf": u"Wakoná",
"wae": u"Walser",
"wad": u"Wandamen",
"wac": u"Wasco-Wishram",
"giy": u"Giyug",
"gix": u"Gilima",
"gig": u"Goaria",
"gid": u"Gidar",
"gic": u"Gail",
"gib": u"Gibanawa",
"gia": u"Kitja",
"wax": u"Watam",
"gio": u"Gelao",
"gin": u"Hinukh",
"gil": u"Gilbertese",
"was": u"Washo",
"waq": u"Wageman",
"urf": u"Uradhi",
"mtz": u"Tacanec",
"mty": u"Nabi",
"mtr": u"Mewari",
"mts": u"Yora",
"mtq": u"Muong",
"mtv": u"Asaro'o",
"mtt": u"Mota",
"mtj": u"Moskona",
"mtk": u"Mbe'",
"mth": u"Munggui",
"mtn": u"Matagalpa",
"mtl": u"Montol",
"mtm": u"Mator",
"mtc": u"Munit",
"mtg": u"Una",
"mtd": u"Mualang",
"nnn": u"Ngete",
"nnm": u"Namia",
"nnk": u"Nankina",
"nnj": u"Nyangatom",
"nnh": u"Ngiemboon",
"nnf": u"Ngaing",
"nne": u"Ngandyera",
"nnc": u"Nancere",
"nnb": u"Nande",
"nna": u"Nyangumarta",
"nnz": u"Nda'nda'",
"nny": u"Nyangga",
"nnx": u"Ngong",
"nnu": u"Dwang",
"nnt": u"Nanticoke",
"nns": u"Ningye",
"nnr": u"Narungga",
"nnq": u"Ngindo",
"tiy": u"Tiruray",
"tit": u"Tinigua",
"tiu": u"Adasen",
"tiv": u"Tiv",
"tiw": u"Tiwi",
"tip": u"Trimuris",
"tiq": u"Tiéfo",
"til": u"Tillamook",
"tim": u"Timbe",
"tin": u"Tindi",
"tio": u"Teop",
"tii": u"Tiene",
"tij": u"Tilung",
"tik": u"Tikar",
"tid": u"Tidong",
"tie": u"Tingal",
"tif": u"Tifal",
"tig": u"Tigre",
"tib": u"Tibetan",
"tic": u"Tira",
"kvf": u"Kabalai",
"kvg": u"Kuni-Boazi",
"kve": u"Kalabakan",
"kvb": u"Kubu",
"kvc": u"Kove",
"kva": u"Bagvalal",
"kvo": u"Dobel",
"kvl": u"Kayaw",
"kvm": u"Kendem",
"kvj": u"Psikye",
"kvh": u"Komodo",
"kvi": u"Kwang",
"kvv": u"Kola",
"kvw": u"Wersing",
"ich": u"Etkywan",
"kvr": u"Kerinci",
"kvs": u"Kunggara",
"kvp": u"Kompane",
"sqa": u"Shama-Sambuga",
"mhq": u"Mandan",
"kvz": u"Tsakwambo",
"ums": u"Pendau",
"umr": u"Umbugarla",
"sgs": u"Samogitian",
"yki": u"Yoke",
"roh": u"Romansh",
"llx": u"Lauan",
"rol": u"Romblomanon",
"rom": u"Romany",
"ron": u"Romanian",
"roo": u"Rotokas",
"llq": u"Lolak",
"rod": u"Rogo",
"roe": u"Ronji",
"llu": u"Lau",
"llk": u"Lelak",
"lli": u"Teke-Laali",
"llh": u"Lamu",
"llo": u"Khlor",
"ice": u"Icelandic",
"llm": u"Lasalimu",
"lll": u"Lilau",
"llb": u"Lolo",
"lla": u"Lala-Roba",
"llg": u"Lole",
"llf": u"Hermit",
"lld": u"Ladin",
"bqg": u"Bago-Kusuntu",
"bqd": u"Bung",
"bqb": u"Bagusa",
"bqa": u"Tchumbuli",
"bqo": u"Balo",
"bql": u"Bilakura",
"bqm": u"Wumboko",
"bqj": u"Bandial",
"bqk": u"Banda-Mbrès",
"bqh": u"Baima",
"bqi": u"Bakhtiari",
"bqt": u"Bamukumbit",
"bqu": u"Boguru",
"bqr": u"Burusu",
"bqs": u"Bosngun",
"bqp": u"Busa",
"bqq": u"Biritai",
"bqz": u"Bakaka",
"bqx": u"Baangi",
"sza": u"Semelai",
"umb": u"Umbundu",
"klf": u"Kendeje",
"szg": u"Sengele",
"szd": u"Seru",
"sze": u"Seze",
"umo": u"Umotína",
"guc": u"Wayuu",
"gub": u"Guajajára",
"gua": u"Shiki",
"guf": u"Gupapuyngu",
"gue": u"Gurinji",
"guk": u"Gumuz",
"guj": u"Gujarati",
"guh": u"Guahibo",
"guo": u"Guayabero",
"gum": u"Guambiano",
"gur": u"Farefare",
"guq": u"Aché",
"gup": u"Gunwinggu",
"guw": u"Gun",
"guv": u"Gey",
"guu": u"Yanomamö",
"guz": u"Gusii",
"gux": u"Gourmanchéma",
"jdg": u"Jadgali",
"pmt": u"Tuamotuan",
"klo": u"Kapya",
"pmr": u"Paynamar",
"pms": u"Piemontese",
"klh": u"Weliki",
"hti": u"Hoti",
"kli": u"Kalumpang",
"pmd": u"Pallanganmiddang",
"pme": u"Pwaamei",
"htu": u"Hitu",
"hts": u"Hadza",
"pmb": u"Pambia",
"pmc": u"Palumata",
"pmn": u"Pam",
"pmo": u"Pom",
"klt": u"Nukna",
"klu": u"Klao",
"szw": u"Sawai",
"klw": u"Lindu",
"klp": u"Kamasa",
"klq": u"Rumu",
"klr": u"Khaling",
"kls": u"Kalasha",
"ply": u"Bolyu",
"ksq": u"Kwaami",
"yan": u"Mayangna",
"eko": u"Koti",
"yij": u"Yindjibarndi",
"ekm": u"Elip",
"eki": u"Eki",
"nce": u"Yale",
"ekg": u"Ekari",
"klx": u"Koluwawa",
"eke": u"Ekit",
"ksr": u"Borong",
"eka": u"Ekajuk",
"kly": u"Kalao",
"klz": u"Kabola",
"yup": u"Yukpa",
"ekr": u"Yace",
"ekp": u"Ekpeye",
"uzb": u"Uzbek",
"ksx": u"Kedang",
"ksz": u"Kodaku",
"kse": u"Kuni",
"msz": u"Momare",
"msy": u"Aruamu",
"ksd": u"Kuanua",
"msw": u"Mansoanka",
"msv": u"Maslam",
"msu": u"Musom",
"ksg": u"Kusaghe",
"msq": u"Caac",
"msp": u"Maritsauá",
"mso": u"Mombum",
"msn": u"Vurës",
"ksf": u"Bafia",
"msk": u"Mansaka",
"msg": u"Moraid",
"ksa": u"Shuwa-Zamani",
"mse": u"Musey",
"msb": u"Masbatenyo",
"wrn": u"Warnang",
"ksb": u"Shambala",
"ksm": u"Kumba",
"kso": u"Kofa",
"caz": u"Canichana",
"cay": u"Cayuga",
"cax": u"Chiquitano",
"ibl": u"Ibaloi",
"ibm": u"Agoi",
"ibn": u"Ibino",
"ibo": u"Igbo",
"cas": u"Tsimané",
"cap": u"Chipaya",
"caw": u"Callawalla",
"cav": u"Cavineña",
"cat": u"Catalan",
"cak": u"Kaqchikel",
"caj": u"Chané",
"cah": u"Cahuarano",
"cao": u"Chácobo",
"can": u"Chambri",
"cam": u"Cemuhî",
"cal": u"Carolinian",
"cac": u"Chuj",
"cab": u"Garifuna",
"caa": u"Chortí",
"ksj": u"Uare",
"cag": u"Nivaclé",
"cae": u"Lehar",
"cad": u"Caddo",
"kyk": u"Kamayo",
"kyj": u"Karao",
"kyi": u"Kiput",
"kyh": u"Karok",
"kyo": u"Kelon",
"kym": u"Kpatili",
"kyl": u"Kalapuya",
"kyc": u"Kyaka",
"kya": u"Kwaya",
"sps": u"Saposa",
"kyg": u"Keyagana",
"kyf": u"Kouya",
"kye": u"Krache",
"kyd": u"Karey",
"kyz": u"Kayabí",
"kyy": u"Kambaira",
"kyx": u"Rapoisi",
"spl": u"Selepet",
"spm": u"Akukem",
"spo": u"Spokane",
"kyr": u"Kuruáya",
"kyq": u"Kenga",
"kyp": u"Kang",
"kyw": u"Kudmali",
"kyv": u"Kayort",
"kyt": u"Kayagar",
"ttp": u"Tombelala",
"zua": u"Zeem",
"tbp": u"Taworta",
"tbs": u"Tanguat",
"aog": u"Angoram",
"aof": u"Bragat",
"aod": u"Andarum",
"aoc": u"Pemon",
"aob": u"Abom",
"aoa": u"Angolar",
"aom": u"Ömie",
"aol": u"Alor",
"aok": u"Arhö",
"aoj": u"Mufian",
"aoi": u"Anindilyakwa",
"aoh": u"Arma",
"aou": u"A'ou",
"aot": u"A'tong",
"aos": u"Taikat",
"aor": u"Aore",
"xzm": u"Zemgalian",
"tbv": u"Tobo",
"aox": u"Atorada",
"ght": u"Kuke",
"tbi": u"Gaam",
"ghr": u"Ghera",
"ghs": u"Guhu-Samane",
"tbj": u"Tiang",
"gha": u"Ghadamès",
"ghl": u"Ghulfan",
"tbm": u"Tagbu",
"ghn": u"Ghanongga",
"gho": u"Ghomara",
"tbo": u"Tawala",
"sob": u"Sobei",
"soe": u"Songomeno",
"que": u"Quechua",
"tbc": u"Takia",
"sod": u"Songoora",
"gta": u"Guató",
"tbb": u"Tapeba",
"sog": u"Sogdian",
"gti": u"Gbati-ri",
"vto": u"Vitou",
"soi": u"Sonha",
"soh": u"Aka",
"ppi": u"Paipai",
"tja": u"Tajuasohn",
"gbf": u"Gaikundi",
"noo": u"Nootka",
"noh": u"Nomu",
"noi": u"Noiri",
"noj": u"Nonuya",
"nok": u"Nooksack",
"noe": u"Nimadi",
"nof": u"Nomane",
"nog": u"Nogai",
"tjm": u"Timucua",
"gbd": u"Karadjeri",
"noc": u"Nuk",
"srt": u"Sauri",
"gbe": u"Niksek",
"tju": u"Tjurruru",
"noy": u"Noy",
"noz": u"Nayi",
"not": u"Nomatsiguenga",
"gbb": u"Kaytetye",
"nov": u"Novial",
"now": u"Nyambo",
"nop": u"Numanggang",
"noq": u"Ngongo",
"nor": u"Norwegian",
"ppr": u"Piru",
"shw": u"Shwai",
"ppq": u"Pei",
"gbn": u"Mo'da",
"tti": u"Tobati",
"mby": u"Memoni",
"gbm": u"Garhwali",
"siz": u"Siwi",
"ppu": u"Papora",
"soy": u"Miyobe",
"sox": u"Swo",
"gbv": u"Gbanu",
"soz": u"Temi",
"eja": u"Ejamat",
"gbu": u"Gagadu",
"gbr": u"Gbagyi",
"lmx": u"Laimbue",
"lmy": u"Lamboya",
"lmz": u"Lumbee",
"lmp": u"Limbum",
"lmq": u"Lamatuka",
"lmr": u"Lamalera",
"lms": u"Limousin",
"lmt": u"Lematang",
"lmu": u"Lamenu",
"lmv": u"Lomaiviti",
"lmh": u"Lambichhong",
"lmi": u"Lombi",
"lmk": u"Lamkang",
"lml": u"Hano",
"lmm": u"Lamam",
"lmn": u"Lambadi",
"lmo": u"Lombard",
"lmb": u"Merei",
"lmc": u"Limilngan",
"lmd": u"Lumun",
"lme": u"Pévé",
"lmg": u"Lamogai",
"yuz": u"Yuracare",
"wai": u"Wares",
"yuq": u"Yuqui",
"wah": u"Watubela",
"yuu": u"Yugh",
"yui": u"Yurutí",
"jwi": u"Jwira-Pepesa",
"yuk": u"Yuki",
"yum": u"Quechan",
"yul": u"Yulu",
"yua": u"Yucateco",
"yuc": u"Yuchi",
"gby": u"Gbari",
"yug": u"Yug",
"zal": u"Zauzou",
"zaj": u"Zaramo",
"zah": u"Zangwal",
"ttl": u"Totela",
"zag": u"Zaghawa",
"wab": u"Wab",
"zaz": u"Zari",
"zay": u"Zayse-Zergulla",
"zau": u"Zangskari",
"zap": u"Zapotec",
"yid": u"Yiddish",
"ian": u"Iatmul",
"iai": u"Iaai",
"yib": u"Yinglish",
"yii": u"Yidiny",
"yiu": u"Awu",
"yiq": u"Miqie",
"yaj": u"Banda-Yangere",
"yis": u"Yis",
"iap": u"Iapama",
"iar": u"Purari",
"hud": u"Huaulu",
"huf": u"Humene",
"hug": u"Huachipaeri",
"way": u"Wayana",
"hub": u"Huambisa",
"huc": u"=/Hua",
"hul": u"Hula",
"hum": u"Hungana",
"hun": u"Hungarian",
"huo": u"Hu",
"huh": u"Huilliche",
"hui": u"Huli",
"huk": u"Hulung",
"hut": u"Humla",
"huw": u"Hukumina",
"hup": u"Hupa",
"huq": u"Tsat",
"hur": u"Halkomelem",
"hus": u"Huastec",
"pnc": u"Pannei",
"huy": u"Hulaulá",
"huz": u"Hunzib",
"wat": u"Kaninuwa",
"wap": u"Wapishana",
"and": u"Ansus",
"ane": u"Xârâcùù",
"anf": u"Animere",
"ana": u"Andaqui",
"anb": u"Andoa",
"anc": u"Ngas",
"anm": u"Anal",
"ann": u"Obolo",
"ano": u"Andoque",
"anh": u"Nend",
"ani": u"Andi",
"anj": u"Anor",
"ank": u"Goemai",
"ant": u"Antakarinya",
"anu": u"Anuak",
"anv": u"Denya",
"anw": u"Anaang",
"anp": u"Angika",
"anr": u"Andh",
"ans": u"Anserma",
"anx": u"Andra-Hus",
"any": u"Anyin",
"anz": u"Anem",
"usu": u"Uya",
"wca": u"Yanomámi",
"gko": u"Kok-Nar",
"gkn": u"Gokana",
"gka": u"Guya",
"lhs": u"Mlahsö",
"gke": u"Ndai",
"lhp": u"Lhokpu",
"uya": u"Doko-Uyanga",
"oca": u"Ocaina",
"lut": u"Lushootseed",
"psq": u"Pasi",
"mrx": u"Maremgi",
"mry": u"Mandaya",
"mrz": u"Marind",
"mrv": u"Mangareva",
"mrw": u"Maranao",
"mrp": u"Morouas",
"mrs": u"Maragus",
"mrl": u"Mortlockese",
"mrm": u"Merlav",
"mro": u"Mru",
"mri": u"Maori",
"mrk": u"Hmwaveke",
"mrf": u"Elseng",
"mrg": u"Mising",
"mra": u"Mlabri",
"mrb": u"Marino",
"mrc": u"Maricopa",
"tkf": u"Tukumanféd",
"tkd": u"Tukudede",
"nlr": u"Ngarla",
"nlu": u"Nchumbulu",
"nly": u"Nyamal",
"nlx": u"Nahali",
"tkl": u"Tokelau",
"nlz": u"Nalögo",
"nla": u"Ngombale",
"tkw": u"Teanu",
"nlc": u"Nalca",
"nld": u"Dutch",
"nlg": u"Gela",
"tkq": u"Tee",
"nli": u"Grangali",
"nlj": u"Nyali",
"tkz": u"Takua",
"nll": u"Nihali",
"nlo": u"Ngul",
"yka": u"Yakan",
"kxj": u"Kulfa",
"dyy": u"Dyaabugay",
"kxo": u"Kanoé",
"ssu": u"Susuami",
"dyu": u"Dyula",
"kxb": u"Krobu",
"kxc": u"Konso",
"kxd": u"Brunei",
"kxe": u"Kakihum",
"kxg": u"Katingan",
"kxx": u"Likuba",
"dyn": u"Dyangadi",
"dyo": u"Jola-Fonyi",
"ssi": u"Sansi",
"ssk": u"Sunam",
"dyd": u"Dyugun",
"kxt": u"Koiwat",
"dya": u"Dyan",
"dyb": u"Dyaberdyaber",
"kxw": u"Konai",
"xud": u"Umiida",
"rmr": u"Caló",
"rmp": u"Rempi",
"rmq": u"Caló",
"rmv": u"Romanova",
"rmt": u"Domari",
"lnz": u"Lonzo",
"lnu": u"Longuda",
"lnt": u"Lintang",
"kem": u"Kemak",
"lns": u"Lamnso'",
"lnm": u"Langam",
"lni": u"Daantanai'",
"lnh": u"Lanoh",
"lnj": u"Leningitij",
"lnd": u"Lundayeh",
"lng": u"Langobardic",
"rmi": u"Lomavren",
"lna": u"Langbashe",
"lnc": u"Languedocien",
"lnb": u"Mbalanhu",
"keh": u"Keak",
"ytp": u"Thopho",
"yla": u"Yaul",
"ytl": u"Tanglang",
"yta": u"Talu",
"xvi": u"Kamviri",
"wre": u"Ware",
"gwe": u"Gweno",
"gwd": u"Gawwada",
"gwg": u"Moo",
"gwf": u"Gowro",
"gwa": u"Mbato",
"gwc": u"Kalami",
"gwb": u"Gwa",
"gwm": u"Awngthim",
"gwn": u"Gwandara",
"gwi": u"Gwichʼin",
"gwj": u"/Gwi",
"gwu": u"Guwamu",
"gwt": u"Gawar-Bati",
"gww": u"Kwini",
"gwr": u"Gwere",
"xns": u"Kanashi",
"gwx": u"Gua",
"hvk": u"Haveke",
"wrm": u"Warumungu",
"pox": u"Polabian",
"hvn": u"Sabu",
"pop": u"Pwapwa",
"pon": u"Pohnpeian",
"pol": u"Polish",
"pok": u"Pokangá",
"poh": u"Poqomchi'",
"kev": u"Kanikkaran",
"pof": u"Poke",
"pog": u"Potiguára",
"pod": u"Ponares",
"poc": u"Poqomam",
"wrv": u"Waruna",
"wru": u"Waru",
"wrr": u"Wardaman",
"tls": u"Tambotalo",
"wrp": u"Waropen",
"tlr": u"Talise",
"khu": u"Nkhumbi",
"xnt": u"Narragansett",
"wgy": u"Warrgamay",
"sow": u"Sowanda",
"tlv": u"Taliabu",
"eip": u"Eipomek",
"eit": u"Eitiep",
"eiv": u"Askopan",
"tlt": u"Teluti",
"tly": u"Talysh",
"ykn": u"Kua-nsi",
"mqc": u"Mangole",
"ids": u"Idesa",
"mqe": u"Matepi",
"mqd": u"Madang",
"mqf": u"Momuna",
"mqi": u"Mariri",
"mqj": u"Mamasa",
"mql": u"Mbelime",
"mqo": u"Modole",
"mqn": u"Moronene",
"mqq": u"Minokok",
"mqp": u"Manipa",
"mqr": u"Mander",
"mqu": u"Mandari",
"mqt": u"Mok",
"mqw": u"Murupi",
"mqv": u"Mosimo",
"mqy": u"Manggarai",
"mqx": u"Mamuju",
"mqz": u"Pano",
"ykm": u"Kap",
"uha": u"Uhami",
"rie": u"Rien",
"rwk": u"Rwa",
"wya": u"Wyandot",
"tld": u"Talaud",
"tli": u"Tlingit",
"tlo": u"Talodi",
"ccq": u"Chaungtha",
"ccp": u"Chakma",
"ccr": u"Cacaopera",
"ccl": u"Cutchi-Swahili",
"cch": u"Atsam",
"ccj": u"Kasanga",
"cce": u"Chopi",
"cca": u"Cauca",
"ccc": u"Chamicuro",
"xka": u"Kalkoti",
"tir": u"Tigrinya",
"prn": u"Prasuni",
"xug": u"Kunigami",
"kwh": u"Kowiai",
"ami": u"Amis",
"amh": u"Amharic",
"amk": u"Ambai",
"amj": u"Amdang",
"aml": u"War-Jaintia",
"amo": u"Amo",
"amn": u"Amanab",
"ama": u"Amanayé",
"amc": u"Amahuaca",
"amb": u"Ambo",
"ame": u"Yanesha'",
"amg": u"Amurdak",
"amf": u"Hamer-Banna",
"amy": u"Ami",
"amx": u"Anmatyerre",
"amz": u"Atampaya",
"amq": u"Amahai",
"amp": u"Alamblak",
"amr": u"Amarakaeri",
"amt": u"Amto",
"amv": u"Ambelau",
"wbv": u"Wajarri",
"wbw": u"Woi",
"wbt": u"Wanman",
"wbr": u"Wagdi",
"wbp": u"Warlpiri",
"wbq": u"Waddar",
"gju": u"Gujari",
"gjn": u"Gonja",
"wbe": u"Waritai",
"wbb": u"Wabo",
"gji": u"Geji",
"wbl": u"Wakhi",
"wbm": u"Wa",
"wbk": u"Waigali",
"wbh": u"Wanda",
"wbi": u"Vwanji",
"yna": u"Aluo",
"gvj": u"Guajá",
"gvn": u"Kuku-Yalanji",
"gvl": u"Gulay",
"gvm": u"Gurmana",
"gvc": u"Guanano",
"gvf": u"Golin",
"pri": u"Paicî",
"gve": u"Duwet",
"gvy": u"Guyani",
"gvs": u"Gumawana",
"sqq": u"Sou",
"nmv": u"Ngamini",
"nmw": u"Nimoa",
"nmt": u"Namonuito",
"nmr": u"Nimbari",
"nms": u"Letemboi",
"nmp": u"Nimanbur",
"nmq": u"Nambya",
"tdc": u"Emberá-Tadó",
"tdb": u"Panchpargania",
"tda": u"Tagdal",
"nmz": u"Nawdm",
"tdf": u"Talieng",
"nmy": u"Namuyi",
"nmg": u"Kwasio",
"nmd": u"Ndumu",
"nmc": u"Ngam",
"nmn": u"!Xóõ",
"nml": u"Ndemli",
"nmm": u"Manangba",
"nmk": u"Namakura",
"nmi": u"Nyam",
"dza": u"Tunzu",
"sra": u"Saruga",
"srf": u"Nafi",
"dzd": u"Daza",
"dzg": u"Dazaga",
"srj": u"Serawai",
"srh": u"Sarikoli",
"sri": u"Siriano",
"dzl": u"Dzalakha",
"dzo": u"Dzongkha",
"dzn": u"Dzando",
"srr": u"Serer",
"srs": u"Sarsi",
"srp": u"Serbian",
"srw": u"Serua",
"sru": u"Suruí",
"srz": u"Shahmirzadi",
"sqo": u"Sorkhei",
"srx": u"Sirmauri",
"sry": u"Sera",
"yaw": u"Yawalapití",
"sqn": u"Susquehannock",
"yav": u"Yangben",
"yaz": u"Lokaa",
"sqm": u"Suma",
"yky": u"Yakoma",
"yaq": u"Yaqui",
"yap": u"Yapese",
"waz": u"Wampur",
"lob": u"Lobi",
"loc": u"Inonhan",
"ehu": u"Ehueun",
"lof": u"Logol",
"log": u"Logo",
"lod": u"Berawan",
"loe": u"Saluan",
"loj": u"Lou",
"lok": u"Loko",
"loh": u"Narim",
"loo": u"Lombo",
"lol": u"Mongo",
"lor": u"Téén",
"los": u"Loniu",
"lop": u"Lopa",
"loq": u"Lobala",
"lov": u"Lopi",
"lot": u"Otuho",
"loz": u"Lozi",
"lox": u"Loun",
"loy": u"Loke",
"wro": u"Worrorra",
"yah": u"Yazgulyam",
"jub": u"Wannu",
"juc": u"Jurchen",
"jua": u"Júma",
"rjs": u"Rajbanshi",
"yak": u"Yakama",
"jud": u"Worodougou",
"juk": u"Wapan",
"juh": u"Hõne",
"jui": u"Ngadjuri",
"jun": u"Juang",
"juo": u"Jiba",
"jul": u"Jirel",
"jum": u"Jumjum",
"jur": u"Jurúna",
"jup": u"Hupdë",
"juw": u"Wãpha",
"jut": u"Jutish",
"juu": u"Ju",
"juy": u"Juray",
"yag": u"Yámana",
"rji": u"Raji",
"yaa": u"Yaminahua",
"yab": u"Yuhup",
"yva": u"Yawa",
"cbb": u"Cabiyarí",
"cbc": u"Carapana",
"cbg": u"Chimila",
"cbd": u"Carijona",
"cbe": u"Chipiajes",
"cbk": u"Chavacano",
"cbh": u"Cagua",
"cbi": u"Chachi",
"cbn": u"Nyahkur",
"cbo": u"Izora",
"cbr": u"Cashibo-Cacataibo",
"cbs": u"Cashinahua",
"cbv": u"Cacua",
"cbw": u"Kinabalian",
"cbt": u"Chayahuita",
"cbu": u"Candoshi-Shapra",
"cby": u"Carabayo",
"igw": u"Igwe",
"yon": u"Yongkom",
"yom": u"Yombe",
"yol": u"Yola",
"igs": u"Interglossa",
"yoi": u"Yonaguni",
"yog": u"Yogad",
"lgm": u"Lega-Mwenga",
"yob": u"Yoba",
"igg": u"Igana",
"ige": u"Igede",
"igb": u"Ebira",
"yoy": u"Yoy",
"igo": u"Isebe",
"ign": u"Ignaciano",
"igm": u"Kanggape",
"igl": u"Igala",
"yos": u"Yos",
"hwo": u"Hwana",
"xtw": u"Tawandê",
"hwa": u"Wané",
"wrl": u"Warlmanpa",
"ziz": u"Zizilivakan",
"alo": u"Larike-Wakasihu",
"all": u"Allar",
"alm": u"Amblong",
"alj": u"Alangan",
"alk": u"Alak",
"alh": u"Alawa",
"ali": u"Amaimon",
"alf": u"Alege",
"ald": u"Alladian",
"ale": u"Aleut",
"alb": u"Albanian",
"alc": u"Qawasqar",
"ala": u"Alago",
"alz": u"Alur",
"alx": u"Amol",
"aly": u"Alyawarr",
"alw": u"Alaba-K’abeena",
"alu": u"'Are'are",
"alr": u"Alutor",
"alp": u"Alune",
"alq": u"Algonquin",
"wms": u"Wambon",
"myb": u"Mbay",
"otu": u"Otuke",
"nal": u"Nalik",
"wmi": u"Wamin",
"wmh": u"Waima'a",
"wmn": u"Waamwang",
"wmc": u"Wamas",
"wmb": u"Wambaya",
"otw": u"Ottawa",
"rob": u"Tae'",
"wme": u"Wambule",
"wmd": u"Mamaindé",
"mpg": u"Marba",
"fax": u"Fala",
"mpb": u"Mullukmulluk",
"mpc": u"Mangarayi",
"mpa": u"Mpoto",
"far": u"Fataleka",
"fas": u"Persian",
"fap": u"Palor",
"fat": u"Fanti",
"fau": u"Fayu",
"faj": u"Faita",
"fai": u"Faiwol",
"fao": u"Faroese",
"fam": u"Fam",
"uwa": u"Kuku-Uwanh",
"faa": u"Fasu",
"faf": u"Fagani",
"fag": u"Finongan",
"fad": u"Wagi",
"mpy": u"Mapia",
"tlx": u"Khehek",
"teh": u"Tehuelche",
"tei": u"Torricelli",
"nby": u"Ningera",
"nbx": u"Ngura",
"tel": u"Telugu",
"tem": u"Timne",
"pum": u"Puma",
"nbr": u"Numana-Nunku-Gbantu-Numbu",
"nbq": u"Nggem",
"nbp": u"Nnam",
"nbv": u"Ngamambo",
"nbt": u"Na",
"nbk": u"Nake",
"nbj": u"Ngarinman",
"nbh": u"Ngamo",
"nbo": u"Nkukoli",
"nbn": u"Kuri",
"nbb": u"Ndoe",
"nba": u"Nyemba",
"rbp": u"Barababaraba",
"nbg": u"Nagarchal",
"nbf": u"Naxi",
"nbd": u"Ngbinda",
"sug": u"Suganga",
"suf": u"Tarpia",
"sue": u"Suena",
"rma": u"Rama",
"sua": u"Sulka",
"sun": u"Sundanese",
"sum": u"Sumo-Mayangna",
"suk": u"Sukuma",
"suj": u"Shubi",
"sui": u"Suki",
"rou": u"Runga",
"suw": u"Sumbwa",
"sut": u"Subtiaba",
"sus": u"Susu",
"sur": u"Mwaghavul",
"suq": u"Suri",
"pue": u"Puelche",
"row": u"Dela-Oenale",
"suy": u"Suyá",
"sux": u"Sumerian",
"kzr": u"Karang",
"kzp": u"Kaidipang",
"kzq": u"Kaike",
"kzv": u"Komyandaret",
"kzw": u"Karirí-Xocó",
"kzu": u"Kayupulau",
"kzz": u"Kalabra",
"kzx": u"Kamarian",
"kzb": u"Kaibobo",
"kzg": u"Kikai",
"kzd": u"Kadai",
"kze": u"Kosena",
"kzk": u"Kazukuru",
"kzh": u"Kenuzi-Dongola",
"kzi": u"Kelabit",
"kzn": u"Kokola",
"kzo": u"Kaningi",
"kzl": u"Kayeli",
"kzm": u"Kais",
"sbb": u"Simbo",
"sba": u"Ngambay",
"pux": u"Puare",
"puy": u"Purisimeño",
"rkt": u"Rangpuri",
"jrb": u"Judeo-Arabic",
"jra": u"Jarai",
"sbe": u"Saliba",
"put": u"Putoh",
"jru": u"Japrería",
"jrt": u"Jorto",
"jrr": u"Jiru",
"rkb": u"Rikbaktsa",
"puu": u"Punu",
"rkm": u"Marka",
"rkh": u"Rakahanga-Manihiki",
"rki": u"Rakhine",
"puw": u"Puluwatese",
"pup": u"Pulabu",
"puq": u"Puquina",
"pur": u"Puruborá",
"pus": u"Pushto",
"zia": u"Zia",
"zin": u"Zinza",
"vem": u"Vemgo-Mabas",
"gqi": u"Guiqiong",
"gqa": u"Ga'anda",
"sce": u"Dongxiang",
"gqu": u"Qau",
"jvd": u"Javindo",
"gqr": u"Gor",
"hhr": u"Kerak",
"wls": u"Wallisian",
"hhy": u"Hoyahoya",
"wrk": u"Garrwa",
"zil": u"Zialo",
"kgb": u"Kawe",
"oyy": u"Oya'oya",
"vmi": u"Miwa",
"oym": u"Wayampi",
"wkw": u"Wakawaka",
"oyd": u"Oyda",
"oyb": u"Oy",
"ynu": u"Yahuna",
"lhn": u"Lahanan",
"lhm": u"Lhomi",
"lhu": u"Lahu",
"lht": u"Lo-Toga",
"ego": u"Eggon",
"egl": u"Emilian",
"ega": u"Ega",
"wau": u"Waurá",
"uvh": u"Uri",
"uvl": u"Lote",
"jit": u"Jita",
"xun": u"Unggarranggu",
"ceg": u"Chamacoco",
"rwa": u"Rawo",
"ceb": u"Cebuano",
"cen": u"Cen",
"rwo": u"Rawa",
"cet": u"Centúúm",
"ces": u"Czech",
"zga": u"Kinga",
"ynl": u"Yangulam",
"ynn": u"Yana",
"yno": u"Yong",
"ynh": u"Yangho",
"ynd": u"Yandruwandha",
"yne": u"Lang'e",
"yng": u"Yango",
"ife": u"Ifè",
"iff": u"Ifo",
"ifm": u"Teke-Fuumu",
"yns": u"Yansi",
"ynq": u"Yendang",
"tln": u"Talondo'",
"ppn": u"Papapana",
"izh": u"Ingrian",
"izi": u"Izi-Ezaa-Ikwo-Mgbo",
"izr": u"Izere",
"pha": u"Pa-Hng",
"ass": u"Ipulo",
"asr": u"Asuri",
"asv": u"Asoa",
"ast": u"Asturian",
"asz": u"As",
"asx": u"Muratayak",
"pub": u"Purum",
"asb": u"Assiniboine",
"asg": u"Cishingini",
"asd": u"Asas",
"ask": u"Ashkun",
"asj": u"Nsari",
"asi": u"Buruwai",
"ash": u"Abishira",
"aso": u"Dano",
"asm": u"Assamese",
"asl": u"Asilulu",
"wly": u"Waling",
"koo": u"Konzo",
"mze": u"Morawa",
"wlr": u"Wailapa",
"kon": u"Kongo",
"wlu": u"Wuliwuli",
"wlw": u"Walak",
"wli": u"Waioli",
"wlk": u"Wailaki",
"wln": u"Walloon",
"wlo": u"Wolio",
"wla": u"Walio",
"wle": u"Wolane",
"wlg": u"Kunbarlang",
"yle": u"Yele",
"koy": u"Koyukon",
"gpn": u"Taiap",
"rws": u"Rawas",
"gpa": u"Gupa-Abawa",
"ncz": u"Natchez",
"tfn": u"Tanaina",
"xri": u"Krikati-Timbira",
"ncp": u"Ndaktup",
"ncr": u"Ncane",
"ncu": u"Chumburung",
"nck": u"Nakara",
"nae": u"Naka'ela",
"ncn": u"Nauna",
"kop": u"Waube",
"nca": u"Iyo",
"ncc": u"Ponam",
"ncd": u"Nachering",
"kos": u"Kosraean",
"ncf": u"Notsi",
"ncg": u"Nisga'a",
"ste": u"Liana-Seti",
"dth": u"Adithinngithigh",
"sta": u"Settla",
"stl": u"Stellingwerfs",
"dta": u"Daur",
"sto": u"Stoney",
"sth": u"Shelta",
"pmf": u"Pamona",
"dtd": u"Ditidaht",
"stu": u"Samtao",
"dty": u"Dotyali",
"stw": u"Satawalese",
"kow": u"Kugama",
"sts": u"Shumashti",
"dtr": u"Lotud",
"tfo": u"Tefaro",
"scw": u"Sha",
"pmm": u"Pomo",
"lid": u"Nyindrou",
"lie": u"Likila",
"lif": u"Limbu",
"lig": u"Ligbi",
"lib": u"Likum",
"lic": u"Hlai",
"lil": u"Lillooet",
"lim": u"Limburgan",
"lin": u"Lingala",
"lio": u"Liki",
"lih": u"Lihir",
"ilu": u"Ili'uun",
"lij": u"Ligurian",
"lik": u"Lika",
"lit": u"Lithuanian",
"efi": u"Efik",
"liv": u"Liv",
"liw": u"Col",
"lip": u"Sekpele",
"liq": u"Libido",
"lis": u"Lisu",
"efa": u"Efai",
"pmk": u"Pamlico",
"lix": u"Liabuku",
"efe": u"Efe",
"liz": u"Libinza",
"kac": u"Kachin",
"kab": u"Kabyle",
"kaa": u"Kara-Kalpak",
"kag": u"Kajaman",
"kaf": u"Katso",
"kae": u"Ketangalan",
"kad": u"Adara",
"kaj": u"Jju",
"kai": u"Karekare",
"kao": u"Xaasongaxango",
"kan": u"Kannada",
"kal": u"Kalaallisut",
"kas": u"Kashmiri",
"kaq": u"Capanahua",
"kap": u"Bezhta",
"kaw": u"Kawi",
"kav": u"Katukína",
"jiv": u"Shuar",
"kat": u"Georgian",
"kaz": u"Kazakh",
"kay": u"Kamayurá",
"kax": u"Kao",
"rhg": u"Rohingya",
"bzv": u"Bebe",
"bzu": u"Burmeso",
"bzt": u"Brithenig",
"bzr": u"Biri",
"bzp": u"Kemberano",
"bzz": u"Evant",
"bzy": u"Obanliku",
"bzg": u"Babuza",
"bzf": u"Boikin",
"bzd": u"Bribri",
"bzb": u"Andio",
"bza": u"Bandi",
"bzo": u"Bozaba",
"bzm": u"Bolondo",
"bzi": u"Bisu",
"cde": u"Chenchu",
"cdf": u"Chiru",
"cdg": u"Chamari",
"cda": u"Choni",
"cdm": u"Chepang",
"cdn": u"Chaudangsi",
"cdh": u"Chambeali",
"cdi": u"Chodri",
"cdj": u"Churahi",
"rtw": u"Rathawi",
"cdr": u"Cinda-Regi-Tiyal",
"cdy": u"Chadong",
"cdz": u"Koda",
"bfa": u"Bari",
"ymr": u"Malasar",
"bff": u"Bofi",
"bfe": u"Betaf",
"bfd": u"Bafut",
"bfj": u"Bafanji",
"bfh": u"Blafe",
"bfn": u"Bunak",
"bfm": u"Mmen",
"bfl": u"Banda-Ndélé",
"bfr": u"Bazigar",
"bfq": u"Badaga",
"bfp": u"Beba",
"bfw": u"Bondo",
"ymd": u"Muda",
"bfu": u"Gahri",
"bft": u"Balti",
"ymi": u"Moji",
"bfy": u"Bagheli",
"bfx": u"Bantayanon",
"ymm": u"Maay",
"tct": u"T'en",
"ymn": u"Yamna",
"std": u"Sentinel",
"hir": u"Himarimã",
"hit": u"Hittite",
"nam": u"Ngan'gityemerri",
"hiw": u"Hiw",
"hix": u"Hixkaryána",
"stf": u"Seta",
"hia": u"Lamang",
"hib": u"Hibito",
"stg": u"Trieng",
"hid": u"Hidatsa",
"hig": u"Kamwe",
"hih": u"Pamosu",
"hii": u"Hinduri",
"hij": u"Hijuk",
"hik": u"Seit-Kaitetu",
"hil": u"Hiligaynon",
"hin": u"Hindi",
"hio": u"Tsoa",
"uun": u"Kulon-Pazeh",
"tco": u"Taungyo",
"tcm": u"Tanahmerah",
"stm": u"Setaman",
"stn": u"Owa",
"tck": u"Tchitchege",
"arp": u"Arapaho",
"arv": u"Arbore",
"arw": u"Arawak",
"tci": u"Wára",
"ara": u"Arabic",
"ard": u"Arabana",
"arf": u"Arafundi",
"arg": u"Aragonese",
"arh": u"Arhuaco",
"ari": u"Arikara",
"arj": u"Arapaso",
"ark": u"Arikapú",
"arl": u"Arabela",
"arm": u"Armenian",
"arn": u"Mapudungun",
"aro": u"Araona",
"woy": u"Weyto",
"wow": u"Wawonii",
"stv": u"Silt'e",
"tcc": u"Datooga",
"wol": u"Wolof",
"woo": u"Manombai",
"won": u"Wongo",
"woi": u"Kamang",
"wok": u"Longto",
"woe": u"Woleaian",
"wod": u"Wolani",
"wog": u"Wogamusin",
"woa": u"Tyaraity",
"woc": u"Wogeo",
"stq": u"Saterfriesisch",
"uuu": u"U",
"wea": u"Wewaw",
"fgr": u"Fongoro",
"uum": u"Urum",
"gmo": u"Gamo-Gofa-Dawro",
"gmn": u"Gimnime",
"gmm": u"Gbaya-Mbodomo",
"rof": u"Rombo",
"wei": u"Kiunum",
"tgr": u"Tareng",
"tgp": u"Tangoa",
"tgq": u"Tring",
"tgv": u"Tingui-Boto",
"tgz": u"Tagalaka",
"weo": u"Wemale",
"tgx": u"Tagish",
"tgy": u"Togoyo",
"tgb": u"Tobilung",
"tgc": u"Tigak",
"tgf": u"Chalikha",
"tgj": u"Tagin",
"gmd": u"Mághdì",
"tgn": u"Tandaganon",
"tgo": u"Sudest",
"tgl": u"Tagalog",
"dui": u"Dumun",
"duj": u"Dhuwal",
"duk": u"Uyajitaya",
"dua": u"Duala",
"dub": u"Dubli",
"duc": u"Duna",
"dud": u"Hun-Saare",
"duf": u"Dumbea",
"dug": u"Duruma",
"dux": u"Duungooma",
"duz": u"Duli",
"gmx": u"Magoma",
"nau": u"Nauru",
"dup": u"Duano",
"dur": u"Dii",
"dus": u"Dumi",
"dut": u"Dutch",
"duu": u"Drung",
"duv": u"Duvle",
"wet": u"Perai",
"iya": u"Iyayu",
"iyo": u"Mesaka",
"gmu": u"Gumalu",
"jpn": u"Japanese",
"hba": u"Hamba",
"rit": u"Ritarungo",
"riu": u"Riung",
"rir": u"Ribun",
"rin": u"Nungu",
"rim": u"Nyaturu",
"rif": u"Tarifit",
"hbb": u"Huba",
"imy": u"Milyan",
"gsp": u"Wasembo",
"xai": u"Kaimbé",
"gsc": u"Gascon",
"hbs": u"Serbo-Croatian",
"vmw": u"Makhuwa",
"gsl": u"Gusilay",
"gsn": u"Gusan",
"lii": u"Lingkhim",
"teq": u"Temein",
"hji": u"Haji",
"liu": u"Logorik",
"wdu": u"Wadjigu",
"wka": u"Kw'adza",
"zkt": u"Kitan",
"ror": u"Rongga",
"lji": u"Laiyolo",
"ljl": u"Li'o",
"lje": u"Rampi",
"liy": u"Banda-Bambari",
"eee": u"E",
"kux": u"Kukatja",
"wpc": u"Maco",
"xsa": u"Sabaean",
"rhp": u"Yahang",
"ruk": u"Che",
"cgk": u"Chocangacakha",
"rui": u"Rufiji",
"rum": u"Romanian",
"cga": u"Changriwa",
"ruc": u"Ruuli",
"cgc": u"Kagayanen",
"ruf": u"Luguru",
"rug": u"Roviana",
"cgg": u"Chiga",
"rue": u"Rusyn",
"ruz": u"Ruma",
"rus": u"Russian",
"rup": u"Macedo-Romanian",
"rut": u"Rutul",
"bga": u"Gwamhi-Wuri",
"bgb": u"Bobongko",
"bgc": u"Haryanvi",
"bge": u"Bauria",
"bgf": u"Bangandu",
"bgg": u"Bugun",
"bgh": u"Bogan",
"bgi": u"Giangan",
"bgj": u"Bangolan",
"bgk": u"Bit",
"bgq": u"Bagri",
"bgs": u"Tagabawa",
"bgt": u"Bughotu",
"bgu": u"Mbongno",
"bgv": u"Warkay-Bipim",
"bgw": u"Bhatri",
"bgy": u"Benggoi",
"bgz": u"Banggai",
"ide": u"Idere",
"idb": u"Indo-Portuguese",
"idc": u"Idon",
"ida": u"Idakho-Isukha-Tiriki",
"kau": u"Kanuri",
"spc": u"Sapé",
"xpj": u"Mpalitjanh",
"xpi": u"Pictish",
"xpo": u"Pochutec",
"kdj": u"Karamojong",
"ixl": u"Ixil",
"xpc": u"Pecheneg",
"ixc": u"Ixcatec",
"xpg": u"Phrygian",
"xpy": u"Puyo",
"msl": u"Molof",
"xps": u"Pisidian",
"xpr": u"Parthian",
"xpq": u"Mohegan-Pequot",
"xpp": u"Puyo-Paekche",
"xpu": u"Punic",
"wnb": u"Wanambre",
"pwr": u"Powari",
"aqp": u"Atakapa",
"wnd": u"Wandarang",
"aqr": u"Arhâ",
"wnk": u"Wanukaka",
"aqz": u"Akuntsu",
"aqg": u"Arigidi",
"aqc": u"Archi",
"msf": u"Mekwei",
"aqm": u"Atohwaim",
"uta": u"Otank",
"utr": u"Etulo",
"utu": u"Utu",
"grw": u"Gweda",
"grt": u"Garo",
"gru": u"Kistane",
"grr": u"Taznatit",
"grs": u"Gresi",
"nad": u"Nijadali",
"grq": u"Gorovu",
"naj": u"Nalu",
"nak": u"Nakanai",
"grz": u"Guramalum",
"nao": u"Naaba",
"grx": u"Guriaso",
"nar": u"Iguta",
"grg": u"Madi",
"grd": u"Guruntum-Mbaaru",
"grb": u"Grebo",
"nat": u"Hungworo",
"grn": u"Guarani",
"gro": u"Groma",
"nax": u"Nakwi",
"grh": u"Gbiri-Niragu",
"gri": u"Ghari",
"tms": u"Tima",
"tmt": u"Tasmate",
"sve": u"Serili",
"dva": u"Duau",
"jiq": u"Guanyinqiao",
"svx": u"Skalvian",
"svr": u"Savara",
"svs": u"Savosavo",
"wie": u"Wik-Epa",
"kxs": u"Kangjia",
"ugo": u"Ugong",
"kxv": u"Kuvi",
"lkn": u"Lakon",
"lko": u"Khayo",
"lkl": u"Laeko-Libuat",
"lkj": u"Remun",
"lkh": u"Lakha",
"lki": u"Laki",
"qxq": u"Qashqa'i",
"lkd": u"Lakondê",
"lke": u"Kenyi",
"lkb": u"Kabras",
"lkc": u"Kucong",
"lka": u"Lakalei",
"rtm": u"Rotuman",
"lky": u"Lokoya",
"lkt": u"Lakota",
"lkr": u"Päri",
"lks": u"Kisa",
"tme": u"Tremembé",
"kce": u"Kaivi",
"kcg": u"Tyap",
"kcf": u"Ukaan",
"kca": u"Khanty",
"kcc": u"Lubila",
"ibi": u"Ibilo",
"kco": u"Kinalakna",
"kcn": u"Nubi",
"kci": u"Kamantan",
"kch": u"Vono",
"kck": u"Kalanga",
"kcj": u"Kobiana",
"kct": u"Kaian",
"kcw": u"Kabwari",
"kcv": u"Kete",
"kcq": u"Kamo",
"kcp": u"Kanga",
"kcs": u"Koenoem",
"kcr": u"Katla",
"jqr": u"Jaqaru",
"kcx": u"Kachama-Ganjule",
"kcz": u"Konongo",
"syi": u"Seki",
"bxz": u"Binahari",
"zmk": u"Mandandanyi",
"bxq": u"Beele",
"bxp": u"Bebil",
"bxs": u"Busam",
"bxt": u"Buxinhua",
"bxw": u"Bankagooma",
"bxv": u"Berakou",
"bxi": u"Pirlatapa",
"bxh": u"Buhutu",
"bxk": u"Bukusu",
"bxj": u"Bayungu",
"bxl": u"Jalkunan",
"bxo": u"Barikanchi",
"bxn": u"Burduna",
"bxa": u"Bauro",
"bxc": u"Molengue",
"bxe": u"Birale",
"bxd": u"Pela",
"bxg": u"Bangala",
"bxf": u"Bilur",
"rro": u"Waima",
"rri": u"Ririo",
"cfd": u"Cara",
"cfa": u"Dijim-Bwilim",
"ibg": u"Ibanag",
"bde": u"Bade",
"bdd": u"Bunama",
"bdg": u"Bonggi",
"bdf": u"Biage",
"bda": u"Bayot",
"bdc": u"Emberá-Baudó",
"bdb": u"Basap",
"bdm": u"Buduma",
"bdo": u"Morom",
"bdn": u"Baldemu",
"bdi": u"Burun",
"bdk": u"Budukh",
"bdj": u"Bai",
"bdu": u"Oroko",
"bdt": u"Bokoto",
"bdw": u"Baham",
"bdq": u"Bahnar",
"bdp": u"Bende",
"bds": u"Burunge",
"uln": u"Unserdeutsch",
"bdy": u"Bandjalang",
"bdx": u"Budong-Budong",
"bdz": u"Badeshi",
"ymp": u"Yamap",
"sav": u"Saafi-Saafi",
"ozm": u"Koonzime",
"yms": u"Mysian",
"tft": u"Ternate",
"hka": u"Kahe",
"ibr": u"Ibuoro",
"hke": u"Hunde",
"ibu": u"Ibu",
"tcx": u"Toda",
"wim": u"Wik-Mungkan",
"apz": u"Safeyoka",
"apx": u"Aputai",
"apy": u"Apalaí",
"spy": u"Sabaot",
"apr": u"Arop-Lokep",
"aps": u"Arop-Sissano",
"app": u"Apma",
"apq": u"A-Pucikwar",
"apv": u"Alapmunte",
"apt": u"Apatani",
"apu": u"Apurinã",
"aph": u"Athpariya",
"api": u"Apiaká",
"apn": u"Apinayé",
"apo": u"Ambul",
"apb": u"Sa'a",
"apg": u"Ampanang",
"ape": u"Bukiyip",
"yma": u"Yamphe",
"usa": u"Usarufa",
"usk": u"Usaghade",
"usi": u"Usui",
"syr": u"Syriac",
"ymb": u"Yambes",
"fer": u"Feroge",
"wik": u"Wikalkan",
"yme": u"Yameo",
"spr": u"Saparua",
"ymg": u"Yamongeri",
"spu": u"Sapuan",
"wij": u"Wik-Iiyanh",
"spv": u"Sambalpuri",
"ymh": u"Mili",
"ymk": u"Makwe",
"spi": u"Saponi",
"swo": u"Shanenawa",
"spg": u"Sian",
"wii": u"Minidien",
"spk": u"Sengo",
"tat": u"Tatar",
"tav": u"Tatuyo",
"taw": u"Tai",
"tap": u"Taabwa",
"taq": u"Tamasheq",
"tcy": u"Tulu",
"tax": u"Tamki",
"tay": u"Atayal",
"taz": u"Tocho",
"tad": u"Tause",
"tae": u"Tariana",
"taf": u"Tapirapé",
"tag": u"Tagoi",
"tab": u"Tabassaran",
"spa": u"Spanish",
"tal": u"Tal",
"tam": u"Tamil",
"tan": u"Tangale",
"tao": u"Yami",
"tah": u"Tahitian",
"tak": u"Tala",
"dwr": u"Dawro",
"siq": u"Sonia",
"sip": u"Sikkimese",
"siw": u"Siwai",
"dww": u"Dawawa",
"siu": u"Sinagen",
"krk": u"Kerek",
"siy": u"Sivandi",
"six": u"Sumau",
"sic": u"Malinguat",
"sib": u"Sebop",
"dwa": u"Diri",
"sig": u"Paasaal",
"sif": u"Siamou",
"sie": u"Simaa",
"sid": u"Sidamo",
"sik": u"Sikiana",
"sij": u"Numbami",
"sih": u"Zire",
"sin": u"Sinhala",
"tcn": u"Tichurong",
"xqa": u"Karakhanid",
"twl": u"Tawara",
"xqt": u"Qatabanian",
"jns": u"Jaunsari",
"kbh": u"Camsá",
"kbi": u"Kaptiau",
"kbo": u"Keliko",
"kbl": u"Kanembu",
"kbm": u"Iwal",
"kbb": u"Kaxuiâna",
"kbc": u"Kadiwéu",
"kba": u"Kalarko",
"kbf": u"Kakauhua",
"kbg": u"Khamba",
"kbd": u"Kabardian",
"kbe": u"Kanju",
"kbz": u"Duhwa",
"jna": u"Jangshung",
"jng": u"Yangman",
"xpn": u"Kapinawá",
"jnd": u"Jandavra",
"kbr": u"Kafa",
"jnj": u"Yemsa",
"jni": u"Janji",
"kbq": u"Kamano",
"kbw": u"Kaiep",
"kbt": u"Abadi",
"jnl": u"Rawat",
"byz": u"Banaro",
"byx": u"Qaqet",
"byy": u"Buya",
"byv": u"Medumba",
"byw": u"Belhariya",
"byt": u"Berti",
"byu": u"Buyang",
"byr": u"Baruya",
"bys": u"Burak",
"byp": u"Bumaji",
"byq": u"Basay",
"byn": u"Bilin",
"byo": u"Biyo",
"byl": u"Bayono",
"bym": u"Bidyara",
"byk": u"Biao",
"byh": u"Bhujel",
"byi": u"Buyu",
"byf": u"Bete",
"byg": u"Baygo",
"byd": u"Benyadu'",
"bye": u"Pouye",
"byb": u"Bikya",
"byc": u"Ubaghara",
"bya": u"Batak",
"nym": u"Nyamwezi",
"rau": u"Raute",
"nfg": u"Nyeng",
"nfd": u"Ahwai",
"nfa": u"Dhao",
"nfl": u"Ayiwo",
"nfk": u"Shakara",
"tnh": u"Maiani",
"nfu": u"Mfumte",
"nfr": u"Nafaanra",
"wgi": u"Wahgi",
"oun": u"!O!ung",
"oum": u"Ouma",
"pqa": u"Pa'a",
"oub": u"Glio-Oubi",
"snd": u"Sindhi",
"oue": u"Oune",
"snb": u"Sebuyau",
"hle": u"Hlersu",
"hlb": u"Halbi",
"hla": u"Halia",
"sna": u"Shona",
"snn": u"Siona",
"sno": u"Snohomish",
"pqm": u"Malecite-Passamaquoddy",
"ecr": u"Eteocretan",
"ecy": u"Eteocypriot",
"lts": u"Tachoni",
"snv": u"Sa'ban",
"tcg": u"Tamagario",
"ltu": u"Latu",
"pig": u"Pisabo",
"ltz": u"Luxembourgish",
"vam": u"Vanimo",
"snu": u"Senggi",
"ltg": u"Latgalian",
"snr": u"Sihan",
"lto": u"Tsotso",
"ltn": u"Latundê",
"tpu": u"Tampuan",
"tcd": u"Tafi",
"snp": u"Siane",
"ykr": u"Yekora",
"vaf": u"Vafsi",
"set": u"Sentani",
"snz": u"Sinsauru",
"mal": u"Malayalam",
"snx": u"Sam",
"sny": u"Saniyo-Hiyewe",
"xuf": u"Kunfal",
"vid": u"Vidunda",
"ydk": u"Yoidik",
"rsb": u"Romano-Serbian",
"cyb": u"Cayubaba",
"cyo": u"Cuyonon",
"cym": u"Welsh",
"bej": u"Beja",
"bek": u"Bebeli",
"beh": u"Biali",
"bei": u"Bekati'",
"ben": u"Bengali",
"beo": u"Beami",
"bel": u"Belarusian",
"beb": u"Bebele",
"bec": u"Iceve-Maci",
"sok": u"Sokoro",
"bea": u"Beaver",
"bef": u"Benabena",
"beg": u"Belait",
"bed": u"Bedoanas",
"bee": u"Byangsi",
"ybi": u"Yamphu",
"ybl": u"Yukuben",
"ybm": u"Yaben",
"ybn": u"Yabaâna",
"ybo": u"Yabong",
"bes": u"Besme",
"bep": u"Besoa",
"beq": u"Beembe",
"bew": u"Betawi",
"beu": u"Blagar",
"soj": u"Soi",
"iba": u"Iban",
"xrm": u"Armazic",
"xrn": u"Arin",
"xre": u"Kreye",
"xra": u"Krahô",
"ybj": u"Hasha",
"xru": u"Marriammu",
"xrt": u"Aranama-Tamique",
"xrw": u"Karawa",
"ibb": u"Ibibio",
"xrr": u"Raetic",
"pyy": u"Pyen",
"sol": u"Solos",
"wha": u"Manusela",
"awx": u"Awara",
"aww": u"Awun",
"awt": u"Araweté",
"awr": u"Awera",
"awo": u"Awak",
"awn": u"Awngi",
"awm": u"Arawum",
"awk": u"Awabakal",
"pym": u"Fyam",
"awi": u"Aekyom",
"awh": u"Awbono",
"awg": u"Anguthimri",
"awe": u"Awetí",
"awc": u"Cicipu",
"awa": u"Awadhi",
"urd": u"Urdu",
"ure": u"Uru",
"soo": u"Songo",
"urg": u"Urigina",
"ura": u"Urarina",
"urb": u"Urubú-Kaapor",
"urc": u"Urningangg",
"url": u"Urali",
"urm": u"Urapmin",
"urn": u"Uruangnirin",
"urh": u"Urhobo",
"uri": u"Urim",
"urt": u"Urat",
"uru": u"Urumi",
"urv": u"Uruava",
"urw": u"Sop",
"urp": u"Uru-Pa-In",
"urr": u"Lehalurup",
"ibd": u"Iwaidja",
"urx": u"Urimo",
"ury": u"Orya",
"urz": u"Uru-Eu-Wau-Wau",
"ttz": u"Tsum",
"tty": u"Sikaritai",
"zka": u"Kaimbulawa",
"ibe": u"Akpes",
"wor": u"Woria",
"nge": u"Ngemba",
"nga": u"Ngbaka",
"ngl": u"Lomwe",
"ngn": u"Ngwo",
"ngo": u"Ngoni",
"ngh": u"N/u",
"ngi": u"Ngizim",
"ngj": u"Ngie",
"ngk": u"Ngalkbun",
"ngt": u"Ngeq",
"ngv": u"Nagumi",
"ngw": u"Ngwaba",
"ngp": u"Ngulu",
"ngq": u"Ngurimi",
"ngr": u"Engdewu",
"ngs": u"Gvoko",
"ngx": u"Nggwahyi",
"ngy": u"Tibea",
"ngz": u"Ngungwel",
"mgc": u"Morokodo",
"mgb": u"Mararit",
"tbz": u"Ditammari",
"mgg": u"Mpumpong",
"mgf": u"Maklew",
"mge": u"Mango",
"mgd": u"Moru",
"mgk": u"Mawes",
"mgj": u"Abureni",
"mgi": u"Lijili",
"mgh": u"Makhuwa-Meetto",
"mgo": u"Meta'",
"mgn": u"Mbangi",
"mgm": u"Mambae",
"mgl": u"Maleu-Kilenge",
"mgr": u"Mambwe-Lungu",
"mgq": u"Malila",
"mgw": u"Matumbi",
"mgv": u"Matengo",
"mgu": u"Mailu",
"mgt": u"Mongol",
"tba": u"Aikanã",
"mgz": u"Mbugwe",
"mgy": u"Mbunga",
"mgx": u"Omati",
"tbe": u"Tanimbili",
"tbf": u"Mandara",
"shp": u"Shipibo-Conibo",
"shq": u"Sala",
"shr": u"Shi",
"shs": u"Shuswap",
"sht": u"Shasta",
"shv": u"Shehri",
"dpp": u"Papar",
"shx": u"She",
"shy": u"Tachawit",
"sha": u"Shall-Zwall",
"kwz": u"Kwadi",
"shc": u"Sonde",
"she": u"Sheko",
"shg": u"Shua",
"shh": u"Shoshoni",
"shj": u"Shatt",
"shk": u"Shilluk",
"shl": u"Shendu",
"shm": u"Shahrudi",
"shn": u"Shan",
"sho": u"Shanga",
"ebg": u"Ebughu",
"ebo": u"Teke-Ebo",
"ebu": u"Embu",
"ebr": u"Ebrié",
"lup": u"Lumbu",
"luq": u"Lucumi",
"lur": u"Laura",
"lus": u"Lushai",
"dlg": u"Dolgan",
"luu": u"Lumba-Yakkha",
"luv": u"Luwati",
"luy": u"Luyia",
"dln": u"Darlong",
"dlm": u"Dalmatian",
"ttf": u"Tuotomb",
"lua": u"Luba-Lulua",
"lub": u"Luba-Katanga",
"luc": u"Aringa",
"lud": u"Ludian",
"lue": u"Luvale",
"luf": u"Laua",
"lug": u"Ganda",
"lui": u"Luiseno",
"luj": u"Luna",
"luk": u"Lunanakha",
"lul": u"Olu'bo",
"lum": u"Luimbi",
"lun": u"Lunda",
"keo": u"Kakwa",
"ken": u"Kenyang",
"jor": u"Jorá",
"kek": u"Kekchí",
"kej": u"Kadar",
"kei": u"Kei",
"jow": u"Jowulu",
"keg": u"Tese",
"kef": u"Kpessi",
"ked": u"Kerewe",
"kec": u"Keiga",
"keb": u"Kélé",
"kea": u"Kabuverdianu",
"job": u"Joba",
"jie": u"Jilbe",
"jod": u"Wojenaka",
"kez": u"Kukele",
"key": u"Kupia",
"kex": u"Kukna",
"jib": u"Jibu",
"keu": u"Akebu",
"ket": u"Ket",
"kes": u"Kugbo",
"ker": u"Kera",
"keq": u"Kamar",
"kep": u"Kaikadi",
"rjg": u"Rajong",
"udj": u"Ujir",
"rpt": u"Rapting",
"rpn": u"Repanbitip",
"bbn": u"Uneapa",
"bbm": u"Babango",
"bbl": u"Bats",
"bbk": u"Babanki",
"bbj": u"Ghomálá'",
"bbi": u"Barombi",
"bbh": u"Bugan",
"bbg": u"Barama",
"bbf": u"Baibai",
"bbe": u"Bangba",
"bbd": u"Bau",
"bbb": u"Barai",
"bba": u"Baatonum",
"yar": u"Yabarana",
"yam": u"Yamba",
"yal": u"Yalunka",
"yao": u"Yao",
"yai": u"Yagnobi",
"bby": u"Befang",
"bbx": u"Bubia",
"bbw": u"Baba",
"bbv": u"Karnai",
"bbt": u"Mburku",
"bbs": u"Bakpinka",
"bbr": u"Girawa",
"bbq": u"Bamali",
"oti": u"Oti",
"hmt": u"Hamtai",
"hmu": u"Hamap",
"hmr": u"Hmar",
"hmn": u"Hmong",
"hmj": u"Ge",
"hmk": u"Maek",
"pix": u"Piu",
"piy": u"Piya-Kwonci",
"piz": u"Pije",
"rjb": u"Rajbanshi",
"myl": u"Moma",
"wkl": u"Kalanadi",
"nom": u"Nocamán",
"avt": u"Au",
"avu": u"Avokaya",
"avv": u"Avá-Canoeiro",
"wkb": u"Kumbaran",
"wkd": u"Wakde",
"avs": u"Aushiri",
"avm": u"Angkamuthi",
"avn": u"Avatime",
"avo": u"Agavotaguerra",
"sbv": u"Sabine",
"avi": u"Avikam",
"ncm": u"Nambo",
"avk": u"Kotava",
"avd": u"Alviri-Vidari",
"ave": u"Avestan",
"wku": u"Kunduvadi",
"ava": u"Avaric",
"avb": u"Avau",
"fkk": u"Kirya-Konzəl",
"tjg": u"Tunjung",
"piu": u"Pintupi-Luritja",
"sbw": u"Simba",
"piv": u"Pileni",
"piw": u"Pimbwe",
"mzt": u"Mintil",
"mzu": u"Inapang",
"mzv": u"Manza",
"mzw": u"Deg",
"mzp": u"Movima",
"mzr": u"Marúbo",
"mzs": u"Macanese",
"mzx": u"Mawayana",
"mzz": u"Maiadomu",
"mzd": u"Malimba",
"ksn": u"Kasiguranin",
"mzf": u"Aiku",
"mzb": u"Tumzabt",
"mzm": u"Mumuye",
"mzn": u"Mazanderani",
"mzo": u"Matipuhy",
"jpr": u"Judeo-Persian",
"mzj": u"Manya",
"tdq": u"Tita",
"ksi": u"Krisa",
"zyp": u"Zyphe",
"mfb": u"Bangka",
"mfc": u"Mba",
"mfd": u"Mendankwe-Nkwen",
"mfe": u"Morisyen",
"mff": u"Naki",
"mfg": u"Mixifore",
"mfh": u"Matal",
"mfi": u"Wandala",
"mfj": u"Mefele",
"mfl": u"Putai",
"ksh": u"Kölsch",
"mfo": u"Mbe",
"mfq": u"Moba",
"mfr": u"Marithiel",
"mft": u"Mokerang",
"mfu": u"Mbwela",
"mfv": u"Mandjak",
"mfw": u"Mulaha",
"mfx": u"Melo",
"mfy": u"Mayo",
"mfz": u"Mabaan",
"tcb": u"Tanacross",
"tca": u"Ticuna",
"sku": u"Sakao",
"skt": u"Sakata",
"skq": u"Sininkere",
"skp": u"Sekapan",
"sks": u"Maia",
"skr": u"Seraiki",
"tgu": u"Tanggu",
"sky": u"Sikaiana",
"skz": u"Sekar",
"skf": u"Sakirabiá",
"ska": u"Skagit",
"skb": u"Saek",
"skm": u"Kutong",
"skl": u"Selako",
"ski": u"Sika",
"skh": u"Sikule",
"skk": u"Sok",
"yyz": u"Ayizi",
"sbx": u"Seberuang",
"xsr": u"Sherpa",
"xss": u"Assan",
"xsp": u"Silopi",
"xsq": u"Makhuwa-Saka",
"xsv": u"Sudovian",
"sby": u"Soli",
"xsu": u"Sanumá",
"xsy": u"Saisiyat",
"xsb": u"Sambal",
"xsc": u"Scythian",
"tga": u"Sagalla",
"xsd": u"Sidetic",
"xse": u"Sempan",
"xsj": u"Subi",
"xsk": u"Sakan",
"xsh": u"Shamang",
"xsi": u"Sio",
"xso": u"Solano",
"tgg": u"Tangga",
"kdl": u"Tsikimba",
"kdm": u"Kagoma",
"kdn": u"Kunda",
"kdh": u"Tem",
"kdi": u"Kumam",
"kdk": u"Numee",
"kdd": u"Yankunytjatjara",
"kde": u"Makonde",
"kdf": u"Mamusi",
"kdg": u"Seba",
"kda": u"Worimi",
"kdc": u"Kutu",
"jle": u"Ngile",
"kdx": u"Kam",
"kdy": u"Keder",
"kdz": u"Kwaja",
"kdt": u"Kuy",
"kdu": u"Kadaru",
"kdv": u"Kado",
"kdw": u"Koneraw",
"kdp": u"Kaningdon-Nindem",
"kdq": u"Koch",
"kdr": u"Karaim",
"tgi": u"Lawunuia",
"swi": u"Sui",
"snc": u"Sinaugoro",
"swj": u"Sira",
"swm": u"Samosa",
"ndh": u"Ndali",
"ndk": u"Ndaka",
"ndj": u"Ndamba",
"ndm": u"Ndam",
"ndl": u"Ndolo",
"ndo": u"Ndonga",
"ndn": u"Ngundi",
"nda": u"Ndasa",
"ndc": u"Ndau",
"ndd": u"Nde-Nsele-Nta",
"ndg": u"Ndengereko",
"ndf": u"Nadruvian",
"ndy": u"Lutos",
"ndx": u"Nduga",
"ndz": u"Ndogo",
"ndq": u"Ndombe",
"ndp": u"Ndo",
"ndr": u"Ndoola",
"ndu": u"Dugun",
"ndt": u"Ndunga",
"ndw": u"Ndobo",
"ndv": u"Ndut",
"scl": u"Shina",
"owi": u"Owiniga",
"swe": u"Swedish",
"swg": u"Swabian",
"swf": u"Sere",
"swy": u"Sarua",
"vah": u"Varhadi-Nagpuri",
"vai": u"Vai",
"van": u"Valman",
"vao": u"Vao",
"val": u"Vehes",
"swx": u"Suruahá",
"sys": u"Sinyar",
"vag": u"Vagla",
"vae": u"Vale",
"vay": u"Wayu",
"var": u"Huarijio",
"vas": u"Vasavi",
"vap": u"Vaiphei",
"vav": u"Varli",
"vau": u"Vanuma",
"xao": u"Khao",
"swq": u"Sharwa",
"swp": u"Suau",
"ppo": u"Folopa",
"hne": u"Chhattisgarhi",
"sws": u"Seluwasan",
"lvu": u"Levuka",
"dma": u"Duma",
"dmc": u"Dimir",
"dme": u"Dugwor",
"swu": u"Suwawa",
"dmk": u"Domaaki",
"dml": u"Dameli",
"dmm": u"Dama",
"dmo": u"Kemedzung",
"hni": u"Hani",
"dms": u"Dampelas",
"lva": u"Maku'a",
"dmu": u"Dubu",
"dmv": u"Dumpas",
"hnh": u"//Ani",
"dmx": u"Dema",
"dmy": u"Demta",
"swv": u"Shekhawati",
"lvk": u"Lavukaleve",
"myy": u"Macuna",
"myx": u"Masaaba",
"myp": u"Pirahã",
"mys": u"Mesmes",
"myr": u"Muniche",
"myu": u"Mundurukú",
"myw": u"Muyuw",
"myv": u"Erzya",
"myh": u"Makah",
"myj": u"Mangayat",
"mym": u"Me'en",
"myo": u"Anfillo",
"mya": u"Burmese",
"myc": u"Mayeka",
"hnn": u"Hanunoo",
"mye": u"Myene",
"myd": u"Maramba",
"myg": u"Manta",
"myf": u"Bambassi",
"nrm": u"Narom",
"nrl": u"Ngarluma",
"nrc": u"Noric",
"tye": u"Kyenga",
"nrb": u"Nara",
"tkk": u"Takpa",
"hnu": u"Hung",
"nra": u"Ngom",
"nrg": u"Narango",
"bcm": u"Bannoni",
"bco": u"Kaluli",
"bch": u"Bariai",
"bci": u"Baoulé",
"bcj": u"Bardi",
"bck": u"Bunaba",
"bce": u"Bamenyam",
"bcf": u"Bamu",
"sbj": u"Surbakhal",
"bcb": u"Bainouk-Samik",
"nrx": u"Ngurmbur",
"bcx": u"Pamona",
"bcy": u"Bacama",
"bcz": u"Bainouk-Gunyaamolo",
"bct": u"Bendi",
"bcv": u"Shoo-Minda-Nye",
"bcw": u"Bana",
"bcq": u"Bench",
"bcr": u"Babine",
"bcs": u"Kohumono"
}

ISO639_3_2 = {
"auf": u"Arauan languages",
"aum": u"Asu (Nigeria)",
"aun": u"Molmo One",
"aus": u"Australian languages",
"xtm": u"Magdalena Peñasco Mixtec",
"auz": u"Uzbeki Arabic",
"xtj": u"San Juan Teita Mixtec",
"xti": u"Sinicahua Mixtec",
"xyy": u"Yorta Yorta",
"tmv": u"Tembo (Motembo)",
"sbn": u"Sindhi Bhil",
"neb": u"Toura (Côte d'Ivoire)",
"nea": u"Eastern Ngad'a",
"mlq": u"Western Maninkakan",
"nez": u"Nez Perce",
"nes": u"Bhoti Kinnauri",
"nep": u"Nepali (macrolanguage)",
"mel": u"Central Melanau",
"meo": u"Kedah Malay",
"men": u"Mende (Sierra Leone)",
"meh": u"Southwestern Tlaxiaco Mixtec",
"xts": u"Sindihui Mixtec",
"mly": u"Malay (individual language)",
"sjs": u"Senhaja De Srair",
"sju": u"Ume Sami",
"dro": u"Daro-Matu Melanau",
"drn": u"West Damar",
"dra": u"Dravidian languages",
"sje": u"Pite Sami",
"txn": u"West Tarangan",
"txb": u"Tokharian B",
"xty": u"Yoloxochitl Mixtec",
"txy": u"Tanosy Malagasy",
"dna": u"Upper Grand Valley Dani",
"dni": u"Lower Grand Valley Dani",
"dnt": u"Mid Grand Valley Dani",
"dnw": u"Western Dani",
"lwl": u"Eastern Lawa",
"lwe": u"Lewo Eleng",
"jmx": u"Western Juxtlahuaca Mixtec",
"kgw": u"Karon Dori",
"jms": u"Mashi (Nigeria)",
"jmi": u"Jimi (Nigeria)",
"jmn": u"Makuri Naga",
"xtl": u"Tijaltepec Mixtec",
"quy": u"Ayacucho Quechua",
"ygl": u"Yangum Gel",
"czt": u"Zotung Chin",
"czh": u"Huizhou Chinese",
"czn": u"Zenzontepec Chatino",
"czo": u"Min Zhong Chinese",
"hob": u"Mari (Madang Province)",
"hok": u"Hokan languages",
"hos": u"Ho Chi Minh City Sign Language",
"tdg": u"Western Tamang",
"wuu": u"Wu Chinese",
"fit": u"Tornedalen Finnish",
"fiu": u"Finno-Ugrian languages",
"zai": u"Isthmus Zapotec",
"zaf": u"Ayoquesco Zapotec",
"zae": u"Yareni Zapotec",
"mxz": u"Central Masela",
"mxy": u"Southeastern Nochixtlán Mixtec",
"mxv": u"Metlatónoc Mixtec",
"mxt": u"Jamiltepec Mixtec",
"mxu": u"Mada (Cameroon)",
"mxr": u"Murik (Malaysia)",
"mxs": u"Huitepec Mixtec",
"mxp": u"Tlahuitoltepec Mixe",
"mxq": u"Juquila Mixe",
"mxn": u"Moi (Indonesia)",
"mxl": u"Maxi Gbe",
"mxb": u"Tezoatlán Mixtec",
"mxa": u"Northwest Oaxaca Mixtec",
"mdo": u"Southwest Gbaya",
"mdl": u"Maltese Sign Language",
"mdc": u"Male (Papua New Guinea)",
"mda": u"Mada (Nigeria)",
"mde": u"Maba (Chad)",
"mdz": u"Suruí Do Pará",
"mdy": u"Male (Ethiopia)",
"zaw": u"Mitla Zapotec",
"mds": u"Maria (Papua New Guinea)",
"mdv": u"Santa Lucía Monteverde Mixtec",
"sms": u"Skolt Sami",
"dsl": u"Danish Sign Language",
"sml": u"Central Sama",
"smj": u"Lule Sami",
"sme": u"Northern Sami",
"dse": u"Dutch Sign Language",
"dsb": u"Lower Sorbian",
"sma": u"Southern Sami",
"yig": u"Wusa Nasu",
"sym": u"Maya Samo",
"atg": u"Ivbie North-Okpela-Arhe",
"atd": u"Ata Manobo",
"atl": u"Mt. Iraya Agta",
"ath": u"Athapascan languages",
"atv": u"Northern Altai",
"att": u"Pamplona Atta",
"ats": u"Gros Ventre",
"atp": u"Pudtol Atta",
"kfw": u"Kharam Naga",
"kfx": u"Kullu Pahari",
"kfd": u"Korra Koraga",
"kfe": u"Kota (India)",
"kfb": u"Northwestern Kolami",
"kfo": u"Koro (Côte d'Ivoire)",
"kfi": u"Kannada Kurumba",
"xiv": u"Indus Valley Language",
"gya": u"Northwest Gbaya",
"gyn": u"Guyanese Creole English",
"nzs": u"New Zealand Sign Language",
"nzz": u"Nanga Dama Dogon",
"yix": u"Axi Yi",
"nza": u"Tigon Mbembe",
"nzm": u"Zeme Naga",
"pnz": u"Pana (Central African Republic)",
"pnq": u"Pana (Burkina Faso)",
"tyl": u"Thu Lao",
"tyj": u"Tai Do",
"nrp": u"North Picene",
"pnu": u"Jiongnai Bunu",
"tyt": u"Tày Tac",
"tyr": u"Tai Daeng",
"tys": u"Tày Sa Pa",
"doi": u"Dogri (macrolanguage)",
"don": u"Toura (Papua New Guinea)",
"doc": u"Northern Dong",
"lpn": u"Long Phuri Naga",
"doq": u"Dominican Sign Language",
"wob": u"Wè Northern",
"ztm": u"San Agustín Mixtepec Zapotec",
"ztl": u"Lapaguía-Guivini Zapotec",
"ztn": u"Santa Catarina Albarradas Zapotec",
"zte": u"Elotepec Zapotec",
"pne": u"Western Penan",
"ztg": u"Xanaguía Zapotec",
"ztc": u"Lachirioag Zapotec",
"zty": u"Yatee Zapotec",
"ztu": u"Güilá Zapotec",
"ztt": u"Tejalapan Zapotec",
"ztq": u"Quioquitani-Quierí Zapotec",
"ztp": u"Loxicha Zapotec",
"zts": u"Tilquiapan Zapotec",
"bat": u"Baltic languages",
"bau": u"Bada (Nigeria)",
"bas": u"Basa (Cameroon)",
"bad": u"Banda languages",
"bah": u"Bahamas Creole English",
"bai": u"Bamileke languages",
"iro": u"Iroquoian languages",
"ira": u"Iranian languages",
"omb": u"East Ambae",
"omr": u"Old Marathi",
"omq": u"Oto-Manguean languages",
"omp": u"Old Manipuri",
"omw": u"South Tairora",
"omv": u"Omotic languages",
"omx": u"Old Mon",
"unz": u"Unde Kaili",
"una": u"North Watut",
"gxx": u"Wè Southern",
"frc": u"Cajun French",
"fri": u"Western Frisian",
"fro": u"Old French (842-ca. 1400)",
"frm": u"Middle French (ca. 1400-1600)",
"frs": u"Eastern Frisian",
"frr": u"Northern Frisian",
"ted": u"Tepo Krumen",
"fry": u"Western Frisian",
"pro": u"Old Provençal (to 1500)",
"mco": u"Coatlán Mixe",
"mcm": u"Malaccan Creole Portuguese",
"mce": u"Itundujia Mixtec",
"glj": u"Gula Iro",
"mcy": u"South Watut",
"mcw": u"Mawa (Chad)",
"mcu": u"Cameroon Mambila",
"sls": u"Singapore Sign Language",
"slh": u"Southern Puget Sound Salish",
"gla": u"Scottish Gaelic",
"prq": u"Ashéninka Perené",
"slf": u"Swiss-Italian Sign Language",
"slg": u"Selungai Murut",
"slb": u"Kahumamahon Saluan",
"tzs": u"San Andrés Larrainzar Tzotzil",
"glc": u"Bon Gula",
"tzu": u"Huixtán Tzotzil",
"qwm": u"Kuman (Russia)",
"tza": u"Tanzanian Sign Language",
"tzb": u"Bachajón Tzeltal",
"tze": u"Chenalhó Tzotzil",
"sjt": u"Ter Sami",
"tzm": u"Central Atlas Tamazight",
"pry": u"Pray 3",
"dha": u"Dhanwar (India)",
"dhw": u"Dhanwar (Nepal)",
"kix": u"Khiamniungan Naga",
"kip": u"Sheshi Kham",
"jkp": u"Paku Karen",
"jkr": u"Koro (India)",
"jkm": u"Mobwa Karen",
"glu": u"Gula (Chad)",
"zoh": u"Chimalapa Zoque",
"bnt": u"Bantu languages",
"bnj": u"Eastern Tawbuid",
"bnd": u"Banda (Indonesia)",
"ope": u"Old Persian",
"whu": u"Wahau Kayan",
"fox": u"Formosan languages",
"umn": u"Makyan Naga",
"tek": u"Ibali Teke",
"sng": u"Sanga (Democratic Republic of Congo)",
"mbo": u"Mbo (Cameroon)",
"mbi": u"Ilianen Manobo",
"mbd": u"Dibabawon Manobo",
"mbf": u"Baba Malay",
"mbg": u"Northern Nambikuára",
"mbb": u"Western Bukidnon Manobo",
"mbx": u"Mari (East Sepik Province)",
"mbz": u"Amoltepec Mixtec",
"mbt": u"Matigsalug Manobo",
"mbr": u"Nukak Makú",
"mbs": u"Sarangani Manobo",
"lwh": u"White Lachi",
"ntp": u"Northern Tepehuan",
"azj": u"North Azerbaijani",
"azm": u"Ipalapa Amuzgo",
"azn": u"Western Durango Nahuatl",
"azb": u"South Azerbaijani",
"azc": u"Uto-Aztecan languages",
"azd": u"Eastern Durango Nahuatl",
"azg": u"San Pedro Amuzgos Amuzgo",
"xwo": u"Written Oirat",
"azz": u"Highland Puebla Nahuatl",
"azt": u"Faire Atta",
"khy": u"Kele (Democratic Republic of Congo)",
"khq": u"Koyra Chiini Songhay",
"khi": u"Khoisan languages",
"khk": u"Halh Mongolian",
"khm": u"Central Khmer",
"khc": u"Tukang Besi North",
"khd": u"Bädi Kanum",
"khg": u"Khams Tibetan",
"xki": u"Kenyan Sign Language",
"xkn": u"Kayan River Kayan",
"xkl": u"Mainstream Kenyah",
"xkb": u"Northern Nago",
"xkd": u"Mendalam Kayan",
"xky": u"Uma' Lasan",
"fse": u"Finnish Sign Language",
"fsl": u"French Sign Language",
"nxd": u"Ngando (Democratic Republic of Congo)",
"fss": u"Finland-Swedish Sign Language",
"nxk": u"Koki Naga",
"osx": u"Old Saxon",
"osp": u"Old Spanish",
"osu": u"Southern One",
"kgi": u"Selangor Sign Language",
"kgh": u"Upper Tanudan Kalinga",
"snm": u"Southern Ma'di",
"kgj": u"Gamale Kham",
"ver": u"Mom Jango",
"lra": u"Rara Bakati'",
"tnu": u"Tay Khang",
"lrc": u"Northern Luri",
"lrr": u"Southern Yamphu",
"lrt": u"Larantuka Malay",
"dik": u"Southwestern Dinka",
"dib": u"South Central Dinka",
"dic": u"Lakota Dida",
"jhs": u"Jhankot Sign Language",
"dix": u"Dixon Reef",
"diw": u"Northwestern Dinka",
"dip": u"Northeastern Dinka",
"diq": u"Dimli (individual language)",
"xuj": u"Jennu Kurumba",
"zra": u"Kara (Korea)",
"qvl": u"Cajatambo North Lima Quechua",
"ydd": u"Eastern Yiddish",
"yde": u"Yangum Dey",
"yds": u"Yiddish Sign Language",
"zac": u"Ocotlán Zapotec",
"boy": u"Bodo (Central African Republic)",
"boz": u"Tiéyaxo Bozo",
"boo": u"Tiemacèwè Bozo",
"boc": u"Bakung Kenyah",
"bog": u"Bamako Sign Language",
"qvn": u"North Junín Quechua",
"ayl": u"Libyan Arabic",
"ayn": u"Sanaani Arabic",
"ayh": u"Hadrami Arabic",
"ayc": u"Southern Aymara",
"ayb": u"Ayizo Gbe",
"ayy": u"Tayabas Ayta",
"ayx": u"Ayi (China)",
"ayz": u"Mai Brat",
"ayt": u"Magbukun Ayta",
"ayq": u"Ayi (Papua New Guinea)",
"ayp": u"North Mesopotamian Arabic",
"ays": u"Sorsogon Ayta",
"ayr": u"Central Aymara",
"ood": u"Tohono O'odham",
"xzp": u"Ancient Zapotec",
"oos": u"Old Ossetic",
"qvi": u"Imbabura Highland Quichua",
"xmv": u"Antankarana Malagasy",
"pye": u"Pye Krumen",
"yxy": u"Yabula Yabula",
"ulu": u"Uma' Lung",
"flm": u"Falam Chin",
"fll": u"North Fali",
"fln": u"Flinders Island",
"fla": u"Kalispel-Pend d'Oreille",
"kxm": u"Northern Khmer",
"fpe": u"Fernando Po Creole English",
"nyr": u"Nyiha (Malawi)",
"nyi": u"Ama (Sudan)",
"maq": u"Chiquihuitlán Mazatec",
"map": u"Austronesian languages",
"mau": u"Huautla Mazatec",
"mat": u"San Francisco Matlatzinca",
"may": u"Malay (macrolanguage)",
"max": u"North Moluccan Malay",
"snj": u"Riverain Sango",
"maa": u"San Jerónimo Tecóatl Mazatec",
"mab": u"Yutanduchi Mixtec",
"maj": u"Jalapa De Díaz Mazatec",
"idd": u"Ede Idaca",
"zna": u"Zan Gula",
"zne": u"Zande (individual language)",
"yli": u"Angguruk Yali",
"ssh": u"Shihhi Arabic",
"lsg": u"Lyons Sign Language",
"lsd": u"Lishana Deni",
"tts": u"Northeastern Thai",
"lso": u"Laos Sign Language",
"lsl": u"Latvian Sign Language",
"ttw": u"Long Wat",
"kxp": u"Wadiyara Koli",
"lst": u"Trinidad and Tobago Sign Language",
"tth": u"Upper Ta'oih",
"lsp": u"Panamanian Sign Language",
"lsy": u"Mauritian Sign Language",
"jim": u"Jimi (Cameroon)",
"djc": u"Dar Daju Daju",
"djk": u"Eastern Maroon Creole",
"djm": u"Jamsay Dogon",
"kkl": u"Kosarek Yale",
"kkn": u"Kon Keu",
"kkg": u"Mabaka Valley Kalinga",
"kkf": u"Kalaktang Monpa",
"xlo": u"Loup A",
"kmm": u"Kom (India)",
"xlg": u"Ligurian (Ancient)",
"xlb": u"Loup B",
"xlu": u"Cuneiform Luwian",
"kmk": u"Limos Kalinga",
"blx": u"Mag-Indi Ayta",
"blu": u"Hmong Njua",
"blt": u"Tai Dam",
"blm": u"Beli (Sudan)",
"bln": u"Southern Catanduanes Bikol",
"blk": u"Pa'o Karen",
"blc": u"Bella Coola",
"xpk": u"Kulina Pano",
"ory": u"Oriya (individual language)",
"orv": u"Old Russian",
"orw": u"Oro Win",
"ort": u"Adivasi Oriya",
"ors": u"Orang Seletar",
"orn": u"Orang Kanaq",
"ori": u"Oriya (macrolanguage)",
"tbt": u"Tembo (Kitembo)",
"onk": u"Kabore One",
"onx": u"Onin Based Pidgin",
"onr": u"Northern One",
"onw": u"Old Nubian",
"fmu": u"Far Western Muria",
"uks": u"Urubú-Kaapor Sign Language",
"ukl": u"Ukrainian Sign Language",
"rmc": u"Carpathian Romani",
"rmf": u"Kalo Finnish Romani",
"rmg": u"Traveller Norwegian",
"sai": u"South American Indian languages",
"sam": u"Samaritan Aramaic",
"sal": u"Salishan languages",
"zoc": u"Copainalá Zoque",
"rmn": u"Balkan Romani",
"zoo": u"Asunción Mixtepec Zapotec",
"zoq": u"Tabasco Zoque",
"zor": u"Rayón Zoque",
"zos": u"Francisco León Zoque",
"rml": u"Baltic Romani",
"xtu": u"Cuyamecalco Mixtec",
"sjk": u"Kemi Sami",
"iws": u"Sepik Iwam",
"axg": u"Mato Grosso Arára",
"axk": u"Yaka (Central African Republic)",
"axm": u"Middle Armenian",
"pwo": u"Pwo Western Karen",
"xml": u"Malaysian Sign Language",
"xmm": u"Manado Malay",
"xmn": u"Manichaean Middle Persian",
"xmk": u"Ancient Macedonian",
"xmz": u"Mori Bawah",
"xmw": u"Tsimihety Malagasy",
"xms": u"Moroccan Sign Language",
"wem": u"Weme Gbe",
"gec": u"Gboloo Grebo",
"geh": u"Hutterite German",
"gen": u"Geman Deng",
"gem": u"Germanic languages",
"vky": u"Kayu Agung",
"vkp": u"Korlai Creole Portuguese",
"vkt": u"Tenggarong Kutai Malay",
"ima": u"Mala Malasar",
"tup": u"Tupi languages",
"tut": u"Altaic languages",
"tuw": u"Tungus languages",
"tuf": u"Central Tunebo",
"kjc": u"Coastal Konjo",
"dks": u"Southeastern Dinka",
"kjd": u"Southern Kiwai",
"kjk": u"Highland Konjo",
"kjo": u"Harijan Kinnauri",
"kjp": u"Pwo Eastern Karen",
"kjq": u"Western Keres",
"kjt": u"Phrae Pwo Karen",
"dkl": u"Kolum So Dogon",
"zpy": u"Mazaltepec Zapotec",
"zpx": u"San Baltazar Loxicha Zapotec",
"zpz": u"Texmelucan Zapotec",
"zpq": u"Zoogocho Zapotec",
"zps": u"Coatlán Zapotec",
"zpr": u"Santiago Xanica Zapotec",
"zpu": u"Yalálag Zapotec",
"zpt": u"San Vicente Coatlán Zapotec",
"zpw": u"Zaniza Zapotec",
"cqd": u"Chuanqiandian Cluster Miao",
"zpi": u"Santa María Quiegolani Zapotec",
"zph": u"Totomachapan Zapotec",
"zpk": u"Tlacolulita Zapotec",
"zpj": u"Quiavicuzas Zapotec",
"zpm": u"Mixtepec Zapotec",
"zpl": u"Lachixío Zapotec",
"zpo": u"Amatlán Zapotec",
"zpn": u"Santa Inés Yatzechi Zapotec",
"zpa": u"Lachiguiri Zapotec",
"zpc": u"Choapan Zapotec",
"zpb": u"Yautepec Zapotec",
"zpe": u"Petapa Zapotec",
"zpd": u"Southeastern Ixtlán Zapotec",
"cqu": u"Chilean Quechua",
"zpf": u"San Pedro Quiatoni Zapotec",
"bmd": u"Baga Manduri",
"bmn": u"Bina (Papua New Guinea)",
"bmm": u"Northern Betsimisaraka Malagasy",
"bms": u"Bilma Kanuri",
"bmt": u"Biao Mon",
"bmy": u"Bemba (Democratic Republic of Congo)",
"hds": u"Honduras Sign Language",
"sit": u"Sino-Tibetan languages",
"hdn": u"Northern Haida",
"sxu": u"Upper Saxon",
"tkt": u"Kathoriya Tharu",
"kjl": u"Western Parbate Kham",
"kjs": u"East Kewa",
"paa": u"Papuan languages",
"pao": u"Northern Paiute",
"kqs": u"Northern Kissi",
"nag": u"Naga Pidgin",
"kqt": u"Klias River Kadazan",
"gds": u"Ghandruk Sign Language",
"nan": u"Min Nan Chinese",
"gda": u"Gade Lohar",
"gdb": u"Pottangi Ollar Gadaba",
"gdc": u"Gugu Badhun",
"pov": u"Upper Guinea Crioulo",
"naq": u"Nama (Namibia)",
"moq": u"Mor (Bomberai Peninsula)",
"mop": u"Mopán Maya",
"mow": u"Moi (Congo)",
"zle": u"East Slavic languages",
"zlm": u"Malay (individual language)",
"zln": u"Lianshan Zhuang",
"zlj": u"Liujiang Zhuang",
"zlw": u"West Slavic languages",
"zls": u"South Slavic languages",
"tvy": u"Timor Pidgin",
"tvt": u"Tutsa Naga",
"poi": u"Highland Popoluca",
"tvk": u"Southeast Ambrym",
"kmf": u"Kare (Papua New Guinea)",
"kmc": u"Southern Dong",
"dds": u"Donno So Dogon",
"kml": u"Tanudan Kalinga",
"kmi": u"Kami (Nigeria)",
"kmw": u"Komo (Democratic Republic of Congo)",
"ddi": u"West Goodenough",
"ddn": u"Dendi (Benin)",
"dda": u"Dadi Dadi",
"poa": u"Eastern Pokomam",
"kmz": u"Khorasani Turkish",
"acc": u"Cubulco Achí",
"acf": u"Saint Lucian Creole French",
"acm": u"Mesopotamian Arabic",
"acq": u"Ta'izzi-Adeni Arabic",
"acp": u"Eastern Acipa",
"acw": u"Hijazi Arabic",
"acy": u"Cypriot Arabic",
"acx": u"Omani Arabic",
"bjf": u"Barzani Jewish Neo-Aramaic",
"bje": u"Biao-Jiao Mien",
"bjo": u"Mid-Southern Banda",
"bjl": u"Bulu (Papua New Guinea)",
"bjq": u"Southern Betsimisaraka Malagasy",
"zpv": u"Chichicapan Zapotec",
"bjx": u"Banao Itneg",
"hea": u"Northern Qiandong Miao",
"ryn": u"Northern Amami-Oshima",
"znd": u"Zande languages",
"zpg": u"Guevea De Humboldt Zapotec",
"wak": u"Wakashan languages",
"oht": u"Old Hittite",
"ohu": u"Old Hungarian",
"xbm": u"Middle Breton",
"pys": u"Paraguayan Sign Language",
"goo": u"Gone Dau",
"cpi": u"Chinese Pidgin English",
"cpa": u"Palantla Chinantec",
"cpb": u"Ucayali-Yurúa Ashéninka",
"cpc": u"Ajyíninka Apurucayali",
"cpe": u"English based Creoles and pidgins",
"cpf": u"French-Based Creoles and pidgins",
"cpg": u"Cappadocian Greek",
"cpx": u"Pu-Xian Chinese",
"cpy": u"South Ucayali Ashéninka",
"cpp": u"Portuguese-Based Creoles and pidgins",
"cpu": u"Pichis Ashéninka",
"sci": u"Sri Lankan Creole Malay",
"qvm": u"Margos-Yarowilca-Lauricocha Quechua",
"mnp": u"Min Bei Chinese",
"mnr": u"Mono (USA)",
"mnh": u"Mono (Democratic Republic of Congo)",
"mnn": u"Southern Mnong",
"mno": u"Manobo languages",
"mng": u"Eastern Mnong",
"qvj": u"Loja Highland Quichua",
"smn": u"Inari Sami",
"zma": u"Manda (Australia)",
"tji": u"Northern Tujia",
"qve": u"Eastern Apurímac Quechua",
"zmw": u"Mbo (Democratic Republic of Congo)",
"ium": u"Iu Mien",
"smi": u"Sami languages",
"pth": u"Pataxó Hã-Ha-Hãe",
"zsr": u"Southern Rincon Zapotec",
"qvc": u"Cajamarca Quechua",
"pbu": u"Northern Pashto",
"pbs": u"Central Pame",
"pbe": u"Mezontla Popoloca",
"pbf": u"Coyotepec Popoloca",
"ylo": u"Naluo Yi",
"hyx": u"Armenian (family)",
"pbl": u"Mak (Nigeria)",
"pbh": u"E'ñapa Woromaipu",
"qvz": u"Northern Pastaza Quichua",
"abc": u"Ambala Ayta",
"abe": u"Western Abnaki",
"abf": u"Abai Sungai",
"abh": u"Tajiki Arabic",
"abl": u"Lampung Nyo",
"abp": u"Abellen Ayta",
"abs": u"Ambonese Malay",
"abv": u"Baharna Arabic",
"aby": u"Aneme Wake",
"qvs": u"San Martín Quechua",
"ggr": u"Aghu Tharnggalu",
"ggo": u"Southern Gondi",
"ggn": u"Eastern Gurung",
"twb": u"Western Tawbuid",
"knn": u"Konkani (individual language)",
"vic": u"Virgin Islands Creole English",
"twf": u"Northern Tiwa",
"twe": u"Tewa (Indonesia)",
"twh": u"Tai Dón",
"twm": u"Tawang Monpa",
"twr": u"Southwestern Tarahumara",
"rgs": u"Southern Roglai",
"ttq": u"Tawallammat Tamajaq",
"xup": u"Upper Umpqua",
"kle": u"Kulung (Nepal)",
"dep": u"Pidgin Delaware",
"deq": u"Dendi (Central African Republic)",
"klk": u"Kono (Nigeria)",
"den": u"Slave (Athapascan)",
"isr": u"Israeli Sign Language",
"isu": u"Isu (Menchum Division)",
"csm": u"Central Sierra Miwok",
"csl": u"Chinese Sign Language",
"cso": u"Sochiapam Chinantec",
"csn": u"Colombian Sign Language",
"csi": u"Coast Miwok",
"csh": u"Asho Chin",
"cse": u"Czech Sign Language",
"csd": u"Chiangmai Sign Language",
"csg": u"Chilean Sign Language",
"csf": u"Cuba Sign Language",
"csa": u"Chiltepec Chinantec",
"csc": u"Catalan Sign Language",
"csy": u"Siyin Chin",
"csu": u"Central Sudanic languages",
"cst": u"Northern Ohlone",
"csw": u"Swampy Cree",
"csv": u"Sumtu Chin",
"csq": u"Croatia Sign Language",
"css": u"Southern Ohlone",
"csr": u"Costa Rican Sign Language",
"bkc": u"Baka (Cameroon)",
"bkm": u"Kom (Cameroon)",
"bkp": u"Boko (Democratic Republic of Congo)",
"bks": u"Northern Sorsoganon",
"sli": u"Lower Silesian",
"isg": u"Irish Sign Language",
"ise": u"Italian Sign Language",
"slm": u"Pangutaran Sama",
"itm": u"Itu Mbon Uzo",
"iti": u"Inlaod Itneg",
"itb": u"Binongan Itneg",
"itc": u"Italic languages",
"ity": u"Moyadan Itneg",
"itt": u"Maeng Itneg",
"pck": u"Paite Chin",
"pcm": u"Nigerian Pidgin",
"pca": u"Santa Inés Ahuatempan Popoloca",
"pce": u"Ruching Palaung",
"okx": u"Okpe (Northwestern Edo)",
"oke": u"Okpe (Southwestern Edo)",
"okg": u"Koko Babangk",
"okh": u"Koresh-e Rostam",
"okk": u"Kwamtim One",
"okm": u"Middle Korean (10th-16th cent.)",
"okl": u"Old Kentish Sign Language",
"oko": u"Old Korean (3rd-9th cent.)",
"tro": u"Tarao Naga",
"gfx": u"Mangetti Dune !Xung",
"oin": u"Inebu One",
"swc": u"Congo Swahili",
"sbr": u"Sembakung Murut",
"sbp": u"Sangu (Tanzania)",
"mms": u"Southern Mam",
"mmr": u"Western Xiangxi Miao",
"mml": u"Man Met",
"mmo": u"Mangga Buang",
"mmg": u"North Ambrym",
"mmc": u"Michoacán Mazahua",
"tos": u"Highland Totonac",
"tov": u"Upper Taromi",
"kok": u"Konkani (macrolanguage)",
"koj": u"Sara Dunjo",
"kol": u"Kol (Papua New Guinea)",
"jeu": u"Jonkor Bourmataguil",
"koq": u"Kota (Gabon)",
"jek": u"Jeri Kuo",
"aae": u"Arbëreshë Albanian",
"aao": u"Algerian Saharan Arabic",
"aah": u"Abu' Arapesh",
"tog": u"Tonga (Nyasa)",
"aat": u"Arvanitika Albanian",
"aav": u"Austro-Asiatic languages",
"aaq": u"Eastern Abnaki",
"aap": u"Pará Arára",
"aax": u"Mandobo Atas",
"bhk": u"Albay Bicolano",
"bhn": u"Bohtan Neo-Aramaic",
"bhz": u"Bada (Indonesia)",
"yhd": u"Judeo-Iraqi Arabic",
"bhq": u"Tukang Besi South",
"bhr": u"Bara Malagasy",
"tjo": u"Temacine Tamazight",
"tpc": u"Azoyú Me'phaa",
"tpo": u"Tai Pao",
"tpl": u"Tlacoapa Me'phaa",
"tpi": u"Tok Pisin",
"tpt": u"Tlachichilco Tepehua",
"tpp": u"Pisaflores Tepehua",
"scs": u"North Slavey",
"tpx": u"Acatepec Me'phaa",
"ojv": u"Ontong Java",
"ojw": u"Western Ojibwa",
"ojs": u"Severn Ojibwa",
"ojp": u"Old Japanese",
"ojg": u"Eastern Ojibwa",
"ugy": u"Uruguayan Sign Language",
"ojb": u"Northwestern Ojibwa",
"ojc": u"Central Ojibwa",
"crr": u"Carolina Algonquian",
"crs": u"Seselwa Creole French",
"crp": u"Creoles and pidgins",
"crq": u"Iyo'wujwa Chorote",
"crt": u"Iyojwa'ja Chorote",
"crb": u"Island Carib",
"crd": u"Coeur d'Alene",
"crj": u"Southern East Cree",
"crk": u"Plains Cree",
"crh": u"Crimean Tatar",
"crn": u"El Nayar Cora",
"crl": u"Northern East Cree",
"crm": u"Moose Cree",
"sew": u"Sewa Bay",
"sev": u"Nyarafolo Senoufo",
"ses": u"Koyraboro Senni Songhai",
"seq": u"Senara Sénoufo",
"sep": u"Sìcìté Sénoufo",
"sez": u"Senthang Chin",
"sef": u"Cebaara Senoufo",
"seb": u"Shempire Senoufo",
"yzg": u"E'ma Buyang",
"sen": u"Nanerigé Sénoufo",
"sem": u"Semitic languages",
"zkp": u"São Paulo Kaingáng",
"qxa": u"Chiquián Ancash Quechua",
"ike": u"Eastern Canadian Inuktitut",
"pdi": u"Pa Di",
"pdc": u"Pennsylvania German",
"raf": u"Western Meohang",
"xay": u"Kayan Mahakam",
"xaa": u"Andalusian Arabic",
"nri": u"Chokri Naga",
"gaz": u"West Central Oromo",
"gax": u"Borana-Arsi-Guji Oromo",
"gau": u"Mudhili Gadaba",
"gas": u"Adiwasi Garasia",
"gan": u"Gan Chinese",
"gac": u"Mixed Great Andamanese",
"nrt": u"Northern Kalapuya",
"fuv": u"Nigerian Fulfulde",
"mlc": u"Cao Lan",
"fuq": u"Central-Eastern Niger Fulfulde",
"mll": u"Malua Bay",
"fud": u"East Futuna",
"fue": u"Borgu Fulfulde",
"fub": u"Adamawa Fulfulde",
"fuh": u"Western Niger Fulfulde",
"fui": u"Bagirmi Fulfulde",
"psh": u"Southwest Pashayi",
"psi": u"Southeast Pashayi",
"pso": u"Polish Sign Language",
"psl": u"Puerto Rican Sign Language",
"tqt": u"Western Totonac",
"dgb": u"Bunoge Dogon",
"dgc": u"Casiguran Dumagat Agta",
"dga": u"Southern Dagaare",
"dgd": u"Dagaari Dioula",
"dgi": u"Northern Dagara",
"dgo": u"Dogri (individual language)",
"psg": u"Penang Sign Language",
"pse": u"Central Malay",
"kno": u"Kono (Sierra Leone)",
"jbu": u"Jukun Takum",
"knj": u"Western Kanjobal",
"knh": u"Kayan River Kenyah",
"knb": u"Lubuagan Kalinga",
"knc": u"Central Kanuri",
"kna": u"Dera (Nigeria)",
"knt": u"Panoan Katukína",
"knu": u"Kono (Guinea)",
"quw": u"Tena Lowland Quichua",
"psr": u"Portuguese Sign Language",
"psp": u"Philippine Sign Language",
"cuu": u"Tai Ya",
"cut": u"Teutila Cuicatec",
"cus": u"Cushitic languages",
"cux": u"Tepeuxila Cuicatec",
"cuc": u"Usila Chinantec",
"cun": u"Cunén Quiché",
"cuk": u"San Blas Kuna",
"cuj": u"Mashco Piro",
"bih": u"Bihari languages",
"qwa": u"Corongo Ancash Quechua",
"vgt": u"Vlaamse Gebarentaal",
"biv": u"Southern Birifor",
"biw": u"Kol (Cameroon)",
"qux": u"Yauyos Quechua",
"qxs": u"Southern Qiang",
"ijs": u"Southeast Ijo",
"pxm": u"Quetzaltepec Mixe",
"ijj": u"Ede Ije",
"ijo": u"Ijo languages",
"pez": u"Eastern Penan",
"peq": u"Southern Pomo",
"pes": u"Iranian Persian",
"peo": u"Old Persian (ca. 600-400 B.C.)",
"pej": u"Northern Pomo",
"ped": u"Mala (Papua New Guinea)",
"pef": u"Northeastern Pomo",
"pea": u"Peranakan Indonesian",
"peb": u"Eastern Pomo",
"pec": u"Southern Pesisir",
"kll": u"Kagan Kalagan",
"suc": u"Western Subanon",
"qxw": u"Jauja Wanca Quechua",
"nsi": u"Nigerian Sign Language",
"nsl": u"Norwegian Sign Language",
"nsm": u"Sumi Naga",
"nsa": u"Sangtam Naga",
"nsd": u"Southern Nisu",
"nsf": u"Northwestern Nisu",
"tai": u"Tai languages",
"nsp": u"Nepalese Sign Language",
"nsq": u"Northern Sierra Miwok",
"nsr": u"Maritime Sign Language",
"nst": u"Tase Naga",
"nsu": u"Sierra Negra Nahuatl",
"nsv": u"Southwestern Nisu",
"mkg": u"Mak (China)",
"mkb": u"Mal Paharia",
"mko": u"Mingang Doso",
"mkn": u"Kupang Malay",
"mkh": u"Mon-Khmer languages",
"mkw": u"Kituba (Congo)",
"mku": u"Konyanka Maninka",
"mks": u"Silacayoapan Mixtec",
"mkq": u"Bay Miwok",
"zib": u"Zimbabwe Sign Language",
"mky": u"East Makian",
"mkx": u"Kinamiging Manobo",
"sdv": u"Eastern Sudanic languages",
"sdr": u"Oraon Sadri",
"sdx": u"Sibu Melanau",
"sdc": u"Sassarese Sardinian",
"sdl": u"Saudi Arabian Sign Language",
"sdn": u"Gallurese Sardinian",
"sdo": u"Bukar-Sadung Bidayuh",
"sdh": u"Southern Kurdish",
"sdi": u"Sindang Kelingi",
"sdk": u"Sos Kundi",
"cib": u"Ci Gbe",
"cik": u"Chitkuli Kinnauri",
"zhx": u"Chinese (family)",
"cin": u"Cinta Larga",
"zhd": u"Dai Zhuang",
"zao": u"Ozolotepec Zapotec",
"zhn": u"Nong Zhuang",
"sxk": u"Southern Kalapuya",
"qub": u"Huallaga Huánuco Quechua",
"sxw": u"Saxwe Gbe",
"jcs": u"Jamaican Country Sign Language",
"kqd": u"Koy Sanjaq Surat",
"kqk": u"Kotafon Gbe",
"kqo": u"Eastern Krahn",
"sjd": u"Kildin Sami",
"qud": u"Calderón Highland Quichua",
"kmd": u"Majukayang Kalinga",
"agk": u"Isarog Agta",
"qug": u"Chimborazo Highland Quichua",
"agz": u"Mt. Iriga Agta",
"agy": u"Southern Alta",
"agv": u"Remontado Dumagat",
"agt": u"Central Cagayan Agta",
"bvs": u"Belgian Sign Language",
"qvo": u"Napo Lowland Quechua",
"bvu": u"Bukit Malay",
"bvt": u"Bati (Indonesia)",
"qva": u"Ambo-Pasco Quechua",
"quf": u"Lambayeque Quechua",
"kmj": u"Kumarbhag Paharia",
"bve": u"Berau Malay",
"bvi": u"Belanda Viri",
"bvl": u"Bolivian Sign Language",
"kmv": u"Karipúna Creole French",
"kmr": u"Northern Kurdish",
"quh": u"South Bolivian Quechua",
"trk": u"Turkic languages",
"trl": u"Traveller Scottish",
"quk": u"Chachapoyas Quechua",
"trc": u"Copala Triqui",
"tre": u"East Tarangan",
"trg": u"Lishán Didán",
"trf": u"Trinidadian Creole English",
"trx": u"Tringgus-Sembaan Bidayuh",
"trq": u"San Martín Itunyoso Triqui",
"trp": u"Kok Borok",
"trs": u"Chicahuaxtla Triqui",
"odt": u"Old Dutch",
"lel": u"Lele (Democratic Republic of Congo)",
"leo": u"Leti (Cameroon)",
"leu": u"Kara (Papua New Guinea)",
"lew": u"Ledo Kaili",
"tdd": u"Tai Nüa",
"ctt": u"Wayanad Chetti",
"ctp": u"Western Highland Chatino",
"cts": u"Northern Catanduanes Bikol",
"ctz": u"Zacatepec Chatino",
"ctd": u"Tedim Chin",
"cte": u"Tepinapa Chinantec",
"cta": u"Tataltepec Chatino",
"ctl": u"Tlacoatzintepec Chinantec",
"cth": u"Thaiphum Chin",
"cti": u"Tila Chol",
"sgx": u"Sierra Leone Sign Language",
"sgw": u"Sebat Bet Gurage",
"sgn": u"Sign Languages",
"sga": u"Old Irish (to 900)",
"sgb": u"Mag-antsi Ayta",
"sgg": u"Swiss-German Sign Language",
"zaa": u"Sierra de Juárez Zapotec",
"chd": u"Highland Oaxaca Chontal",
"chf": u"Tabasco Chontal",
"chj": u"Ojitlán Chinantec",
"chm": u"Mari (Russia)",
"chn": u"Chinook jargon",
"chq": u"Quiotepec Chinantec",
"chu": u"Church Slavic",
"chz": u"Ozumacín Chinantec",
"tdt": u"Tetun Dili",
"ztx": u"Zaachila Zapotec",
"iir": u"Indo-Iranian languages",
"iii": u"Sichuan Yi",
"ocu": u"Atzingo Matlatzinca",
"xcg": u"Cisalpine Gaulish",
"tac": u"Lowland Tarahumara",
"xcl": u"Classical Armenian",
"sro": u"Campidanese Sardinian",
"xct": u"Classical Tibetan",
"tde": u"Tiranige Diga Dogon",
"xna": u"Ancient North Arabian",
"afg": u"Afghan Sign Language",
"afa": u"Afro-Asiatic languages",
"afb": u"Gulf Arabic",
"gcr": u"Guianese Creole French",
"gct": u"Colonia Tovar German",
"afs": u"Afro-Seminole Creole",
"npl": u"Southeastern Puebla Nahuatl",
"npo": u"Pochuri Naga",
"npi": u"Nepali (individual language)",
"nph": u"Phom Naga",
"npg": u"Ponyo-Gongwang Naga",
"npa": u"Nar Phu",
"npu": u"Puimei Naga",
"mjd": u"Northwest Maidu",
"mjc": u"San Juan Colorado Mixtec",
"mjn": u"Ma (Papua New Guinea)",
"gcf": u"Guadeloupean Creole French",
"mjh": u"Mwera (Nyasa)",
"mji": u"Kim Mun",
"mjt": u"Sauria Paharia",
"xnn": u"Northern Kankanay",
"vmm": u"Mitlatongo Mixtec",
"vmj": u"Ixtayutla Mixtec",
"vmd": u"Mudu Koraga",
"vme": u"East Masela",
"gcl": u"Grenadian Creole English",
"vmz": u"Mazatlán Mazatec",
"vmx": u"Tamazola Mixtec",
"vmy": u"Ayautla Mazatec",
"vmv": u"Valley Maidu",
"vmp": u"Soyaltepec Mazatec",
"tsm": u"Turkish Sign Language",
"tsf": u"Southwestern Tamang",
"tse": u"Tunisian Sign Language",
"tdx": u"Tandroy-Mahafaly Malagasy",
"tst": u"Tondi Songway Kiini",
"euq": u"Basque (family)",
"dao": u"Daai Chin",
"daj": u"Dar Fur Daju",
"dat": u"Darang Deng",
"dau": u"Dar Sila Daju",
"dap": u"Nisi (India)",
"daq": u"Dandami Maria",
"day": u"Land Dayak languages",
"kpp": u"Paku Karen",
"kpx": u"Mountain Koiali",
"kpb": u"Mullu Kurumba",
"lfn": u"Lingua Franca Nova",
"yym": u"Yuanjiang-Mojiang Yi",
"src": u"Logudorese Sardinian",
"wes": u"Cameroon Pidgin",
"rer": u"Rer Bare",
"puz": u"Purum Naga",
"cwd": u"Woods Cree",
"ree": u"Rejang Kayan",
"bwp": u"Mandobo Bawah",
"bwq": u"Southern Bobo Madaré",
"bwu": u"Buli (Ghana)",
"bwv": u"Bahau River Kenyah",
"bwx": u"Bu-Nao Bunu",
"bwy": u"Cwi Bwamu",
"quz": u"Cusco Quechua",
"bwe": u"Bwe Karen",
"bwj": u"Láá Láá Bwamu",
"bwn": u"Wunai Bunu",
"bwo": u"Boro (Ethiopia)",
"zaq": u"Aloápam Zapotec",
"pga": u"Sudanese Creole Arabic",
"ihb": u"Iha Based Pidgin",
"too": u"Xicotepec De Juárez Totonac",
"oge": u"Old Georgian",
"qwe": u"Quechuan (family)",
"tdu": u"Tempasuk Dusun",
"nqy": u"Akyaung Ari Naga",
"nqg": u"Southern Nago",
"mii": u"Chigmecatitlán Mixtec",
"mih": u"Chayuco Mixtec",
"mim": u"Alacatlatzala Mixtec",
"mil": u"Peñoles Mixtec",
"mio": u"Pinotepa Nacional Mixtec",
"mib": u"Atatláhuca Mixtec",
"mie": u"Ocotepec Mixtec",
"mig": u"San Miguel El Grande Mixtec",
"miy": u"Ayutla Mixtec",
"mix": u"Mixtepec Mixtec",
"miz": u"Coatzospan Mixtec",
"mip": u"Apasco-Apoala Mixtec",
"mis": u"Uncoded languages",
"mir": u"Isthmus Mixe",
"miu": u"Cacaloxtepec Mixtec",
"mit": u"Southern Puebla Mixtec",
"sfs": u"South African Sign Language",
"sfm": u"Small Flowery Miao",
"sfe": u"Eastern Subanen",
"sfb": u"Langue des signes de Belgique Francophone",
"cke": u"Eastern Cakchiquel",
"ckd": u"South Central Cakchiquel",
"ckf": u"Southern Cakchiquel",
"cka": u"Khumi Awa Chin",
"ckc": u"Northern Cakchiquel",
"ckb": u"Central Kurdish",
"ckn": u"Kaang Chin",
"cki": u"Santa María De Jesús Cakchiquel",
"ckk": u"Acatenango Southwestern Cakchiquel",
"ckj": u"Santo Domingo Xenacoj Cakchiquel",
"ckw": u"Western Cakchiquel",
"ckz": u"Cakchiquel-Quiché Mixed Language",
"dba": u"Bangi Me",
"szc": u"Semaq Beri",
"dbg": u"Dogul Dom Dogon",
"dbu": u"Bondum Dom Dogon",
"dbt": u"Ben Tey Dogon",
"dbw": u"Bankan Tey Dogon",
"ksw": u"S'gaw Karen",
"jax": u"Jambi Malay",
"jar": u"Jarawa (Nigeria)",
"jas": u"New Caledonian Javanese",
"jam": u"Jamaican Creole English",
"jah": u"Jah Hut",
"jai": u"Western Jacalteco",
"vmc": u"Juxtlahuaca Mixtec",
"xdy": u"Malayic Dayak",
"aer": u"Eastern Arrernte",
"gba": u"Gbaya (Central African Republic)",
"gbj": u"Bodo Gadaba",
"gbh": u"Defi Gbe",
"aec": u"Saidi Arabic",
"aeb": u"Tunisian Arabic",
"aee": u"Northeast Pashayi",
"aed": u"Argentine Sign Language",
"gbx": u"Eastern Xwla Gbe",
"aen": u"Armenian Sign Language",
"bts": u"Batak Simalungun",
"btx": u"Batak Karo",
"btz": u"Batak Alas-Kluet",
"btd": u"Batak Dairi",
"btg": u"Gagnoa Bété",
"btc": u"Bati (Cameroon)",
"btb": u"Beti (Cameroon)",
"btm": u"Batak Mandailing",
"bto": u"Rinconada Bikol",
"bth": u"Biatah Bidayuh",
"btk": u"Batak languages",
"btj": u"Bacanese Malay",
"gmy": u"Mycenaean Greek",
"tlq": u"Tai Loi",
"tlp": u"Filomena Mata-Coahuitlán Totonac",
"tla": u"Southwestern Tepehuan",
"ote": u"Mezquital Otomi",
"eth": u"Ethiopian Sign Language",
"etn": u"Eton (Vanuatu)",
"eto": u"Eton (Cameroon)",
"yso": u"Nisi (China)",
"ila": u"Ile Ape",
"cvn": u"Valle Nacional Chinantec",
"rbl": u"Miraya Bikol",
"rbk": u"Northern Bontok",
"tsp": u"Northern Toussian",
"tsq": u"Thai Sign Language",
"rbb": u"Rumai Palaung",
"qws": u"Sihuas Ancash Quechua",
"cjh": u"Upper Chehalis",
"cjo": u"Ashéninka Pajonal",
"cjm": u"Eastern Cham",
"cja": u"Western Cham",
"cjy": u"Jinyu Chinese",
"zgm": u"Minz Zhuang",
"zgn": u"Guibian Zhuang",
"ils": u"International Sign",
"phi": u"Philippine languages",
"pht": u"Phu Thai",
"lzh": u"Literary Chinese",
"wyy": u"Western Fijian",
"ofs": u"Old Frisian",
"qvh": u"Huamalíes-Dos de Mayo Huánuco Quechua",
"lzn": u"Leinong Naga",
"wec": u"Wè Western",
"ads": u"Adamorobe Sign Language",
"wen": u"Sorbian languages",
"adx": u"Amdo Tibetan",
"adf": u"Dhofari Arabic",
"weu": u"Rawngtu Chin",
"psa": u"Asue Awyu",
"zyg": u"Yang Zhuang",
"otq": u"Querétaro Otomi",
"mho": u"Mashi (Zambia)",
"mhh": u"Maskoy Pidgin",
"mha": u"Manda (India)",
"mhz": u"Mor (Mor Islands)",
"mhr": u"Eastern Mari",
"mhs": u"Buru (Indonesia)",
"mhp": u"Balinese Malay",
"njb": u"Nocte Naga",
"vsv": u"Valencian Sign Language",
"njd": u"Ndonde Hamba",
"njh": u"Lotha Naga",
"njo": u"Ao Naga",
"njn": u"Liangmai Naga",
"njm": u"Angami Naga",
"njt": u"Ndyuka-Trio Pidgin",
"psd": u"Plains Indian Sign Language",
"zsm": u"Standard Malay",
"tmp": u"Tai Mène",
"esu": u"Central Yupik",
"ess": u"Central Siberian Yupik",
"esx": u"Eskimo-Aleut languages",
"tma": u"Tama (Chad)",
"ese": u"Ese Ejja",
"eso": u"Estonian Sign Language",
"esn": u"Salvadoran Sign Language",
"esl": u"Egypt Sign Language",
"esk": u"Northwest Alaska Inupiatun",
"tmm": u"Tai Thanh",
"esi": u"North Alaskan Inupiatun",
"krz": u"Sota Kanum",
"krr": u"Kru'ng 2",
"krs": u"Gbaya (Sudan)",
"krw": u"Western Krahn",
"krt": u"Tumari Kanuri",
"kro": u"Kru languages",
"krf": u"Koro (Vanuatu)",
"krg": u"North Korowai",
"rcf": u"Réunion Creole French",
"buy": u"Bullom So",
"buh": u"Younuo Bunu",
"bum": u"Bulu (Cameroon)",
"pia": u"Pima Bajo",
"ins": u"Indian Sign Language",
"inl": u"Indonesian Sign Language",
"inj": u"Jungle Inga",
"ine": u"Indo-European languages",
"pit": u"Pitta Pitta",
"ina": u"Interlingua (International Auxiliary Language Association)",
"inc": u"Indic languages",
"hps": u"Hawai'i Pidgin Sign Language",
"oav": u"Old Avar",
"oar": u"Old Aramaic (up to 700 BCE)",
"sot": u"Southern Sotho",
"ubl": u"Buhi'non Bikol",
"ubm": u"Upper Baram Kenyah",
"zqe": u"Qiubei Zhuang",
"xxb": u"Boro (Ghana)",
"eot": u"Beti (Côte d'Ivoire)",
"nwx": u"Middle Newar",
"nwc": u"Classical Newari",
"nwi": u"Southwest Tanna",
"mwq": u"Mün Chin",
"mwp": u"Kala Lagaw Ya",
"mww": u"Hmong Daw",
"mwe": u"Mwera (Chimwera)",
"mwk": u"Kita Maninkakan",
"mwo": u"Central Maewo",
"scf": u"San Miguel Creole French",
"psw": u"Port Sandwich",
"gnw": u"Western Bolivian Guaraní",
"cmo": u"Central Mnong",
"cmn": u"Mandarin Chinese",
"cmg": u"Classical Mongolian",
"cmc": u"Chamic languages",
"reg": u"Kara (Tanzania)",
"zdj": u"Ngazidja Comorian",
"cmr": u"Mro-Khimi Chin",
"qup": u"Southern Pastaza Quechua",
"qus": u"Santiago del Estero Quichua",
"qur": u"Yanahuanca Pasco Quechua",
"ptv": u"Port Vato",
"quu": u"Eastern Quiché",
"psu": u"Sauraseni Prākrit",
"qut": u"West Central Quiché",
"zlq": u"Liuqian Zhuang",
"kuu": u"Upper Kuskokwim",
"kuf": u"Western Katu",
"glh": u"Northwest Pashayi",
"tmk": u"Northwestern Tamang",
"ssl": u"Western Sisaala",
"akh": u"Angal Heneng",
"akb": u"Batak Angkola",
"tml": u"Tamnim Citak",
"brx": u"Bodo (India)",
"brv": u"Western Bru",
"bru": u"Eastern Bru",
"brc": u"Berbice Creole Dutch",
"tzt": u"Western Tzutujil",
"quj": u"Joyabaj Quiché",
"qul": u"North Bolivian Quechua",
"tmn": u"Taman (Indonesia)",
"nkb": u"Khoibu Naga",
"nkf": u"Inpui Naga",
"nkh": u"Khezha Naga",
"nki": u"Thangal Naga",
"nks": u"North Asmat",
"nkt": u"Nyika (Tanzania)",
"nku": u"Bouna Kulango",
"nkv": u"Nyika (Malawi and Zambia)",
"nky": u"Khiamniungan Naga",
"tnz": u"Tonga (Thailand)",
"tne": u"Tinoc Kallahan",
"tnd": u"Angosturas Tunebo",
"tnb": u"Western Tunebo",
"erk": u"South Efate",
"mpf": u"Tajumulco Mam",
"mvc": u"Central Mam",
"enf": u"Forest Enets",
"enh": u"Tundra Enets",
"enm": u"Middle English (1100-1500)",
"env": u"Enwan (Edu State)",
"enw": u"Enwan (Akwa Ibom State)",
"mpl": u"Middle Watut",
"laj": u"Lango (Uganda)",
"lak": u"Laka (Nigeria)",
"sbl": u"Botolan Sambal",
"laa": u"Southern Subanen",
"lab": u"Linear A",
"lay": u"Lama (Myanmar)",
"lap": u"Laka (Chad)",
"las": u"Lama (Togo)",
"zeh": u"Eastern Hongshuihe Zhuang",
"clo": u"Lowland Oaxaca Chontal",
"clj": u"Laitu Chin",
"cld": u"Chaldean Neo-Aramaic",
"cle": u"Lealao Chinantec",
"ssa": u"Nilo-Saharan languages",
"cly": u"Eastern Highland Chatino",
"clt": u"Lautu Chin",
"pgl": u"Primitive Irish",
"pbt": u"Southern Pashto",
"xgn": u"Mongolian languages",
"gom": u"Goan Konkani",
"ajz": u"Amri Karbi",
"goh": u"Old High German (ca. 750-1050)",
"ajp": u"South Levantine Arabic",
"ajt": u"Judeo-Tunisian Arabic",
"aju": u"Judeo-Moroccan Arabic",
"aja": u"Aja (Sudan)",
"ajg": u"Aja (Benin)",
"ntx": u"Tangkhul Naga (Myanmar)",
"kiw": u"Northeast Kiwai",
"kiu": u"Kirmanjki (individual language)",
"mvv": u"Tagal Murut",
"mvy": u"Indus Kohistani",
"mve": u"Marwari (Pakistan)",
"mvf": u"Peripheral Mongolian",
"mvg": u"Yucuañe Mixtec",
"mvj": u"Todos Santos Cuchumatán Mam",
"mvl": u"Mbara (Australia)",
"nhe": u"Eastern Huasteca Nahuatl",
"nhg": u"Tetelcingo Nahuatl",
"nhc": u"Tabasco Nahuatl",
"nhm": u"Morelos Nahuatl",
"nhn": u"Central Nahuatl",
"nhi": u"Zacatlán-Ahuacatlán-Tepetzintla Nahuatl",
"nhk": u"Isthmus-Cosoleacaque Nahuatl",
"nhj": u"Tlalitzlipa Nahuatl",
"nht": u"Ometepec Nahuatl",
"nhw": u"Western Huasteca Nahuatl",
"nhv": u"Temascaltepec Nahuatl",
"nhq": u"Huaxcaleca Nahuatl",
"nhp": u"Isthmus-Pajapan Nahuatl",
"nhs": u"Southeastern Puebla Nahuatl",
"nhy": u"Northern Oaxaca Nahuatl",
"nhx": u"Isthmus-Mecayapan Nahuatl",
"nhz": u"Santa María La Alta Nahuatl",
"tor": u"Togbo-Vara Banda",
"top": u"Papantla Totonac",
"tot": u"Patla-Chicontla Totonac",
"kif": u"Eastern Parbate Kham",
"toi": u"Tonga (Zambia)",
"ton": u"Tonga (Tonga Islands)",
"toc": u"Coyutla Totonac",
"tjl": u"Tai Laing",
"tee": u"Huehuetla Tepehua",
"kty": u"Kango (Bas-Uélé District)",
"ktu": u"Kituba (Democratic Republic of Congo)",
"ktv": u"Eastern Katu",
"ktr": u"Kota Marudu Tinagas",
"kts": u"South Muyu",
"kti": u"North Muyu",
"ktj": u"Plapo Krumen",
"lbs": u"Libyan Sign Language",
"lbk": u"Central Bontok",
"lbl": u"Libon Bikol",
"ypw": u"Puwa Yi",
"ypb": u"Labo Phowa",
"ypk": u"Yupik languages",
"tew": u"Tewa (USA)",
"ypn": u"Ani Phowa",
"ypo": u"Alo Phola",
"ypl": u"Pula Yi",
"bsy": u"Sabah Bisaya",
"bsz": u"Souletin Basque",
"bsv": u"Baga Sobané",
"bsp": u"Baga Sitemu",
"bsd": u"Sarawak Bisaya",
"bsb": u"Brunei Bisaya",
"pkr": u"Attapady Kurumba",
"pks": u"Pakistan Sign Language",
"pka": u"Ardhamāgadhī Prākrit",
"oci": u"Occitan (post 1500)",
"och": u"Old Chinese",
"oco": u"Old Cornish",
"hrm": u"Horned Miao",
"xtp": u"San Miguel Piedras Mixtec",
"emg": u"Eastern Meohang",
"xom": u"Komo (Sudan)",
"emk": u"Eastern Maninkakan",
"emu": u"Eastern Muria",
"emp": u"Northern Emberá",
"ems": u"Pacific Gulf Yupik",
"emy": u"Epigraphic Mayan",
"nuz": u"Tlamacazapa Nahuatl",
"nuv": u"Northern Nuni",
"nut": u"Nung (Viet Nam)",
"nul": u"Nusa Laut",
"nub": u"Nubian languages",
"mut": u"Western Muria",
"muq": u"Eastern Xiangxi Miao",
"mue": u"Media Lengua",
"mud": u"Mednyj Aleut",
"mul": u"Multiple languages",
"mun": u"Munda languages",
"zbe": u"East Berawan",
"zbc": u"Central Berawan",
"zbw": u"West Berawan",
"hak": u"Hakka Chinese",
"cov": u"Cao Miao",
"ili": u"Ili Turki",
"coa": u"Cocos Islands Malay",
"cok": u"Santa Teresa Cora",
"kwg": u"Sara Kaba Deme",
"hae": u"Eastern Oromo",
"haf": u"Haiphong Sign Language",
"kwv": u"Sara Kaba Náà",
"kwy": u"San Salvador Kongo",
"hax": u"Southern Haida",
"pnm": u"Punan Batu 1",
"xbb": u"Lower Burdekin",
"tsy": u"Tebul Sign Language",
"vsi": u"Moldova Sign Language",
"gnr": u"Gureng Gureng",
"sjb": u"Sajau Basap",
"ais": u"Nataoran Amis",
"ain": u"Ainu (Japan)",
"aii": u"Assyrian Neo-Aramaic",
"aij": u"Lishanid Noshan",
"aig": u"Antigua and Barbuda Creole English",
"gno": u"Northern Gondi",
"aib": u"Ainu (China)",
"nqk": u"Kura Ede Nago",
"vwa": u"Awa (China)",
"nik": u"Southern Nicobarese",
"nih": u"Nyiha (Tanzania)",
"nic": u"Niger-Kordofanian languages",
"nit": u"Southeastern Kolami",
"thz": u"Tayart Tamajeq",
"thv": u"Tahaggart Tamahaq",
"thr": u"Rana Tharu",
"thq": u"Kochila Tharu",
"thl": u"Dangaura Tharu",
"thi": u"Tai Long",
"the": u"Chitwania Tharu",
"thc": u"Tai Hang Tong",
"tss": u"Taiwan Sign Language",
"elh": u"El Hugeirat",
"elo": u"El Molo",
"ell": u"Modern Greek (1453-)",
"lcp": u"Western Lawa",
"xba": u"Kamba (Brazil)",
"rnr": u"Nari Nari",
"qxc": u"Chincha Quechua",
"ywu": u"Wumeng Nasu",
"bpl": u"Broome Pearling Lugger Pidgin",
"bpn": u"Dzao Min",
"bpq": u"Banda Malay",
"bps": u"Sarangani Blaan",
"bpr": u"Koronadal Blaan",
"bpt": u"Barrow Point",
"bpw": u"Bo (Papua New Guinea)",
"bpv": u"Bian Marind",
"bpx": u"Palya Bareli",
"ywm": u"Wumeng Yi",
"qxh": u"Panao Huánuco Quechua",
"qxi": u"San Andrés Quiché",
"zca": u"Coatecas Altas Zapotec",
"qxn": u"Northern Conchucos Ancash Quechua",
"zch": u"Central Hongshuihe Zhuang",
"qxo": u"Southern Conchucos Ancash Quechua",
"zsl": u"Zambian Sign Language",
"qxl": u"Salasaca Highland Quichua",
"cnw": u"Ngawn Chin",
"cnt": u"Tepetotutla Chinantec",
"ykg": u"Northern Yukaghir",
"cns": u"Central Asmat",
"icl": u"Icelandic Sign Language",
"ica": u"Ede Ica",
"qxp": u"Puno Quechua",
"cnx": u"Middle Cornish",
"cng": u"Northern Qiang",
"jye": u"Judeo-Yemeni Arabic",
"cnb": u"Chinbon Chin",
"cnl": u"Lalana Chinantec",
"cnm": u"Ixtatán Chuj",
"cnk": u"Khumi Chin",
"cnh": u"Haka Chin",
"hsb": u"Upper Sorbian",
"plv": u"Southwest Palawano",
"plt": u"Plateau Malagasy",
"hsf": u"Southeastern Huastec",
"plr": u"Palaka Senoufo",
"hsh": u"Hungarian Sign Language",
"hsn": u"Xiang Chinese",
"hsl": u"Hausa Sign Language",
"plc": u"Central Palawano",
"plo": u"Oluta Popoluca",
"pll": u"Shwe Palaung",
"plk": u"Kohistani Shina",
"obo": u"Obo Manobo",
"obk": u"Southern Bontok",
"obt": u"Old Breton",
"obr": u"Old Burmese",
"ahi": u"Tiagbamrin Aizi",
"ahm": u"Mobumrin Aizi",
"ahp": u"Aproumu Aizi",
"giw": u"White Gelao",
"gis": u"North Giziga",
"gir": u"Red Gelao",
"giq": u"Green Gelao",
"gip": u"Gimi (West New Britain)",
"giz": u"South Giziga",
"gim": u"Gimi (Eastern Highlands)",
"war": u"Waray (Philippines)",
"hca": u"Andaman Creole Hindi",
"mtx": u"Tidaá Mixtec",
"mtp": u"Wichí Lhamtés Nocten",
"mtw": u"Southern Binukidnon",
"mtu": u"Tututepec Mixtec",
"mti": u"Maiwa (Papua New Guinea)",
"mto": u"Totontepec Mixe",
"mtb": u"Anyin Morofo",
"mta": u"Cotabato Manobo",
"mtf": u"Murik (Papua New Guinea)",
"mte": u"Mono (Solomon Islands)",
"nno": u"Norwegian Nynorsk",
"nnl": u"Northern Rengma Naga",
"nni": u"North Nuaulu",
"nng": u"Maring Naga",
"nnd": u"West Ambae",
"nnw": u"Southern Nuni",
"nnv": u"Nugunu (Australia)",
"nnp": u"Wancho Naga",
"tix": u"Southern Tiwa",
"tiz": u"Tai Hongjin",
"tis": u"Masadiit Itneg",
"tih": u"Timugon Murut",
"tia": u"Tidikelt Tamazight",
"kvd": u"Kui (Indonesia)",
"kvn": u"Border Kuna",
"kvk": u"Korean Sign Language",
"kvt": u"Lahta Karen",
"kvq": u"Geba Karen",
"kvx": u"Parkari Koli",
"kvy": u"Yintale Karen",
"lls": u"Lithuanian Sign Language",
"roa": u"Romance languages",
"llp": u"North Efate",
"rog": u"Northern Roglai",
"llj": u"Ladji Ladji",
"llc": u"Lele (Guinea)",
"lle": u"Lele (Papua New Guinea)",
"bqf": u"Baga Kaloum",
"bqe": u"Navarro-Labourdin Basque",
"bqc": u"Boko (Benin)",
"bqn": u"Bulgarian Sign Language",
"bqv": u"Koro Wachi",
"bqw": u"Buru (Nigeria)",
"bqy": u"Bengkala Sign Language",
"yux": u"Southern Yukaghir",
"ysr": u"Sirenik Yupik",
"icr": u"Islander Creole English",
"gug": u"Paraguayan Guaraní",
"gud": u"Yocoboué Dida",
"gui": u"Eastern Bolivian Guaraní",
"gun": u"Mbyá Guaraní",
"gul": u"Sea Island Creole English",
"gus": u"Guinean Sign Language",
"gut": u"Maléku Jaíka",
"plw": u"Brooke's Point Palawano",
"pmq": u"Northern Pame",
"hto": u"Minica Huitoto",
"pmx": u"Poumei Naga",
"pmy": u"Papuan Malay",
"klj": u"Turkic Khalaj",
"pml": u"Lingua Franca",
"pls": u"San Marcos Tlalcoyalco Popoloca",
"pmh": u"Māhārāṣṭri Prākrit",
"pmi": u"Northern Pumi",
"pmj": u"Southern Pumi",
"htx": u"Middle Hittite",
"szv": u"Isu (Fako Division)",
"ekl": u"Kol (Bangladesh)",
"ekk": u"Standard Estonian",
"kss": u"Southern Kisi",
"eky": u"Eastern Kayah",
"uzn": u"Northern Uzbek",
"ksy": u"Kharia Thar",
"fbl": u"West Albay Bikol",
"mst": u"Cataelano Mandaya",
"mss": u"West Masela",
"msm": u"Agusan Manobo",
"msj": u"Ma (Democratic Republic of Congo)",
"msi": u"Sabah Malay",
"msh": u"Masikoro Malagasy",
"msd": u"Yucatec Maya Sign Language",
"msc": u"Sankaran Maninka",
"msa": u"Malay (macrolanguage)",
"ksc": u"Southern Kalinga",
"car": u"Galibi Carib",
"caq": u"Car Nicobarese",
"cau": u"Caucasian languages",
"cai": u"Central American Indian languages",
"caf": u"Southern Carrier",
"kyn": u"Northern Binukidnon",
"kyb": u"Butbut Kalinga",
"kys": u"Baram Kayan",
"kyu": u"Western Kayah",
"tbq": u"Tibeto-Burman languages",
"plf": u"Central Malayo-Polynesian languages",
"aoe": u"Angal Enen",
"aon": u"Bumbita Arapesh",
"yir": u"North Awyu",
"pqw": u"Western Malayo-Polynesian languages",
"aoz": u"Uab Meto",
"tbk": u"Calamian Tagbanwa",
"ghe": u"Southern Ghale",
"ghc": u"Hiberno-Scottish Gaelic",
"ghh": u"Northern Ghale",
"ghk": u"Geko Karen",
"soa": u"Thai Song",
"tbn": u"Barro Negro Tunebo",
"soc": u"So (Democratic Republic of Congo)",
"ttt": u"Muslim Tat",
"non": u"Old Norse",
"nod": u"Northern Thai",
"nob": u"Norwegian Bokmål",
"tjs": u"Southern Tujia",
"nos": u"Eastern Nisu",
"pps": u"San Luís Temalacayuca Popoloca",
"ryu": u"Central Okinawan",
"gbo": u"Northern Grebo",
"sou": u"Southern Thai",
"ywt": u"Xishanba Lalo",
"tto": u"Lower Ta'oih",
"gbs": u"Gbesi Gbe",
"lmw": u"Lake Miwok",
"lmj": u"West Lembata",
"lma": u"East Limba",
"lmf": u"South Lembata",
"yuy": u"East Yugur",
"gbz": u"Zoroastrian Dari",
"yus": u"Chan Santa Cruz Maya",
"yuw": u"Yau (Morobe Province)",
"yun": u"Bena (Nigeria)",
"yue": u"Yue Chinese",
"yud": u"Judeo-Tripolitanian Arabic",
"zam": u"Miahuatlán Zapotec",
"zad": u"Cajonos Zapotec",
"zab": u"San Juan Guelavía Zapotec",
"waa": u"Walla Walla",
"zax": u"Xadani Zapotec",
"zav": u"Yatzachi Zapotec",
"zat": u"Tabaa Zapotec",
"zar": u"Rincón Zapotec",
"zas": u"Santo Domingo Albarradas Zapotec",
"yim": u"Yimchungru Naga",
"yio": u"Dayao Yi",
"yih": u"Western Yiddish",
"yik": u"Dongshanba Lalo",
"yit": u"Eastern Lalu",
"yiv": u"Northern Nisu",
"tch": u"Turks And Caicos Creole English",
"yiy": u"Yir Yoront",
"hue": u"San Francisco Del Mar Huave",
"huj": u"Northern Guiyang Hmong",
"huu": u"Murui Huitoto",
"huv": u"San Mateo Del Mar Huave",
"pna": u"Punan Bah-Biau",
"pnb": u"Western Panjabi",
"hux": u"Nüpode Huitoto",
"ssb": u"Southern Sama",
"xtd": u"Diuxi-Tilantongo Mixtec",
"qvw": u"Huaylla Wanca Quechua",
"ang": u"Old English (ca. 450-1100)",
"pra": u"Prakrit languages",
"anl": u"Anu-Hkongso Chin",
"anq": u"Jarawa (India)",
"prz": u"Providencia Sign Language",
"gkp": u"Guinea Kpelle",
"fcs": u"Quebec Sign Language",
"mrt": u"Marghi Central",
"mru": u"Mono (Cameroon)",
"mrq": u"North Marquesan",
"mrr": u"Maria (India)",
"mrn": u"Cheke Holo",
"mrh": u"Mara Chin",
"mrj": u"Western Mari",
"mrd": u"Western Magar",
"mre": u"Martha's Vineyard Sign Language",
"tkg": u"Tesaka Malagasy",
"nlv": u"Orizaba Nahuatl",
"qvp": u"Pacaraos Quechua",
"tku": u"Upper Necaxa Totonac",
"nle": u"East Nyala",
"nlk": u"Ninia Yali",
"nln": u"Durango Nahuatl",
"kxh": u"Karo (Ethiopia)",
"kxi": u"Keningau Murut",
"kxk": u"Zayein Karen",
"kxl": u"Nepali Kurux",
"kxn": u"Kanowit-Tanjong Melanau",
"kxf": u"Manumanaw Karen",
"dym": u"Yanda Dom Dogon",
"dyi": u"Djimini Senoufo",
"dyk": u"Land Dayak",
"kxq": u"Smärky Kanum",
"kxr": u"Koro (Papua New Guinea)",
"dyg": u"Villa Viciosa Agta",
"neq": u"North Central Mixe",
"rms": u"Romanian Sign Language",
"rmw": u"Welsh Romani",
"rmy": u"Vlax Romani",
"lnl": u"South Central Banda",
"lno": u"Lango (Sudan)",
"kel": u"Kela (Democratic Republic of Congo)",
"rmd": u"Traveller Danish",
"rmo": u"Sinte Romani",
"ytw": u"Yout Wam",
"xwl": u"Western Xwla Gbe",
"xwe": u"Xwela Gbe",
"yln": u"Langnian Buyang",
"poz": u"Malayo-Polynesian languages",
"hva": u"San Luís Potosí Huastec",
"pow": u"San Felipe Otlaltepec Popoloca",
"hvc": u"Haitian Vodoun Culture Language",
"pou": u"Southern Pokomam",
"hve": u"San Dionisio Del Mar Huave",
"pos": u"Sayula Popoluca",
"poq": u"Texistepec Popoluca",
"poo": u"Central Pomo",
"pom": u"Southeastern Pomo",
"poj": u"Lower Pokomo",
"poe": u"San Juan Atzingo Popoloca",
"pob": u"Western Pokomchí",
"hvv": u"Santa María Del Mar Huave",
"wrw": u"Gugu Warra",
"tlw": u"South Wemale",
"wrz": u"Waray (Australia)",
"wrx": u"Wae Rana",
"tnn": u"North Tanna",
"mqa": u"Maba (Indonesia)",
"mqg": u"Kota Bangun Kutai Malay",
"mqh": u"Tlazoyaltepec Mixtec",
"mqk": u"Rajah Kabunsuwan Manobo",
"mqm": u"South Marquesan",
"mqs": u"West Makian",
"tlc": u"Yecuatla Totonac",
"tle": u"Southern Marakwet",
"kxu": u"Kui (India)",
"ccy": u"Southern Zhuang",
"ccx": u"Northern Zhuang",
"yhl": u"Hlepho Phowa",
"xkm": u"Mahakam Kenyah",
"ccs": u"South Caucasian languages",
"ccm": u"Malaccan Creole Malay",
"cco": u"Comaltepec Chinantec",
"ccn": u"North Caucasian languages",
"ccd": u"Cafundo Creole",
"ccg": u"Samba Daka",
"xnd": u"Na-Dene languages",
"xua": u"Alu Kurumba",
"amm": u"Ama (Papua New Guinea)",
"psc": u"Persian Sign Language",
"amd": u"Amapá Creole",
"ams": u"Southern Amami-Oshima",
"amu": u"Guerrero Amuzgo",
"amw": u"Western Neo-Aramaic",
"gjk": u"Kachi Koli",
"tzz": u"Zinacantán Tzotzil",
"gvo": u"Gavião Do Jiparaná",
"gva": u"Guana (Paraguay)",
"sqs": u"Sri Lankan Sign Language",
"sqr": u"Siculo Arabic",
"gvr": u"Western Gurung",
"gvp": u"Pará Gavião",
"nmu": u"Northeast Maidu",
"nmx": u"Nama (Papua New Guinea)",
"nmf": u"Tangkhul Naga (India)",
"nme": u"Mzieme Naga",
"nmb": u"Big Nambas",
"nma": u"Maram Naga",
"nmo": u"Moyon Naga",
"nmj": u"Ngombe (Central African Republic)",
"nmh": u"Monsang Naga",
"sqk": u"Albanian Sign Language",
"sqj": u"Albanian languages",
"srk": u"Serudung Murut",
"srn": u"Sranan Tongo",
"kvu": u"Yinbaw Karen",
"srv": u"Southern Sorsoganon",
"yas": u"Nugunu (Cameroon)",
"loi": u"Loma (Côte d'Ivoire)",
"lon": u"Malawi Lomwe",
"lom": u"Loma (Liberia)",
"low": u"Tampias Lobu",
"lou": u"Louisiana Creole French",
"rmu": u"Tavringer Romani",
"vsl": u"Venezuelan Sign Language",
"jus": u"Jumla Sign Language",
"yaf": u"Yaka (Democratic Republic of Congo)",
"yac": u"Pass Valley Yali",
"cba": u"Chibchan languages",
"cbj": u"Ede Cabe",
"cbl": u"Bualkhaw Chin",
"cbm": u"Yepocapa Southwestern Cakchiquel",
"otl": u"Tilapa Otomi",
"otm": u"Eastern Highland Otomi",
"otn": u"Tenango Otomi",
"ota": u"Ottoman Turkish (1500-1928)",
"otb": u"Old Tibetan",
"otd": u"Ot Danum",
"hwc": u"Hawai'i Creole English",
"nxl": u"South Nuaulu",
"otx": u"Texcatepec Otomi",
"xub": u"Betta Kurumba",
"oty": u"Old Tamil",
"otz": u"Ixtenco Otomi",
"kbx": u"Ap Ma",
"aln": u"Gheg Albanian",
"alg": u"Algonquian languages",
"pta": u"Pai Tavytera",
"alv": u"Atlantic-Congo languages",
"alt": u"Southern Altai",
"als": u"Tosk Albanian",
"xtt": u"Tacahua Mixtec",
"ots": u"Estado de México Otomi",
"prl": u"Peruvian Sign Language",
"wmo": u"Wom (Papua New Guinea)",
"wmm": u"Maiwa (Indonesia)",
"wma": u"Mawa (Nigeria)",
"faz": u"Northwestern Fars",
"fay": u"Southwestern Fars",
"mpm": u"Yosondúa Mixtec",
"mpj": u"Martu Wangka",
"mpk": u"Mbara (Chad)",
"fak": u"Fang (Cameroon)",
"fah": u"Baissa Fali",
"fan": u"Fang (Equatorial Guinea)",
"fal": u"South Fali",
"fab": u"Fa D'ambu",
"ysl": u"Yugoslavian Sign Language",
"ssv": u"Shark Bay",
"lln": u"Lele (Chad)",
"ten": u"Tama (Colombia)",
"nbs": u"Namibian Sign Language",
"nbw": u"Southern Ngbandi",
"nbu": u"Rongmei Naga",
"nbi": u"Mao Naga",
"nbm": u"Ngbaka Ma'bo",
"nbl": u"South Ndebele",
"nbc": u"Chang Naga",
"nbe": u"Konyak Naga",
"puj": u"Punan Tubu",
"puk": u"Pu Ko",
"sbz": u"Sara Kaba",
"puf": u"Punan Merah",
"kzs": u"Sugut Dusun",
"kzt": u"Tambunan Dusun",
"kzy": u"Kango (Tshopo District)",
"ywl": u"Western Lalu",
"kzc": u"Bondoukou Kulango",
"kza": u"Western Karaboro",
"kzf": u"Da'a Kaili",
"kzj": u"Coastal Kadazan",
"ysp": u"Southern Lolopo",
"sbc": u"Kele (Papua New Guinea)",
"jvn": u"Caribbean Javanese",
"xng": u"Middle Mongolian",
"gqn": u"Guana (Brazil)",
"pzn": u"Para Naga",
"xtr": u"Early Tripuri",
"hhi": u"Hoia Hoia",
"xtg": u"Transalpine Gaulish",
"egy": u"Egyptian (Ancient)",
"egx": u"Egyptian languages",
"lha": u"Laha (Viet Nam)",
"lhl": u"Lahul Lohar",
"lhi": u"Lahu Shi",
"lhh": u"Laha (Indonesia)",
"ffm": u"Maasina Fulfulde",
"ffi": u"Foia Foia",
"uve": u"West Uvean",
"xtb": u"Chazumba Mixtec",
"cea": u"Lower Chehalis",
"cel": u"Celtic languages",
"cek": u"Eastern Khumi Chin",
"rwm": u"Amba (Uganda)",
"rwr": u"Marwari (India)",
"xta": u"Alcozauca Mixtec",
"zgb": u"Guibei Zhuang",
"ifu": u"Mayoyao Ifugao",
"ynk": u"Naukan Yupik",
"ify": u"Keley-I Kallahan",
"ifa": u"Amganad Ifugao",
"ifb": u"Batad Ifugao",
"ifk": u"Tuwali Ifugao",
"nab": u"Southern Nambikuára",
"xto": u"Tokharian A",
"hab": u"Hanoi Sign Language",
"xtn": u"Northern Tlaxiaco Mixtec",
"asq": u"Austrian Sign Language",
"asp": u"Algerian Sign Language",
"asw": u"Australian Aborigines Sign Language",
"asu": u"Tocantins Asurini",
"pud": u"Punan Aput",
"asy": u"Yaosakor Asmat",
"pua": u"Western Highland Purepecha",
"puc": u"Punan Merap",
"asc": u"Casuarina Coast Asmat",
"asa": u"Asu (Tanzania)",
"asf": u"Australian Sign Language",
"ase": u"American Sign Language",
"asn": u"Xingú Asuriní",
"wlx": u"Wali (Ghana)",
"wlv": u"Wichí Lhamtés Vejoz",
"wll": u"Wali (Sudan)",
"wlm": u"Middle Welsh",
"wlc": u"Mwali Comorian",
"pmu": u"Mirpur Panjabi",
"pmw": u"Plains Miwok",
"qwh": u"Huaylas Ancash Quechua",
"gpe": u"Ghanaian Pidgin English",
"ncx": u"Central Puebla Nahuatl",
"tfi": u"Tofin Gbe",
"ywq": u"Wuding-Luquan Yi",
"ncs": u"Nicaraguan Sign Language",
"nct": u"Chothe Naga",
"nch": u"Central Huasteca Nahuatl",
"nci": u"Classical Nahuatl",
"ncj": u"Northern Puebla Nahuatl",
"ncl": u"Michoacán Nahuatl",
"ncb": u"Central Nicobarese",
"dtk": u"Tene Kan Dogon",
"dti": u"Ana Tinga Dogon",
"dto": u"Tommo So Dogon",
"dtm": u"Tomo Kan Dogon",
"stc": u"Santa Cruz",
"dtb": u"Labuk-Kinabatangan Kadazan",
"stj": u"Matya Samo",
"stt": u"Budeh Stieng",
"stp": u"Southeastern Tepehuan",
"str": u"Straits Salish",
"dts": u"Toro So Dogon",
"dtp": u"Central Dusun",
"dtu": u"Tebul Ure Dogon",
"dtt": u"Toro Tegu Dogon",
"zyj": u"Youjiang Zhuang",
"lia": u"West-Central Limba",
"lir": u"Liberian English",
"jsl": u"Japanese Sign Language",
"kah": u"Kara (Central African Republic)",
"kam": u"Kamba (Kenya)",
"kar": u"Karen languages",
"bzw": u"Basa (Nigeria)",
"bzs": u"Brazilian Sign Language",
"bzq": u"Buli (Indonesia)",
"scp": u"Helambu Sherpa",
"bzx": u"Kɛlɛngaxo Bozo",
"bze": u"Jenaama Bozo",
"bzc": u"Southern Betsimisaraka Malagasy",
"bzn": u"Boano (Maluku)",
"bzl": u"Boano (Sulawesi)",
"bzk": u"Nicaragua Creole English",
"bzj": u"Belize Kriol English",
"bzh": u"Mapos Buang",
"cdd": u"Caddoan languages",
"rtc": u"Rungtu Chin",
"cdc": u"Chadic languages",
"cdo": u"Min Dong Chinese",
"cds": u"Chadian Sign Language",
"tcz": u"Thado Chin",
"bfc": u"Northern Bai",
"bfb": u"Pauri Bareli",
"bfg": u"Busang Kayan",
"bfk": u"Ban Khor Sign Language",
"bfi": u"British Sign Language",
"bfo": u"Malba Birifor",
"bfs": u"Southern Bai",
"bfz": u"Mahasu Pahari",
"ymo": u"Yangum Mon",
"tcu": u"Southeastern Tarahumara",
"mfm": u"Marghi South",
"tcp": u"Tawr Chin",
"hif": u"Fiji Hindi",
"him": u"Himachali languages",
"pmz": u"Southern Pame",
"stb": u"Northern Subanen",
"tcl": u"Taman (Myanmar)",
"vmq": u"Soyaltepec Mixtec",
"arq": u"Algerian Arabic",
"arr": u"Karo (Brazil)",
"ars": u"Najdi Arabic",
"art": u"Artificial languages",
"aru": u"Aruá (Amazonas State)",
"arx": u"Aruá (Rodonia State)",
"ary": u"Moroccan Arabic",
"arz": u"Egyptian Arabic",
"sti": u"Bulo Stieng",
"roc": u"Cacgia Roglai",
"arb": u"Standard Arabic",
"arc": u"Official Aramaic (700-300 BCE)",
"are": u"Western Arrarnta",
"wos": u"Hanga Hundi",
"wom": u"Wom (Nigeria)",
"wof": u"Gambian Wolof",
"uur": u"Ura (Vanuatu)",
"gmh": u"Middle High German (ca. 1050-1500)",
"gml": u"Middle Low German",
"yha": u"Baha Buyang",
"tgw": u"Tagwana Senoufo",
"tgt": u"Central Tagbanwa",
"gme": u"East Germanic languages",
"tge": u"Eastern Gorkha Tamang",
"tgh": u"Tobagonian Creole English",
"duh": u"Dungra Bhil",
"dul": u"Alabat Island Agta",
"dum": u"Middle Dutch (ca. 1050-1350)",
"dun": u"Dusun Deyah",
"duo": u"Dupaninan Agta",
"swa": u"Swahili (macrolanguage)",
"due": u"Umiray Dumaget Agta",
"duy": u"Dicamay Agta",
"duq": u"Dusun Malang",
"duw": u"Dusun Witu",
"hbo": u"Ancient Hebrew",
"naz": u"Coatepec Nahuatl",
"gmq": u"North Germanic languages",
"skn": u"Kolibugan Subanon",
"gmw": u"West Germanic languages",
"iyx": u"Yaka (Congo)",
"jpa": u"Jewish Palestinian Aramaic",
"jpx": u"Japanese (family)",
"ril": u"Riang (Myanmar)",
"ria": u"Riang (India)",
"gss": u"Greek Sign Language",
"gsw": u"Swiss German",
"gse": u"Ghanaian Sign Language",
"gsg": u"German Sign Language",
"gsm": u"Guatemalan Sign Language",
"gso": u"Southwest Gbaya",
"sla": u"Slavic languages",
"qwc": u"Classical Quechua",
"ybe": u"West Yugur",
"qxr": u"Cañar Highland Quichua",
"ljp": u"Lampung Api",
"ssp": u"Spanish Sign Language",
"kak": u"Kayapa Kallahan",
"uzs": u"Southern Uzbek",
"ruo": u"Istro Romanian",
"sim": u"Mende (Papua New Guinea)",
"ruy": u"Mala (Nigeria)",
"zzj": u"Zuojiang Zhuang",
"ruq": u"Megleno Romanian",
"ruu": u"Lanas Lobu",
"bgd": u"Rathwi Bareli",
"bgl": u"Bo (Laos)",
"bgm": u"Baga Mboteni",
"bgn": u"Western Balochi",
"bgo": u"Baga Koga",
"bgp": u"Eastern Balochi",
"bgr": u"Bawm Chin",
"bgx": u"Balkan Gagauz Turkish",
"msr": u"Mongolian Sign Language",
"ixj": u"Chajul Ixil",
"ixi": u"Nebaj Ixil",
"xpe": u"Liberia Kpelle",
"syc": u"Classical Syriac",
"pww": u"Pwo Northern Karen",
"wni": u"Ndzwani Comorian",
"aqd": u"Ampari Dogon",
"aqa": u"Alacalufan languages",
"aql": u"Algic languages",
"aqn": u"Northern Alta",
"ute": u"Ute-Southern Paiute",
"utp": u"Amba (Solomon Islands)",
"grv": u"Central Grebo",
"nah": u"Nahuatl languages",
"nai": u"North American Indian",
"gry": u"Barclayville Grebo",
"gre": u"Modern Greek (1453-)",
"grc": u"Ancient Greek (to 1453)",
"gra": u"Rajput Garasia",
"grm": u"Kota Marudu Talantang",
"grj": u"Southern Grebo",
"grk": u"Greek languages",
"tmr": u"Jewish Babylonian Aramaic (ca. 200-1200 CE)",
"wci": u"Waci Gbe",
"yyu": u"Yau (Sandaun Province)",
"svk": u"Slovakian Sign Language",
"svc": u"Vincentian Creole English",
"syd": u"Samoyedic languages",
"ugn": u"Ugandan Sign Language",
"kcd": u"Ngkâlmpw Kanum",
"kcm": u"Gula (Central African Republic)",
"kcl": u"Kela (Papua New Guinea)",
"kcu": u"Kami (Tanzania)",
"bxx": u"Borna (Democratic Republic of Congo)",
"bxr": u"Russia Buriat",
"bxu": u"China Buriat",
"bxm": u"Mongolia Buriat",
"bxb": u"Belanda Bor",
"cfm": u"Falam Chin",
"cfg": u"Como Karim",
"bdl": u"Indonesian Bajau",
"bdh": u"Baka (Sudan)",
"bdv": u"Bodo Parja",
"bdr": u"West Coast Bajau",
"ymq": u"Qila Muji",
"hks": u"Hong Kong Sign Language",
"hkk": u"Hunjara-Kaina Ke",
"vbb": u"Southeast Babar",
"vbk": u"Southwestern Bontok",
"xwr": u"Kwerba Mamberamo",
"ymx": u"Northern Muji",
"spx": u"South Picene",
"tcw": u"Tecpatlán Totonac",
"wib": u"Southern Toussian",
"apw": u"Western Apache",
"apj": u"Jicarilla Apache",
"apk": u"Kiowa Apache",
"apl": u"Lipan Apache",
"apm": u"Mescalero-Chiricahua Apache",
"apc": u"North Levantine Arabic",
"apa": u"Apache languages",
"apf": u"Pahanan Agta",
"apd": u"Sudanese Arabic",
"ymc": u"Southern Muji",
"spp": u"Supyire Senoufo",
"spq": u"Loreto-Ucayali Spanish",
"spt": u"Spiti Bhoti",
"ymj": u"Muji Yi",
"tcs": u"Torres Strait Creole",
"tau": u"Upper Tanana",
"tar": u"Central Tarahumara",
"tas": u"Tay Boi",
"taa": u"Lower Tanana",
"spb": u"Sepa (Indonesia)",
"taj": u"Eastern Tamang",
"dws": u"Dutton World Speedwords",
"spe": u"Sepa (Papua New Guinea)",
"sia": u"Akkala Sami",
"sii": u"Shom Peng",
"sio": u"Siouan languages",
"dwl": u"Walo Kumbe Dogon",
"sil": u"Tumulung Sisaala",
"zmi": u"Negeri Sembilan Malay",
"zmg": u"Marti Ke",
"qxt": u"Santa Ana de Tusi Pasco Quechua",
"kbk": u"Grass Koiari",
"kbn": u"Kare (Central African Republic)",
"kby": u"Manga Kanuri",
"kbv": u"Dera (Indonesia)",
"byj": u"Bina (Nigeria)",
"syy": u"Al-Sayyid Bedouin Sign Language",
"qxu": u"Arequipa-La Unión Quechua",
"oui": u"Old Uighur",
"hlu": u"Hieroglyphic Luwian",
"hlt": u"Matu Chin",
"sne": u"Bau Bidayuh",
"hld": u"Halang Doan",
"pqe": u"Eastern Malayo-Polynesian languages",
"mzh": u"Wichí Lhamtés Güisnay",
"maz": u"Central Mazahua",
"tcf": u"Malinaltepec Me'phaa",
"ecs": u"Ecuadorian Sign Language",
"ltc": u"Late Middle Chinese",
"lti": u"Leti (Indonesia)",
"sns": u"South West Bay",
"snq": u"Sangu (Gabon)",
"zxx": u"No linguistic content",
"rsl": u"Russian Sign Language",
"rsi": u"Rennellese Sign Language",
"cya": u"Nopala Chatino",
"bem": u"Bemba (Zambia)",
"bez": u"Bena (Tanzania)",
"bex": u"Jur Modo",
"bey": u"Beli (Papua New Guinea)",
"ber": u"Berber languages",
"bev": u"Daloa Bété",
"bet": u"Guiberoua Béte",
"xrb": u"Eastern Karaboro",
"pyx": u"Pyu (Myanmar)",
"whg": u"North Wahgi",
"awy": u"Edera Awyu",
"awv": u"Jair Awyu",
"awu": u"Central Awyu",
"aws": u"South Awyu",
"whk": u"Wahau Kenyah",
"awd": u"Arawakan languages",
"awb": u"Awa (Papua New Guinea)",
"uro": u"Ura (Papua New Guinea)",
"urj": u"Uralic languages",
"urk": u"Urak Lawoi'",
"pst": u"Central Pashto",
"son": u"Songhai languages",
"ttx": u"Tutong 1",
"ngd": u"Ngando (Central African Republic)",
"ngf": u"Trans-New Guinea languages",
"ngg": u"Ngbaka Manza",
"ngb": u"Northern Ngbandi",
"ngc": u"Ngombe (Democratic Republic of Congo)",
"ngm": u"Ngatik Men's Creole",
"ngu": u"Guerrero Nahuatl",
"mga": u"Middle Irish (900-1200)",
"mgs": u"Manda (Tanzania)",
"mgp": u"Eastern Magar",
"tbd": u"Kaki Ae",
"tbg": u"North Tairora",
"shu": u"Chadian Arabic",
"shz": u"Syenara Senoufo",
"thh": u"Northern Tarahumara",
"shd": u"Kundal Shahi",
"ssr": u"Swiss-French Sign Language",
"ttm": u"Northern Tutchone",
"ebk": u"Eastern Bontok",
"luw": u"Luo (Cameroon)",
"luz": u"Southern Luri",
"luo": u"Luo (Kenya and Tanzania)",
"jos": u"Jordanian Sign Language",
"kee": u"Eastern Keres",
"kew": u"West Kewa",
"myz": u"Classical Mandaic",
"bbo": u"Northern Bobo Madaré",
"bbc": u"Batak Toba",
"jiu": u"Youle Jinuo",
"bbz": u"Babalia Creole Arabic",
"bbu": u"Kulung (Nigeria)",
"bbp": u"West Central Banda",
"otk": u"Old Turkish",
"hmx": u"Hmong-Mien languages",
"hmy": u"Southern Guiyang Hmong",
"hmz": u"Hmong Shua",
"oto": u"Otomian languages",
"hmv": u"Hmong Dô",
"hmw": u"Western Mashan Hmong",
"hmp": u"Northern Mashan Hmong",
"hmq": u"Eastern Qiandong Miao",
"hms": u"Southern Qiandong Miao",
"hml": u"Luopohe Hmong",
"hmm": u"Central Mashan Hmong",
"hmo": u"Hiri Motu",
"hmh": u"Southwestern Huishui Hmong",
"hmi": u"Northern Huishui Hmong",
"hmd": u"Large Flowery Miao",
"hme": u"Eastern Huishui Hmong",
"hmf": u"Hmong Don",
"hmg": u"Southwestern Guiyang Hmong",
"ott": u"Temoaya Otomi",
"hma": u"Southern Mashan Hmong",
"hmb": u"Humburi Senni Songhay",
"hmc": u"Central Huishui Hmong",
"jiy": u"Buyuan Jinuo",
"avl": u"Eastern Egyptian Bedawi Arabic",
"fkv": u"Kven Finnish",
"mzq": u"Mori Atas",
"mzy": u"Mozambican Sign Language",
"noa": u"Woun Meu",
"mzg": u"Monastic Sign Language",
"mza": u"Santa María Zacatepec Mixtec",
"mzc": u"Madagascar Sign Language",
"mzl": u"Mazatlán Mixe",
"mzi": u"Ixcatlán Mazatec",
"mzk": u"Nigeria Mambila",
"zyb": u"Yongbei Zhuang",
"zyn": u"Yongnan Zhuang",
"sbu": u"Stod Bhoti",
"syb": u"Central Subanen",
"mfa": u"Pattani Malay",
"mfk": u"North Mofu",
"mfn": u"Cross River Mbembe",
"mfp": u"Makassar Malay",
"mfs": u"Mexican Sign Language",
"tce": u"Southern Tutchone",
"skw": u"Skepi Creole Dutch",
"skx": u"Seko Padang",
"ske": u"Seke (Vanuatu)",
"skd": u"Southern Sierra Miwok",
"skg": u"Sakalava Malagasy",
"skc": u"Ma Manda",
"sko": u"Seko Tengah",
"skj": u"Seke (Nepal)",
"xsn": u"Sanga (Nigeria)",
"xsl": u"South Slavey",
"kdo": u"Kordofanian languages",
"jls": u"Jamaican Sign Language",
"kds": u"Lahu Shi",
"swh": u"Swahili (individual language)",
"swk": u"Malawi Sena",
"swl": u"Swedish Sign Language",
"ndi": u"Samba Leko",
"ndb": u"Kenswei Nsei",
"nde": u"North Ndebele",
"nds": u"Low German",
"owl": u"Old Welsh",
"swb": u"Maore Comorian",
"vaj": u"Vasekela Bushman",
"vaa": u"Vaagri Booli",
"zpp": u"El Alto Zapotec",
"hna": u"Mina (Cameroon)",
"hnd": u"Southern Hindko",
"dmb": u"Mombo Dogon",
"dmd": u"Madhi Madhi",
"lvs": u"Standard Latvian",
"dmg": u"Upper Kinabatangan",
"dmn": u"Mande languages",
"dmr": u"East Damar",
"hnj": u"Hmong Njua",
"myq": u"Forest Maninka",
"myt": u"Sangab Mandaya",
"myi": u"Mina (India)",
"myk": u"Mamara Senoufo",
"hno": u"Northern Hindko",
"myn": u"Mayan languages",
"sbd": u"Southern Samo",
"nre": u"Southern Rengma Naga",
"tzc": u"Chamula Tzotzil",
"bcl": u"Central Bikol",
"bcn": u"Bali (Nigeria)",
"bcd": u"North Babar",
"bcg": u"Baga Binari",
"bca": u"Central Bai",
"bcc": u"Southern Balochi",
"hns": u"Caribbean Hindustani",
"bcu": u"Awad Bing",
"bcp": u"Bali (Democratic Republic of Congo)"
}


ISO639_3_SUBST = dict(ISO639_3_1, **ISO639_3_2)

EXACT_LANGUAGE_NAME_REGEXES = {
    k: re.compile(ur'^{0}$'.format(re.escape(v)), re.I) for
    (k, v) in ISO639_3_SUBST.items()
}

WB_LANGUAGE_NAME_REGEXES = {
    k: re.compile(ur'\b{0}\b'.format(re.escape(v)), re.I) for
    (k, v) in ISO639_3_SUBST.items()
}
